import { createIconBase } from '../createIcon.js';

export const RhUiCardPaymentFillIconConfig = {
  name: 'RhUiCardPaymentFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M1 10V7.5C1 6.673 1.673 6 2.5 6h27c.827 0 1.5.673 1.5 1.5V10H1Zm30 3v11.5c0 .827-.673 1.5-1.5 1.5h-27c-.827 0-1.5-.673-1.5-1.5V13h30Zm-13.75 7c0-.69-.56-1.25-1.25-1.25H7a1.25 1.25 0 0 0 0 2.5h9c.69 0 1.25-.56 1.25-1.25Z"},
  rhUiIcon: null,
};

export const RhUiCardPaymentFillIcon = createIconBase(RhUiCardPaymentFillIconConfig);

export default RhUiCardPaymentFillIcon;