import { createIconBase } from '../createIcon.js';

export const RhStandardVulnerabilityIconConfig = {
  name: 'RhStandardVulnerabilityIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M18 23.38a.63.63 0 0 0-.62.63.63.63 0 0 0 1.25 0 .63.63 0 0 0-.63-.63Zm0-2.76a.62.62 0 0 1-.62-.62v-8a.62.62 0 1 1 1.24 0v8a.62.62 0 0 1-.62.62Z"},{"path":"M18 31.62A11.63 11.63 0 0 1 6.38 20V7.34a.61.61 0 0 1 .49-.61l11-2.34a.57.57 0 0 1 .26 0l11 2.34a.61.61 0 0 1 .49.61V20A11.63 11.63 0 0 1 18 31.62ZM7.62 7.84V20a10.38 10.38 0 0 0 20.76 0V7.84L18 5.64Z"}]},
  rhUiIcon: null,
};

export const RhStandardVulnerabilityIcon = createIconBase(RhStandardVulnerabilityIconConfig);

export default RhStandardVulnerabilityIcon;