import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsArrowRightIconConfig: {
  name: 'RhMicronsArrowRightIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M18.35 8.94 12.7 3.29a.987.987 0 0 0-1.41-.02.987.987 0 0 0-.02 1.41l.02.02 4.29 4.29H2c-.55 0-1 .45-1 1s.45 1 1 1h13.59l-4.29 4.29a.987.987 0 0 0-.02 1.41c.38.4 1.02.41 1.41.02l.02-.02 5.65-5.65c.59-.59.59-1.53 0-2.12Z"},
  rhUiIcon: null,
};
export declare const RhMicronsArrowRightIcon: ComponentClass<SVGIconProps>;
export default RhMicronsArrowRightIcon;