import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardLayeredIconConfig: {
  name: 'RhStandardLayeredIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M31 11.38h-6.38V5a.62.62 0 0 0-.62-.62H5a.62.62 0 0 0-.62.62v19a.62.62 0 0 0 .62.62h6.38V31a.62.62 0 0 0 .62.62h19a.62.62 0 0 0 .62-.62V12a.62.62 0 0 0-.62-.62ZM11.38 12v11.38H5.62V5.62h17.76v5.76H12a.62.62 0 0 0-.62.62Zm19 18.38H12.62V12.62h17.76Z"},
  rhUiIcon: null,
};
export declare const RhStandardLayeredIcon: ComponentClass<SVGIconProps>;
export default RhStandardLayeredIcon;