import { createIconBase } from '../createIcon.js';

export const RhUiCloudFillIconConfig = {
  name: 'RhUiCloudFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30.75 19.5a5.256 5.256 0 0 1-5.25 5.25H8c-3.722 0-6.75-3.028-6.75-6.75S4.278 11.25 8 11.25c.549 0 1.094.068 1.628.203A8.777 8.777 0 0 1 18 5.25c4.825 0 8.75 3.925 8.75 8.75 0 .136-.004.275-.013.419A5.21 5.21 0 0 1 30.75 19.5Z"},
  rhUiIcon: null,
};

export const RhUiCloudFillIcon = createIconBase(RhUiCloudFillIconConfig);

export default RhUiCloudFillIcon;