import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardCommandLineIconConfig: {
  name: 'RhStandardCommandLineIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"m11.44 25.44 7-7a.61.61 0 0 0 0-.88l-7-7a.63.63 0 1 0-.88.88L17.12 18l-6.56 6.56a.63.63 0 1 0 .88.88Zm6.94-.52a.63.63 0 0 0 .62.63h7a.63.63 0 0 0 0-1.25h-7a.62.62 0 0 0-.62.62Z"},{"path":"M31 4.38H5a.62.62 0 0 0-.62.62v26a.62.62 0 0 0 .62.62h26a.62.62 0 0 0 .62-.62V5a.62.62 0 0 0-.62-.62Zm-.62 26H5.62V5.62h24.76Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardCommandLineIcon: ComponentClass<SVGIconProps>;
export default RhStandardCommandLineIcon;