import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiHarveyBall50IconConfig: {
  name: 'RhUiHarveyBall50Icon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1ZM3 16C3 9.168 8.297 3.551 15 3.038v25.924C8.297 28.449 3 22.832 3 16Z"},
  rhUiIcon: null,
};
export declare const RhUiHarveyBall50Icon: ComponentClass<SVGIconProps>;
export default RhUiHarveyBall50Icon;