import { createIconBase } from '../createIcon.js';

export const RhUiLongArrowDownIconConfig = {
  name: 'RhUiLongArrowDownIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"m22.707 24.707-5.646 5.646c-.292.292-.676.438-1.061.438s-.768-.146-1.061-.438l-5.646-5.646a.999.999 0 1 1 1.414-1.414L15 27.586V2a1 1 0 0 1 2 0v25.586l4.293-4.293a.999.999 0 1 1 1.414 1.414Z"},
  rhUiIcon: null,
};

export const RhUiLongArrowDownIcon = createIconBase(RhUiLongArrowDownIconConfig);

export default RhUiLongArrowDownIcon;