import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiFlagFillIconConfig: {
  name: 'RhUiFlagFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"m27.978 2.209-3 14A1 1 0 0 1 24 17H6v13a1 1 0 1 1-2 0V2.5C4 1.673 4.673 1 5.5 1H27a.997.997 0 0 1 .977 1.209Z"},
  rhUiIcon: null,
};
export declare const RhUiFlagFillIcon: ComponentClass<SVGIconProps>;
export default RhUiFlagFillIcon;