import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiCaretDownFillIconConfig: {
  name: 'RhUiCaretDownFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29.707 11.707 17.061 24.353c-.292.292-.677.438-1.061.438s-.769-.146-1.061-.438L2.293 11.707A1 1 0 0 1 3 10h26a1 1 0 0 1 .707 1.707Z"},
  rhUiIcon: null,
};
export declare const RhUiCaretDownFillIcon: ComponentClass<SVGIconProps>;
export default RhUiCaretDownFillIcon;