import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiPublishIconConfig: {
  name: 'RhUiPublishIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30 3.5V6a1 1 0 1 1-2 0V4H4v2a1 1 0 1 1-2 0V3.5C2 2.673 2.673 2 3.5 2h25c.827 0 1.5.673 1.5 1.5ZM17.061 7.646a1.501 1.501 0 0 0-2.121 0l-8.646 8.646a.999.999 0 1 0 1.414 1.414l7.293-7.293v18.586a1 1 0 1 0 2 0V10.414l7.293 7.293a.997.997 0 0 0 1.414 0 .999.999 0 0 0 0-1.414l-8.646-8.646Z"},
  rhUiIcon: null,
};
export declare const RhUiPublishIcon: ComponentClass<SVGIconProps>;
export default RhUiPublishIcon;