import { createIconBase } from '../createIcon.js';

export const RhUiArrowCircleUpLeftFillIconConfig = {
  name: 'RhUiArrowCircleUpLeftFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm6.795 21.796c-.22.22-.507.329-.795.329s-.576-.109-.795-.329l-10.08-10.08V19a1.125 1.125 0 0 1-2.25 0v-8.5c0-.896.729-1.625 1.625-1.625H19a1.125 1.125 0 0 1 0 2.25h-6.284l10.079 10.079a1.127 1.127 0 0 1 0 1.592Z"},
  rhUiIcon: null,
};

export const RhUiArrowCircleUpLeftFillIcon = createIconBase(RhUiArrowCircleUpLeftFillIconConfig);

export default RhUiArrowCircleUpLeftFillIcon;