import { createIconBase } from '../createIcon.js';

export const RhStandardCupIconConfig = {
  name: 'RhStandardCupIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M26 13.38H10a.63.63 0 0 0-.62.73l3 17a.63.63 0 0 0 .62.51h10a.63.63 0 0 0 .62-.51l3-17a.63.63 0 0 0-.62-.73Zm-3.52 17h-9l-2.73-15.76h14.5Zm4.52-20h-8.38V6.33l2.73-1.81a.63.63 0 0 0-.7-1l-3 2a.63.63 0 0 0-.27.52v4.38H9a.62.62 0 0 0 0 1.24h18a.62.62 0 0 0 0-1.28Z"},
  rhUiIcon: null,
};

export const RhStandardCupIcon = createIconBase(RhStandardCupIconConfig);

export default RhStandardCupIcon;