.pf-v6-svg {
  width: 1em;
  height: 1em;
  vertical-align: -0.125em;
}

.pf-v6-svg .pf-v6-icon-rh-ui {
  display: none;
}

.pf-v6-icon-set-rh-ui .pf-v6-svg .pf-v6-icon-default {
  display: none;
}
.pf-v6-icon-set-rh-ui .pf-v6-svg .pf-v6-icon-rh-ui {
  display: revert;
}

.pf-v6-icon-rh-standard {
  width: 3rem;
  height: 3rem;
  color: var(--pf-t--global--icon--color--brand--accent--default);
}