import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiOpenDrawerLeftFillIconConfig: {
  name: 'RhUiOpenDrawerLeftFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M7.125 9.125h5.75v13.75h-5.75V9.125ZM31 4.5v23c0 .827-.673 1.5-1.5 1.5h-27c-.827 0-1.5-.673-1.5-1.5v-23C1 3.673 1.673 3 2.5 3h27c.827 0 1.5.673 1.5 1.5Zm-15.875 4c0-.896-.729-1.625-1.625-1.625h-7c-.896 0-1.625.729-1.625 1.625v15c0 .896.729 1.625 1.625 1.625h7c.896 0 1.625-.729 1.625-1.625v-15Z"},
  rhUiIcon: null,
};
export declare const RhUiOpenDrawerLeftFillIcon: ComponentClass<SVGIconProps>;
export default RhUiOpenDrawerLeftFillIcon;