import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiArrowCircleLeftFillIconConfig: {
  name: 'RhUiArrowCircleLeftFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm8 16.125H10.716l4.08 4.08A1.127 1.127 0 0 1 14 23.126c-.288 0-.576-.11-.796-.33L7.558 17.15a1.628 1.628 0 0 1 0-2.298l5.646-5.646a1.127 1.127 0 0 1 1.592 0 1.127 1.127 0 0 1 0 1.591l-4.08 4.08H24a1.125 1.125 0 0 1 0 2.25Z"},
  rhUiIcon: null,
};
export declare const RhUiArrowCircleLeftFillIcon: ComponentClass<SVGIconProps>;
export default RhUiArrowCircleLeftFillIcon;