import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiDesktopIconConfig: {
  name: 'RhUiDesktopIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29.5 3h-27C1.673 3 1 3.673 1 4.5v17c0 .827.673 1.5 1.5 1.5H12v4H8a1 1 0 0 0 0 2h16a1 1 0 0 0 0-2h-4v-4h9.5c.827 0 1.5-.673 1.5-1.5v-17c0-.827-.673-1.5-1.5-1.5ZM18 27h-4v-4h4v4Zm11-6H3V5h26v16Z"},
  rhUiIcon: null,
};
export declare const RhUiDesktopIcon: ComponentClass<SVGIconProps>;
export default RhUiDesktopIcon;