import { createIconBase } from '../createIcon.js';

export const RhUiArrowCircleDownRightFillIconConfig = {
  name: 'RhUiArrowCircleDownRightFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm7.125 20.5c0 .896-.729 1.625-1.625 1.625H13a1.125 1.125 0 0 1 0-2.25h6.284L9.205 10.796a1.125 1.125 0 1 1 1.591-1.592l10.08 10.08V13a1.125 1.125 0 0 1 2.25 0v8.5Z"},
  rhUiIcon: null,
};

export const RhUiArrowCircleDownRightFillIcon = createIconBase(RhUiArrowCircleDownRightFillIconConfig);

export default RhUiArrowCircleDownRightFillIcon;