import { createIconBase } from '../createIcon.js';

export const RhUiExportIconConfig = {
  name: 'RhUiExportIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30 3.5V11a1 1 0 1 1-2 0V4H4v24h7a1 1 0 1 1 0 2H3.5c-.827 0-1.5-.673-1.5-1.5v-25C2 2.673 2.673 2 3.5 2h25c.827 0 1.5.673 1.5 1.5ZM29 17a1 1 0 0 0-1 1v8.586L14.707 13.293a.999.999 0 1 0-1.414 1.414L26.586 28H18a1 1 0 1 0 0 2h10.5c.827 0 1.5-.673 1.5-1.5V18a1 1 0 0 0-1-1Z"},
  rhUiIcon: null,
};

export const RhUiExportIcon = createIconBase(RhUiExportIconConfig);

export default RhUiExportIcon;