import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiArrowLeftIconConfig: {
  name: 'RhUiArrowLeftIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30 15H4.414l9.293-9.293a.999.999 0 1 0-1.414-1.414L1.646 14.939c-.283.283-.439.66-.439 1.061s.156.777.439 1.061l10.646 10.646a.997.997 0 0 0 1.414 0 .999.999 0 0 0 0-1.414L4.413 17h25.586a1 1 0 0 0 0-2Z"},
  rhUiIcon: null,
};
export declare const RhUiArrowLeftIcon: ComponentClass<SVGIconProps>;
export default RhUiArrowLeftIcon;