import { createIconBase } from '../createIcon.js';

export const RhStandardPaperBlankIconConfig = {
  name: 'RhStandardPaperBlankIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M28 4.38H12a.7.7 0 0 0-.44.18l-4 4a.59.59 0 0 0-.15.28V31a.62.62 0 0 0 .62.62H28a.62.62 0 0 0 .62-.62V5a.62.62 0 0 0-.62-.62ZM11.38 6.51v1.87H9.51Zm16 23.87H8.62V9.62H12a.62.62 0 0 0 .62-.62V5.62h14.76Z"},
  rhUiIcon: null,
};

export const RhStandardPaperBlankIcon = createIconBase(RhStandardPaperBlankIconConfig);

export default RhStandardPaperBlankIcon;