import { createIconBase } from '../createIcon.js';

export const RhUiArrowCircleUpLeftIconConfig = {
  name: 'RhUiArrowCircleUpLeftIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M21.657 20.243a.999.999 0 1 1-1.414 1.414L12 13.414V20a1 1 0 1 1-2 0v-8.5c0-.827.673-1.5 1.5-1.5H20a1 1 0 1 1 0 2h-6.586l8.243 8.243ZM31 16c0 8.271-6.729 15-15 15S1 24.271 1 16 7.729 1 16 1s15 6.729 15 15Zm-2 0c0-7.168-5.832-13-13-13S3 8.832 3 16s5.832 13 13 13 13-5.832 13-13Z"},
  rhUiIcon: null,
};

export const RhUiArrowCircleUpLeftIcon = createIconBase(RhUiArrowCircleUpLeftIconConfig);

export default RhUiArrowCircleUpLeftIcon;