import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardPencilIconConfig: {
  name: 'RhStandardPencilIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"m31.44 7.56-3-3a.61.61 0 0 0-.88 0l-3 3L7.07 24.91a1.53 1.53 0 0 0-.14.21l-2.5 5.63a.61.61 0 0 0 .13.69.6.6 0 0 0 .69.13l5.65-2.51.19-.13 17.35-17.49 3-3a.61.61 0 0 0 0-.88ZM6.23 29.77l1.48-3.33 1.85 1.85ZM26 12.12l-.57-.56a.62.62 0 0 0-.88.88l.57.57L10.64 27.6 8.4 25.36 25 8.88 27.12 11Zm2-2L25.88 8 28 5.88 30.12 8Z"},
  rhUiIcon: null,
};
export declare const RhStandardPencilIcon: ComponentClass<SVGIconProps>;
export default RhStandardPencilIcon;