import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiCaretDownIconConfig: {
  name: 'RhUiCaretDownIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 24.792c-.384 0-.769-.146-1.061-.438L2.293 11.707a.999.999 0 1 1 1.414-1.414L16 22.586l12.293-12.293a.999.999 0 1 1 1.414 1.414L17.061 24.353a1.497 1.497 0 0 1-1.061.438Z"},
  rhUiIcon: null,
};
export declare const RhUiCaretDownIcon: ComponentClass<SVGIconProps>;
export default RhUiCaretDownIcon;