import { createIconBase } from '../createIcon.js';

export const RhStandardPaperStackBlankIconConfig = {
  name: 'RhStandardPaperStackBlankIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M25.62 27.88V5a.62.62 0 0 0-.62-.62H12a.66.66 0 0 0-.44.19l-4 4a.55.55 0 0 0-.18.43v18.88a.62.62 0 0 0 .62.62h17a.62.62 0 0 0 .62-.62ZM11.38 6.51v1.87H9.51Zm13 20.74H8.62V9.62H12a.62.62 0 0 0 .62-.62V5.62h11.76Z"},{"path":"M28 7.5a.62.62 0 0 0-.62.62v22.26H11a.62.62 0 0 0 0 1.24h17a.62.62 0 0 0 .62-.62V8.12A.62.62 0 0 0 28 7.5Z"}]},
  rhUiIcon: null,
};

export const RhStandardPaperStackBlankIcon = createIconBase(RhStandardPaperStackBlankIconConfig);

export default RhStandardPaperStackBlankIcon;