import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardYenIconConfig: {
  name: 'RhStandardYenIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M30.442 4.558a.625.625 0 0 0-.884 0L18 16.116 6.442 4.558a.625.625 0 1 0-.884.884l10.933 10.933H10a.625.625 0 0 0 0 1.25h7.375v3.75H10a.625.625 0 0 0 0 1.25h7.375V31a.625.625 0 0 0 1.25 0v-8.375H26a.625.625 0 0 0 0-1.25h-7.375v-3.75H26a.625.625 0 0 0 0-1.25h-6.49L30.441 5.442a.626.626 0 0 0 0-.884Z"},
  rhUiIcon: null,
};
export declare const RhStandardYenIcon: ComponentClass<SVGIconProps>;
export default RhStandardYenIcon;