import { createIconBase } from '../createIcon.js';

export const RhMicronsQuestionMarkCircleFillIconConfig = {
  name: 'RhMicronsQuestionMarkCircleFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M10 0C4.486 0 0 4.486 0 10s4.486 10 10 10 10-4.486 10-10S15.514 0 10 0Zm0 16.5a1.5 1.5 0 1 1 0-3 1.5 1.5 0 0 1 0 3Zm1.125-6.572V11a1.125 1.125 0 0 1-2.25 0V9c0-.621.504-1.125 1.125-1.125.758 0 1.375-.617 1.375-1.375a1.377 1.377 0 0 0-2.723-.277 1.125 1.125 0 1 1-2.205-.445A3.633 3.633 0 0 1 10 2.874 3.629 3.629 0 0 1 13.625 6.5c0 1.604-1.054 2.952-2.5 3.428Z"},
  rhUiIcon: null,
};

export const RhMicronsQuestionMarkCircleFillIcon = createIconBase(RhMicronsQuestionMarkCircleFillIconConfig);

export default RhMicronsQuestionMarkCircleFillIcon;