import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiArrowCircleUpFillIconConfig: {
  name: 'RhUiArrowCircleUpFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm6.796 13.795a1.122 1.122 0 0 1-1.592 0l-4.079-4.079V24a1.125 1.125 0 0 1-2.25 0V10.716l-4.079 4.079a1.127 1.127 0 0 1-1.592 0 1.127 1.127 0 0 1 0-1.591l5.646-5.646a1.627 1.627 0 0 1 2.299 0l5.646 5.646a1.127 1.127 0 0 1 0 1.591Z"},
  rhUiIcon: null,
};
export declare const RhUiArrowCircleUpFillIcon: ComponentClass<SVGIconProps>;
export default RhUiArrowCircleUpFillIcon;