import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiMobilePhoneFillIconConfig: {
  name: 'RhUiMobilePhoneFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M22 1H10C8.346 1 7 2.346 7 4v24c0 1.654 1.346 3 3 3h12c1.654 0 3-1.346 3-3V4c0-1.654-1.346-3-3-3Zm-5.995 3.128a1.875 1.875 0 1 1 0 3.75 1.875 1.875 0 0 1 0-3.75ZM19 27.125h-6a1.125 1.125 0 0 1 0-2.25h6a1.125 1.125 0 0 1 0 2.25Z"},
  rhUiIcon: null,
};
export declare const RhUiMobilePhoneFillIcon: ComponentClass<SVGIconProps>;
export default RhUiMobilePhoneFillIcon;