import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const MicrosoftIconConfig: {
  name: 'MicrosoftIcon',
  icon: {"xOffset":0,"yOffset":0,"width":448,"height":512,"svgPathData":"M0 32h214.6v214.6H0V32zm233.4 0H448v214.6H233.4V32zM0 265.4h214.6V480H0V265.4zm233.4 0H448V480H233.4V265.4z"},
  rhUiIcon: null,
};
export declare const MicrosoftIcon: ComponentClass<SVGIconProps>;
export default MicrosoftIcon;