import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardPauseIconConfig: {
  name: 'RhStandardPauseIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M15 4.38H8a.61.61 0 0 0-.62.62v26a.61.61 0 0 0 .62.62h7a.61.61 0 0 0 .62-.62V5a.61.61 0 0 0-.62-.62Zm-.62 26H8.62V5.62h5.76ZM28 4.38h-7a.61.61 0 0 0-.62.62v26a.61.61 0 0 0 .62.62h7a.61.61 0 0 0 .62-.62V5a.61.61 0 0 0-.62-.62Zm-.62 26h-5.76V5.62h5.76Z"},
  rhUiIcon: null,
};
export declare const RhStandardPauseIcon: ComponentClass<SVGIconProps>;
export default RhStandardPauseIcon;