
// Do not edit directly
// Generated on Tue, 23 Jun 2026 19:20:00 GMT

// Only tokens that differ from base theme (24 tokens)
@mixin pf-v6-tokens {
  --pf-t--global--background--color--glass--primary--default: rgb(255, 255, 255, 0.5000);
  --pf-t--global--background--color--primary--clicked: rgb(199, 199, 199, 0.3000);
  --pf-t--global--background--color--primary--default: rgb(255, 255, 255, 0.6000);
  --pf-t--global--background--color--primary--hover: rgb(199, 199, 199, 0.3000);
  --pf-t--global--background--color--secondary--clicked: rgb(163, 163, 163, 0.3000);
  --pf-t--global--background--color--secondary--default: rgb(199, 199, 199, 0.3000);
  --pf-t--global--background--color--secondary--hover: rgb(163, 163, 163, 0.3000);
  --pf-t--global--background--filter--glass--blur--primary: blur(16px);
  --pf-t--global--border--width--main--default: var(--pf-t--global--border--width--100);
  --pf-t--global--background--color--action--plain--alt--clicked: var(--pf-t--global--background--color--action--plain--clicked);
  --pf-t--global--background--color--action--plain--alt--hover: var(--pf-t--global--background--color--action--plain--hover);
  --pf-t--global--border--color--brand--accent--clicked: var(--pf-t--global--color--brand--accent--400);
  --pf-t--global--border--color--brand--accent--default: var(--pf-t--global--color--brand--accent--400);
  --pf-t--global--border--color--brand--accent--hover: var(--pf-t--global--color--brand--accent--400);
  --pf-t--global--border--color--glass--default: var(--pf-t--global--border--color--alt);
  --pf-t--global--border--radius--action--plain--default: var(--pf-t--global--border--radius--pill);
  --pf-t--global--border--radius--control--default: var(--pf-t--global--border--radius--pill);
  --pf-t--global--border--radius--glass--default: var(--pf-t--global--border--radius--medium);
  --pf-t--global--border--width--glass--default: var(--pf-t--global--border--width--regular);
  --pf-t--global--color--brand--accent--clicked: var(--pf-t--global--color--brand--accent--200);
  --pf-t--global--color--brand--accent--default: var(--pf-t--global--color--brand--accent--100);
  --pf-t--global--color--brand--accent--hover: var(--pf-t--global--color--brand--accent--200);
  --pf-t--global--spacer--inset--page-chrome: var(--pf-t--global--spacer--md);
  --pf-t--global--background--color--floating--secondary--default: var(--pf-t--global--background--color--floating--default);
}
