import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardWalkArrowIconConfig: {
  name: 'RhStandardWalkArrowIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"m21.44 17.56-13-13a.62.62 0 0 0-.88.88L20.12 18 7.56 30.56a.62.62 0 0 0 .88.88l13-13a.61.61 0 0 0 0-.88Z"},{"path":"m28.44 17.56-13-13a.62.62 0 0 0-.88.88L27.12 18 14.56 30.56a.62.62 0 0 0 .88.88l13-13a.61.61 0 0 0 0-.88Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardWalkArrowIcon: ComponentClass<SVGIconProps>;
export default RhStandardWalkArrowIcon;