import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiBookmarkIconConfig: {
  name: 'RhUiBookmarkIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M28 31a1 1 0 0 1-.707-.293L16 19.414 4.707 30.707A.999.999 0 0 1 3 30V2.5C3 1.673 3.673 1 4.5 1h23c.827 0 1.5.673 1.5 1.5V30a.999.999 0 0 1-1 1ZM16 17.207c.4 0 .777.156 1.061.439L27 27.585V3H5v24.586l9.939-9.939A1.49 1.49 0 0 1 16 17.208Z"},
  rhUiIcon: null,
};
export declare const RhUiBookmarkIcon: ComponentClass<SVGIconProps>;
export default RhUiBookmarkIcon;