import { createIconBase } from '../createIcon.js';

export const RhUiPauseFillIconConfig = {
  name: 'RhUiPauseFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M13.5 2.5v27c0 .551-.448 1-1 1h-8c-.552 0-1-.449-1-1v-27c0-.551.448-1 1-1h8c.552 0 1 .449 1 1Zm14-1h-8c-.552 0-1 .449-1 1v27c0 .551.448 1 1 1h8c.552 0 1-.449 1-1v-27c0-.551-.448-1-1-1Z"},
  rhUiIcon: null,
};

export const RhUiPauseFillIcon = createIconBase(RhUiPauseFillIconConfig);

export default RhUiPauseFillIcon;