import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiArrowCircleDownLeftFillIconConfig: {
  name: 'RhUiArrowCircleDownLeftFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm6.795 9.796L12.716 20.875H19a1.125 1.125 0 0 1 0 2.25h-8.5A1.627 1.627 0 0 1 8.875 21.5V13a1.125 1.125 0 0 1 2.25 0v6.284l10.08-10.08a1.126 1.126 0 0 1 1.591 1.592Z"},
  rhUiIcon: null,
};
export declare const RhUiArrowCircleDownLeftFillIcon: ComponentClass<SVGIconProps>;
export default RhUiArrowCircleDownLeftFillIcon;