import { createIconBase } from '../createIcon.js';

export const RhMicronsCaretRightFillIconConfig = {
  name: 'RhMicronsCaretRightFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M14.48 10.977 8.76 17.65A1 1 0 0 1 7 17V3a.998.998 0 0 1 1.76-.65l5.72 6.674a1.49 1.49 0 0 1 0 1.953Z"},
  rhUiIcon: null,
};

export const RhMicronsCaretRightFillIcon = createIconBase(RhMicronsCaretRightFillIconConfig);

export default RhMicronsCaretRightFillIcon;