import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiExpandIconConfig: {
  name: 'RhUiExpandIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30 3.5V10a1 1 0 0 1-2 0V4h-6a1 1 0 0 1 0-2h6.5c.827 0 1.5.673 1.5 1.5ZM10 2H3.5C2.673 2 2 2.673 2 3.5V10a1 1 0 0 0 2 0V4h6a1 1 0 0 0 0-2Zm0 26H4v-6a1 1 0 0 0-2 0v6.5c0 .827.673 1.5 1.5 1.5H10a1 1 0 0 0 0-2Zm19-7a1 1 0 0 0-1 1v6h-6a1 1 0 0 0 0 2h6.5c.827 0 1.5-.673 1.5-1.5V22a1 1 0 0 0-1-1Z"},
  rhUiIcon: null,
};
export declare const RhUiExpandIcon: ComponentClass<SVGIconProps>;
export default RhUiExpandIcon;