import { createIconBase } from '../createIcon.js';

export const RhUiImportAltFillIconConfig = {
  name: 'RhUiImportAltFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30 3.5v25c0 .827-.673 1.5-1.5 1.5h-25c-.827 0-1.5-.673-1.5-1.5V3.591l13.284 13.284H7a1.125 1.125 0 0 0 0 2.25h10.5c.896 0 1.625-.729 1.625-1.625V7a1.125 1.125 0 0 0-2.25 0v8.284L3.591 2H28.5c.827 0 1.5.673 1.5 1.5Z"},
  rhUiIcon: null,
};

export const RhUiImportAltFillIcon = createIconBase(RhUiImportAltFillIconConfig);

export default RhUiImportAltFillIcon;