import { createIconBase } from '../createIcon.js';

export const RhMicronsDoubleCaretDownIconConfig = {
  name: 'RhMicronsDoubleCaretDownIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M1.293 2.707a1 1 0 1 1 1.414-1.414L10 8.586l7.293-7.293a1 1 0 1 1 1.414 1.414l-7.646 7.647c-.293.292-.677.438-1.061.438s-.768-.146-1.06-.438L1.292 2.707Zm16 6.586L10 16.586 2.707 9.293a1 1 0 1 0-1.414 1.414l7.646 7.647c.293.292.677.438 1.061.438s.768-.146 1.06-.438l7.647-7.647a1 1 0 1 0-1.414-1.414Z"},
  rhUiIcon: null,
};

export const RhMicronsDoubleCaretDownIcon = createIconBase(RhMicronsDoubleCaretDownIconConfig);

export default RhMicronsDoubleCaretDownIcon;