import { Level, LevelItem } from '@patternfly/react-core';

export const LevelBasic: React.FunctionComponent = () => (
  <Level>
    <LevelItem>Level Item</LevelItem>
    <LevelItem>Level Item</LevelItem>
    <LevelItem>Level Item</LevelItem>
  </Level>
);
