import { createIconBase } from '../createIcon.js';

export const OutlinedWindowMinimizeIconConfig = {
  name: 'OutlinedWindowMinimizeIcon',
  icon: {"xOffset":0,"yOffset":0,"width":512,"height":512,"svgPathData":"M480 480H32c-17.7 0-32-14.3-32-32s14.3-32 32-32h448c17.7 0 32 14.3 32 32s-14.3 32-32 32z"},
  rhUiIcon: null,
};

export const OutlinedWindowMinimizeIcon = createIconBase(OutlinedWindowMinimizeIconConfig);

export default OutlinedWindowMinimizeIcon;