import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const ModxIconConfig: {
  name: 'ModxIcon',
  icon: {"xOffset":0,"yOffset":0,"width":448,"height":512,"svgPathData":"M356 241.8l36.7 23.7V480l-133-83.8L356 241.8zM440 75H226.3l-23 37.8 153.5 96.5L440 75zm-89 142.8L55.2 32v214.5l46 29L351 217.8zM97 294.2L8 437h213.7l125-200.5L97 294.2z"},
  rhUiIcon: null,
};
export declare const ModxIcon: ComponentClass<SVGIconProps>;
export default ModxIcon;