import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiDoubleCaretLeftFillIconConfig: {
  name: 'RhUiDoubleCaretLeftFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M15.707 20.293A1 1 0 0 1 16 21v8a1.002 1.002 0 0 1-1.707.707L1.646 17.061a1.501 1.501 0 0 1 0-2.121L14.293 2.293A1 1 0 0 1 16 3v8c0 .265-.105.52-.293.707l-3.586 3.586a1 1 0 0 0 0 1.414l3.586 3.586ZM29.383 2.076a.996.996 0 0 0-1.09.217L15.647 14.939a1.501 1.501 0 0 0 0 2.121l12.646 12.646A1 1 0 0 0 30 28.999V3c0-.404-.244-.769-.617-.924Z"},
  rhUiIcon: null,
};
export declare const RhUiDoubleCaretLeftFillIcon: ComponentClass<SVGIconProps>;
export default RhUiDoubleCaretLeftFillIcon;