import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiHarveyBall75IconConfig: {
  name: 'RhUiHarveyBall75Icon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm-1 2.038V15H3.038C3.525 8.627 8.627 3.525 15 3.038Z"},
  rhUiIcon: null,
};
export declare const RhUiHarveyBall75Icon: ComponentClass<SVGIconProps>;
export default RhUiHarveyBall75Icon;