import { createIconBase } from '../createIcon.js';

export const RhUiPlugIconConfig = {
  name: 'RhUiPlugIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M22.5 7H21V2a1 1 0 1 0-2 0v5h-6V2a1 1 0 1 0-2 0v5H9.5C8.673 7 8 7.673 8 8.5V15c0 4.072 3.06 7.436 7 7.931V30a1 1 0 1 0 2 0v-7.069c3.94-.495 7-3.859 7-7.931V8.5c0-.827-.673-1.5-1.5-1.5Zm-.5 8c0 3.309-2.691 6-6 6s-6-2.691-6-6V9h12v6Z"},
  rhUiIcon: null,
};

export const RhUiPlugIcon = createIconBase(RhUiPlugIconConfig);

export default RhUiPlugIcon;