import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardCrawlArrowIconConfig: {
  name: 'RhStandardCrawlArrowIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M12 31.62a.62.62 0 0 1-.44-1.06L24.12 18 11.56 5.44c-.58-.56.31-1.47.88-.88l13 13a.61.61 0 0 1 0 .88l-13 13a.62.62 0 0 1-.44.18Z"},
  rhUiIcon: null,
};
export declare const RhStandardCrawlArrowIcon: ComponentClass<SVGIconProps>;
export default RhStandardCrawlArrowIcon;