/// <reference types="react" />
export interface CompassHeaderProps {
    /** Content of the logo area */
    logo?: React.ReactNode;
    /** Content of the navigation area */
    nav?: React.ReactNode;
    /** Content of the profile area */
    profile?: React.ReactNode;
}
export declare const CompassHeader: React.FunctionComponent<CompassHeaderProps>;
//# sourceMappingURL=CompassHeader.d.ts.map