import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiLaptopIconConfig: {
  name: 'RhUiLaptopIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M31 27a1 1 0 0 1-1 1H2a1 1 0 1 1 0-2h28a1 1 0 0 1 1 1ZM4.5 23h23c.827 0 1.5-.673 1.5-1.5v-16c0-.827-.673-1.5-1.5-1.5H22a1 1 0 1 0 0 2h5v15H5V6h5a1 1 0 1 0 0-2H4.5C3.673 4 3 4.673 3 5.5v16c0 .827.673 1.5 1.5 1.5ZM16.005 6.638a1.625 1.625 0 1 0 0-3.25 1.625 1.625 0 0 0 0 3.25Z"},
  rhUiIcon: null,
};
export declare const RhUiLaptopIcon: ComponentClass<SVGIconProps>;
export default RhUiLaptopIcon;