import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const BandcampIconConfig: {
  name: 'BandcampIcon',
  icon: {"xOffset":0,"yOffset":0,"width":512,"height":512,"svgPathData":"M256,8C119,8,8,119,8,256S119,504,256,504,504,393,504,256,393,8,256,8Zm48.2,326.1h-181L207.9,178h181Z"},
  rhUiIcon: null,
};
export declare const BandcampIcon: ComponentClass<SVGIconProps>;
export default BandcampIcon;