import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiAddSquareIconConfig: {
  name: 'RhUiAddSquareIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M28.5 2h-25C2.673 2 2 2.673 2 3.5v25c0 .827.673 1.5 1.5 1.5h25c.827 0 1.5-.673 1.5-1.5v-25c0-.827-.673-1.5-1.5-1.5ZM28 28H4V4h24v24ZM8 16a1 1 0 0 1 1-1h6V9a1 1 0 1 1 2 0v6h6a1 1 0 1 1 0 2h-6v6a1 1 0 1 1-2 0v-6H9a1 1 0 0 1-1-1Z"},
  rhUiIcon: null,
};
export declare const RhUiAddSquareIcon: ComponentClass<SVGIconProps>;
export default RhUiAddSquareIcon;