import { createIconBase } from '../createIcon.js';

export const RhStandardServerIconConfig = {
  name: 'RhStandardServerIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M27 18.62a.62.62 0 1 0-.62-.62.61.61 0 0 0 .62.62Z"},{"path":"M31 12.38H5a.61.61 0 0 0-.62.62v10a.61.61 0 0 0 .62.62h26a.61.61 0 0 0 .62-.62V13a.61.61 0 0 0-.62-.62Zm-.62 10H5.62v-8.76h24.76Z"},{"path":"M9 18.62h6a.62.62 0 0 0 0-1.24H9a.62.62 0 0 0 0 1.24Z"}]},
  rhUiIcon: null,
};

export const RhStandardServerIcon = createIconBase(RhStandardServerIconConfig);

export default RhStandardServerIcon;