import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiHarveyBall60IconConfig: {
  name: 'RhUiHarveyBall60Icon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16a15.03 15.03 0 0 0 6.18 12.128A14.842 14.842 0 0 0 16 31c8.271 0 15-6.729 15-15S24.271 1 16 1ZM3 16C3 9.168 8.297 3.551 15 3.038v12.637L7.571 25.893A13.03 13.03 0 0 1 3 16Z"},
  rhUiIcon: null,
};
export declare const RhUiHarveyBall60Icon: ComponentClass<SVGIconProps>;
export default RhUiHarveyBall60Icon;