import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardHarveyBall75IconConfig: {
  name: 'RhStandardHarveyBall75Icon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M18 3.375A14.625 14.625 0 1 0 32.625 18 14.642 14.642 0 0 0 18 3.375Zm-.625 1.282v12.718H4.657A13.37 13.37 0 0 1 17.375 4.657Z"},
  rhUiIcon: null,
};
export declare const RhStandardHarveyBall75Icon: ComponentClass<SVGIconProps>;
export default RhStandardHarveyBall75Icon;