/// <reference types="react" />
export interface CardSubtitleProps {
    /** Content rendered inside the description. */
    children?: React.ReactNode;
    /** Id of the description. */
    id?: string;
}
export declare const CardSubtitle: React.FunctionComponent<CardSubtitleProps>;
//# sourceMappingURL=CardSubtitle.d.ts.map