import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const CircleIconConfig: {
  name: 'CircleIcon',
  icon: {"xOffset":0,"yOffset":0,"width":512,"height":512,"svgPathData":"M256 8C119 8 8 119 8 256s111 248 248 248 248-111 248-248S393 8 256 8z"},
  rhUiIcon: null,
};
export declare const CircleIcon: ComponentClass<SVGIconProps>;
export default CircleIcon;