import { createIconBase } from '../createIcon.js';

export const RhStandardThoughtBubbleIconConfig = {
  name: 'RhStandardThoughtBubbleIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M18 3.38C6.76 3.23-.46 16.09 5.51 25.6l-1.12 5.27a.76.76 0 0 0 .08.47.66.66 0 0 0 .66.27l5.27-1.12c9.51 6 22.37-1.25 22.22-12.49A14.64 14.64 0 0 0 18 3.38Zm0 28a13.38 13.38 0 0 1-7.15-2.07.7.7 0 0 0-.49-.09l-4.55 1 1-4.57a.59.59 0 0 0-.09-.47A13.38 13.38 0 0 1 18 4.62c17.74.74 17.74 26.02 0 26.76Z"},
  rhUiIcon: null,
};

export const RhStandardThoughtBubbleIcon = createIconBase(RhStandardThoughtBubbleIconConfig);

export default RhStandardThoughtBubbleIcon;