import { createIconBase } from '../createIcon.js';

export const RhUiAddIconConfig = {
  name: 'RhUiAddIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29 15H17V3a1 1 0 0 0-2 0v12H3a1 1 0 0 0 0 2h12v12a1 1 0 0 0 2 0V17h12a1 1 0 0 0 0-2Z"},
  rhUiIcon: null,
};

export const RhUiAddIcon = createIconBase(RhUiAddIconConfig);

export default RhUiAddIcon;