import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
import styles from '@patternfly/react-styles/css/components/Login/login.mjs';
import { css } from '@patternfly/react-styles';
export const LoginMainFooterBandItem = (_a) => {
    var { children = null, className = '' } = _a, props = __rest(_a, ["children", "className"]);
    return (_jsx("p", Object.assign({ className: css(`${styles.loginMainFooterBand}-item`, className) }, props, { children: children })));
};
LoginMainFooterBandItem.displayName = 'LoginMainFooterBandItem';
//# sourceMappingURL=LoginMainFooterBandItem.js.map