import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardUserIconConfig: {
  name: 'RhStandardUserIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M21.32 17.8C27.8 14.41 25.42 4.39 18 4.38s-9.8 10-3.32 13.42A13.63 13.63 0 0 0 4.38 31a.61.61 0 0 0 .62.62h26a.61.61 0 0 0 .62-.62 13.63 13.63 0 0 0-10.3-13.2Zm-9.2-6.3c.25-7.76 11.51-7.76 11.76 0-.25 7.76-11.51 7.76-11.76 0ZM5.64 30.38c1.36-15.59 23.41-15.58 24.72 0Z"},
  rhUiIcon: null,
};
export declare const RhStandardUserIcon: ComponentClass<SVGIconProps>;
export default RhStandardUserIcon;