import { createIconBase } from '../createIcon.js';

export const RhUiArrowUpRightDownLeftFromCenterIconConfig = {
  name: 'RhUiArrowUpRightDownLeftFromCenterIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30 3.5V10a1 1 0 1 1-2 0V5.414l-8.293 8.293a.997.997 0 0 1-1.414 0 .999.999 0 0 1 0-1.414L26.586 4H22a1 1 0 1 1 0-2h6.5c.827 0 1.5.673 1.5 1.5ZM12.293 18.293 4 26.586V22a1 1 0 1 0-2 0v6.5c0 .827.673 1.5 1.5 1.5H10a1 1 0 1 0 0-2H5.414l8.293-8.293a.999.999 0 1 0-1.414-1.414Z"},
  rhUiIcon: null,
};

export const RhUiArrowUpRightDownLeftFromCenterIcon = createIconBase(RhUiArrowUpRightDownLeftFromCenterIconConfig);

export default RhUiArrowUpRightDownLeftFromCenterIcon;