
// Do not edit directly
// Generated on Tue, 23 Jun 2026 19:20:00 GMT

// Only tokens that differ from base theme (122 tokens)
@mixin pf-v6-tokens {
  --pf-t--global--border--color--nonstatus--green--default: var(--pf-t--global--color--nonstatus--green--400);
  --pf-t--global--border--color--status--success--default: var(--pf-t--global--color--status--success--150);
  --pf-t--global--border--width--action--plain--clicked: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--action--plain--hover: var(--pf-t--global--border--width--100);
  --pf-t--global--border--width--control--hover: var(--pf-t--global--border--width--200);
  --pf-t--global--border--width--main--default: var(--pf-t--global--border--width--200);
  --pf-t--global--border--color--brand--accent--clicked: var(--pf-t--global--color--brand--accent--400);
  --pf-t--global--border--color--brand--accent--default: var(--pf-t--global--color--brand--accent--400);
  --pf-t--global--border--color--brand--accent--hover: var(--pf-t--global--color--brand--accent--400);
  --pf-t--global--border--color--brand--subtle--clicked: var(--pf-t--global--color--brand--subtle--400);
  --pf-t--global--border--color--brand--subtle--hover: var(--pf-t--global--color--brand--subtle--400);
  --pf-t--global--border--color--clicked: var(--pf-t--global--color--brand--400);
  --pf-t--global--border--color--control--default: var(--pf-t--global--border--color--400);
  --pf-t--global--border--color--default: var(--pf-t--global--border--color--400);
  --pf-t--global--border--color--hover: var(--pf-t--global--color--brand--300);
  --pf-t--global--border--color--nonstatus--blue--clicked: var(--pf-t--global--color--nonstatus--blue--500);
  --pf-t--global--border--color--nonstatus--blue--default: var(--pf-t--global--color--nonstatus--blue--400);
  --pf-t--global--border--color--nonstatus--blue--hover: var(--pf-t--global--color--nonstatus--blue--500);
  --pf-t--global--border--color--nonstatus--gray--clicked: var(--pf-t--global--color--nonstatus--gray--500);
  --pf-t--global--border--color--nonstatus--gray--default: var(--pf-t--global--color--nonstatus--gray--400);
  --pf-t--global--border--color--nonstatus--gray--hover: var(--pf-t--global--color--nonstatus--gray--500);
  --pf-t--global--border--color--nonstatus--green--clicked: var(--pf-t--global--color--nonstatus--green--500);
  --pf-t--global--border--color--nonstatus--green--hover: var(--pf-t--global--color--nonstatus--green--500);
  --pf-t--global--border--color--nonstatus--orange--clicked: var(--pf-t--global--color--nonstatus--orange--500);
  --pf-t--global--border--color--nonstatus--orange--default: var(--pf-t--global--color--nonstatus--orange--400);
  --pf-t--global--border--color--nonstatus--orange--hover: var(--pf-t--global--color--nonstatus--orange--500);
  --pf-t--global--border--color--nonstatus--orangered--clicked: var(--pf-t--global--color--nonstatus--orangered--500);
  --pf-t--global--border--color--nonstatus--orangered--default: var(--pf-t--global--color--nonstatus--orangered--400);
  --pf-t--global--border--color--nonstatus--orangered--hover: var(--pf-t--global--color--nonstatus--orangered--500);
  --pf-t--global--border--color--nonstatus--purple--clicked: var(--pf-t--global--color--nonstatus--purple--500);
  --pf-t--global--border--color--nonstatus--purple--default: var(--pf-t--global--color--nonstatus--purple--400);
  --pf-t--global--border--color--nonstatus--purple--hover: var(--pf-t--global--color--nonstatus--purple--500);
  --pf-t--global--border--color--nonstatus--red--clicked: var(--pf-t--global--color--nonstatus--red--500);
  --pf-t--global--border--color--nonstatus--red--default: var(--pf-t--global--color--nonstatus--red--400);
  --pf-t--global--border--color--nonstatus--red--hover: var(--pf-t--global--color--nonstatus--red--500);
  --pf-t--global--border--color--nonstatus--teal--clicked: var(--pf-t--global--color--nonstatus--teal--500);
  --pf-t--global--border--color--nonstatus--teal--default: var(--pf-t--global--color--nonstatus--teal--400);
  --pf-t--global--border--color--nonstatus--teal--hover: var(--pf-t--global--color--nonstatus--teal--500);
  --pf-t--global--border--color--nonstatus--yellow--clicked: var(--pf-t--global--color--nonstatus--yellow--500);
  --pf-t--global--border--color--nonstatus--yellow--default: var(--pf-t--global--color--nonstatus--yellow--400);
  --pf-t--global--border--color--nonstatus--yellow--hover: var(--pf-t--global--color--nonstatus--yellow--500);
  --pf-t--global--border--color--on-secondary: var(--pf-t--global--border--color--400);
  --pf-t--global--border--color--status--success--clicked: var(--pf-t--global--color--status--success--200);
  --pf-t--global--border--color--status--success--hover: var(--pf-t--global--color--status--success--200);
  --pf-t--global--border--color--status--warning--clicked: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--border--color--status--warning--default: var(--pf-t--global--color--status--warning--500);
  --pf-t--global--border--color--status--warning--hover: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--border--color--subtle: var(--pf-t--global--border--color--400);
  --pf-t--global--border--radius--action--plain--default: var(--pf-t--global--border--radius--pill);
  --pf-t--global--border--radius--control--default: var(--pf-t--global--border--radius--pill);
  --pf-t--global--border--width--high-contrast--extra-strong: var(--pf-t--global--border--width--extra-strong);
  --pf-t--global--border--width--high-contrast--regular: var(--pf-t--global--border--width--regular);
  --pf-t--global--border--width--high-contrast--strong: var(--pf-t--global--border--width--strong);
  --pf-t--global--color--brand--accent--clicked: var(--pf-t--global--color--brand--accent--300);
  --pf-t--global--color--brand--accent--default: var(--pf-t--global--color--brand--accent--400);
  --pf-t--global--color--brand--accent--hover: var(--pf-t--global--color--brand--accent--300);
  --pf-t--global--color--brand--clicked: var(--pf-t--global--color--brand--400);
  --pf-t--global--color--brand--default: var(--pf-t--global--color--brand--300);
  --pf-t--global--color--brand--hover: var(--pf-t--global--color--brand--400);
  --pf-t--global--color--favorite--clicked: var(--pf-t--global--color--favorite--400);
  --pf-t--global--color--favorite--default: var(--pf-t--global--color--favorite--300);
  --pf-t--global--color--favorite--hover: var(--pf-t--global--color--favorite--400);
  --pf-t--global--color--nonstatus--gray--clicked: var(--pf-t--global--color--nonstatus--gray--100);
  --pf-t--global--color--nonstatus--gray--default: var(--pf-t--global--color--nonstatus--gray--50);
  --pf-t--global--color--nonstatus--gray--hover: var(--pf-t--global--color--nonstatus--gray--100);
  --pf-t--global--color--status--custom--clicked: var(--pf-t--global--color--status--custom--300);
  --pf-t--global--color--status--custom--default: var(--pf-t--global--color--status--custom--200);
  --pf-t--global--color--status--custom--hover: var(--pf-t--global--color--status--custom--300);
  --pf-t--global--color--status--danger--clicked: var(--pf-t--global--color--status--danger--300);
  --pf-t--global--color--status--danger--default: var(--pf-t--global--color--status--danger--200);
  --pf-t--global--color--status--danger--hover: var(--pf-t--global--color--status--danger--300);
  --pf-t--global--color--status--info--clicked: var(--pf-t--global--color--status--info--300);
  --pf-t--global--color--status--info--default: var(--pf-t--global--color--status--info--200);
  --pf-t--global--color--status--info--hover: var(--pf-t--global--color--status--info--300);
  --pf-t--global--color--status--success--clicked: var(--pf-t--global--color--status--success--300);
  --pf-t--global--color--status--success--default: var(--pf-t--global--color--status--success--200);
  --pf-t--global--color--status--success--hover: var(--pf-t--global--color--status--success--300);
  --pf-t--global--color--status--warning--clicked: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--color--status--warning--default: var(--pf-t--global--color--status--warning--500);
  --pf-t--global--color--status--warning--hover: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--focus-ring--color--default: var(--pf-t--global--focus-ring--color--200);
  --pf-t--global--icon--color--brand--clicked: var(--pf-t--global--color--brand--400);
  --pf-t--global--icon--color--brand--default: var(--pf-t--global--color--brand--300);
  --pf-t--global--icon--color--brand--hover: var(--pf-t--global--color--brand--400);
  --pf-t--global--icon--color--severity--important--default: var(--pf-t--global--color--severity--important--200);
  --pf-t--global--icon--color--severity--minor--default: var(--pf-t--global--color--severity--minor--200);
  --pf-t--global--icon--color--severity--moderate--default: var(--pf-t--global--color--severity--moderate--200);
  --pf-t--global--icon--color--severity--none--default: var(--pf-t--global--color--severity--none--200);
  --pf-t--global--icon--color--severity--undefined--default: var(--pf-t--global--color--severity--undefined--200);
  --pf-t--global--icon--color--status--danger--clicked: var(--pf-t--global--color--status--danger--200);
  --pf-t--global--icon--color--status--danger--default: var(--pf-t--global--color--status--danger--100);
  --pf-t--global--icon--color--status--danger--hover: var(--pf-t--global--color--status--danger--200);
  --pf-t--global--icon--color--status--warning--clicked: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--icon--color--status--warning--default: var(--pf-t--global--color--status--warning--500);
  --pf-t--global--icon--color--status--warning--hover: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--icon--color--subtle: var(--pf-t--global--icon--color--150);
  --pf-t--global--text--color--brand--clicked: var(--pf-t--global--color--brand--500);
  --pf-t--global--text--color--brand--default: var(--pf-t--global--color--brand--400);
  --pf-t--global--text--color--brand--hover: var(--pf-t--global--color--brand--500);
  --pf-t--global--text--color--link--default: var(--pf-t--global--text--color--link--200);
  --pf-t--global--text--color--link--hover: var(--pf-t--global--text--color--link--250);
  --pf-t--global--text--color--link--visited: var(--pf-t--global--text--color--link--350);
  --pf-t--global--text--color--required: var(--pf-t--global--text--color--500);
  --pf-t--global--text--color--status--success--clicked: var(--pf-t--global--color--status--success--300);
  --pf-t--global--text--color--status--success--default: var(--pf-t--global--color--status--success--200);
  --pf-t--global--text--color--status--success--hover: var(--pf-t--global--color--status--success--300);
  --pf-t--global--text--color--status--warning--clicked: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--text--color--status--warning--default: var(--pf-t--global--color--status--warning--500);
  --pf-t--global--text--color--status--warning--hover: var(--pf-t--global--color--status--warning--600);
  --pf-t--global--text--color--subtle: var(--pf-t--global--text--color--250);
  --pf-t--global--text-decoration--color--default: var(--pf-t--global--border--color--400);
  --pf-t--global--text-decoration--width--hover: var(--pf-t--global--border--width--strong);
  --pf-t--global--background--color--action--plain--alt--clicked: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--background--color--action--plain--alt--hover: var(--pf-t--global--background--color--primary--default);
  --pf-t--global--border--color--high-contrast: var(--pf-t--global--border--color--default);
  --pf-t--global--border--color--main--default: var(--pf-t--global--border--color--default);
  --pf-t--global--icon--color--status--on-warning--clicked: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--default: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--icon--color--status--on-warning--hover: var(--pf-t--global--icon--color--inverse);
  --pf-t--global--text--color--status--on-warning--clicked: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--default: var(--pf-t--global--text--color--inverse);
  --pf-t--global--text--color--status--on-warning--hover: var(--pf-t--global--text--color--inverse);
}
