import { createIconBase } from '../createIcon.js';

export const HouzzIconConfig = {
  name: 'HouzzIcon',
  icon: {"xOffset":0,"yOffset":0,"width":448,"height":512,"svgPathData":"M275.9 330.7H171.3V480H17V32h109.5v104.5l305.1 85.6V480H275.9z"},
  rhUiIcon: null,
};

export const HouzzIcon = createIconBase(HouzzIconConfig);

export default HouzzIcon;