import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const LocationArrowIconConfig: {
  name: 'LocationArrowIcon',
  icon: {"xOffset":0,"yOffset":0,"width":512,"height":512,"svgPathData":"M444.52 3.52L28.74 195.42c-47.97 22.39-31.98 92.75 19.19 92.75h175.91v175.91c0 51.17 70.36 67.17 92.75 19.19l191.9-415.78c15.99-38.39-25.59-79.97-63.97-63.97z"},
  rhUiIcon: null,
};
export declare const LocationArrowIcon: ComponentClass<SVGIconProps>;
export default LocationArrowIcon;