import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardCheckboxIndeterminateIconConfig: {
  name: 'RhStandardCheckboxIndeterminateIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M31 4.375H5A.625.625 0 0 0 4.375 5v26a.625.625 0 0 0 .625.625h26a.625.625 0 0 0 .625-.625V5A.625.625 0 0 0 31 4.375Zm-.625 26H5.625V5.625h24.75Z"},{"path":"M10 18.625h16a.625.625 0 0 0 0-1.25H10a.625.625 0 0 0 0 1.25Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardCheckboxIndeterminateIcon: ComponentClass<SVGIconProps>;
export default RhStandardCheckboxIndeterminateIcon;