import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiPlatformFillIconConfig: {
  name: 'RhUiPlatformFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M1.039 13.083c0-.357.19-.688.5-.866l14-8.083a.998.998 0 0 1 1 0l14 8.083a1 1 0 0 1 0 1.732l-14 8.083a1.003 1.003 0 0 1-1 0l-14-8.083a1 1 0 0 1-.5-.866Zm28.5 4.977-13.5 7.794-13.5-7.794a1 1 0 0 0-1 1.732l14 8.083a1.003 1.003 0 0 0 1 0l14-8.083a1 1 0 1 0-1-1.732Z"},
  rhUiIcon: null,
};
export declare const RhUiPlatformFillIcon: ComponentClass<SVGIconProps>;
export default RhUiPlatformFillIcon;