import { createIconBase } from '../createIcon.js';

export const RhUiResourcesEmptyIconConfig = {
  name: 'RhUiResourcesEmptyIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 31C7.729 31 1 24.271 1 16S7.729 1 16 1s15 6.729 15 15-6.729 15-15 15Zm0-28C8.832 3 3 8.832 3 16s5.832 13 13 13 13-5.832 13-13S23.168 3 16 3Z"},
  rhUiIcon: null,
};

export const RhUiResourcesEmptyIcon = createIconBase(RhUiResourcesEmptyIconConfig);

export default RhUiResourcesEmptyIcon;