import { createIconBase } from '../createIcon.js';

export const RhUiCaretRightIconConfig = {
  name: 'RhUiCaretRightIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M11 30a.999.999 0 0 1-.707-1.707L22.586 16 10.293 3.707a.999.999 0 1 1 1.414-1.414l12.646 12.646a1.501 1.501 0 0 1 0 2.121L11.707 29.706a.997.997 0 0 1-.707.293Z"},
  rhUiIcon: null,
};

export const RhUiCaretRightIcon = createIconBase(RhUiCaretRightIconConfig);

export default RhUiCaretRightIcon;