import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardEnvelopeManillaIconConfig: {
  name: 'RhStandardEnvelopeManillaIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M27 4.38H9a.62.62 0 0 0-.62.62v26a.64.64 0 0 0 .62.63h18a.62.62 0 0 0 .62-.62V5a.62.62 0 0 0-.62-.62Zm-15 23a.6.6 0 0 0-.44.18l-1.94 1.93V11.72a3.6 3.6 0 0 0 2.38.9h5.38v14.76Zm.26 1.24h11.48l1.75 1.76h-15Zm12.18-1.06a.6.6 0 0 0-.44-.18h-5.38V12.62H24a3.6 3.6 0 0 0 2.38-.9v17.77ZM26.38 9A2.39 2.39 0 0 1 24 11.38H12A2.39 2.39 0 0 1 9.62 9V5.62h16.76Z"},{"path":"M16 9.62h4a.62.62 0 0 0 0-1.24h-4a.62.62 0 0 0 0 1.24Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardEnvelopeManillaIcon: ComponentClass<SVGIconProps>;
export default RhStandardEnvelopeManillaIcon;