import { Flex, FlexItem } from '@patternfly/react-core';

export const FlexAlternative: React.FunctionComponent = () => (
  <Flex component="ul">
    <FlexItem component="li">Flex item</FlexItem>
    <FlexItem component="li">Flex item</FlexItem>
    <FlexItem component="li">Flex item</FlexItem>
    <FlexItem component="li">Flex item</FlexItem>
    <FlexItem component="li">Flex item</FlexItem>
  </Flex>
);
