import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiHarveyBallUpper50IconConfig: {
  name: 'RhUiHarveyBallUpper50Icon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm0 28C9.17 29 3.565 23.701 3.051 17H28.95c-.514 6.701-6.119 12-12.949 12Z"},
  rhUiIcon: null,
};
export declare const RhUiHarveyBallUpper50Icon: ComponentClass<SVGIconProps>;
export default RhUiHarveyBallUpper50Icon;