import { createIconBase } from '../createIcon.js';

export const RhMicronsCaretUpFillIconConfig = {
  name: 'RhMicronsCaretUpFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M17.938 12.347A1 1 0 0 1 17 13H3a1 1 0 0 1-.65-1.76l6.674-5.72a1.492 1.492 0 0 1 1.954.001l6.673 5.72a1 1 0 0 1 .287 1.106Z"},
  rhUiIcon: null,
};

export const RhMicronsCaretUpFillIcon = createIconBase(RhMicronsCaretUpFillIconConfig);

export default RhMicronsCaretUpFillIcon;