import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsCaretDownFillIconConfig: {
  name: 'RhMicronsCaretDownFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"m17.65 8.76-6.674 5.72a1.496 1.496 0 0 1-.976.365c-.347 0-.694-.122-.978-.366l-6.673-5.72A1 1 0 0 1 3 7h14a1 1 0 0 1 .65 1.76Z"},
  rhUiIcon: null,
};
export declare const RhMicronsCaretDownFillIcon: ComponentClass<SVGIconProps>;
export default RhMicronsCaretDownFillIcon;