import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiModuleFillIconConfig: {
  name: 'RhUiModuleFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29.5 17.876v7.505a.5.5 0 0 1-.25.433l-6.5 3.753a.496.496 0 0 1-.5 0L16 25.958l-6.25 3.609a.496.496 0 0 1-.5 0l-6.5-3.753a.5.5 0 0 1-.25-.433v-7.505a.5.5 0 0 1 .25-.433L9 13.834V6.618a.5.5 0 0 1 .25-.433l6.5-3.753a.497.497 0 0 1 .5 0l6.5 3.753a.5.5 0 0 1 .25.433v7.216l6.25 3.609a.5.5 0 0 1 .25.433Z"},
  rhUiIcon: null,
};
export declare const RhUiModuleFillIcon: ComponentClass<SVGIconProps>;
export default RhUiModuleFillIcon;