import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiPanelCloseFillIconConfig: {
  name: 'RhUiPanelCloseFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30 3.5v25c0 .827-.673 1.5-1.5 1.5h-4c-.827 0-1.5-.673-1.5-1.5v-25c0-.827.673-1.5 1.5-1.5h4c.827 0 1.5.673 1.5 1.5ZM19 15H5.414l5.293-5.293a.999.999 0 1 0-1.414-1.414l-6.646 6.646a1.501 1.501 0 0 0 0 2.121l6.646 6.646a.997.997 0 0 0 1.414 0 .999.999 0 0 0 0-1.414l-5.293-5.293H19a1 1 0 1 0 0-2Z"},
  rhUiIcon: null,
};
export declare const RhUiPanelCloseFillIcon: ComponentClass<SVGIconProps>;
export default RhUiPanelCloseFillIcon;