import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiApplicationFillIconConfig: {
  name: 'RhUiApplicationFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M28.5 2h-25C2.673 2 2 2.673 2 3.5v25c0 .827.673 1.5 1.5 1.5h25c.827 0 1.5-.673 1.5-1.5v-25c0-.827-.673-1.5-1.5-1.5ZM17.005 9.873a1.874 1.874 0 1 1-.001-3.749 1.874 1.874 0 0 1 .001 3.749Zm7 0a1.874 1.874 0 1 1-.001-3.749 1.874 1.874 0 0 1 .001 3.749Z"},
  rhUiIcon: null,
};
export declare const RhUiApplicationFillIcon: ComponentClass<SVGIconProps>;
export default RhUiApplicationFillIcon;