import { createIconBase } from '../createIcon.js';

export const GenderlessIconConfig = {
  name: 'GenderlessIcon',
  icon: {"xOffset":0,"yOffset":0,"width":288,"height":512,"svgPathData":"M144 176c44.1 0 80 35.9 80 80s-35.9 80-80 80-80-35.9-80-80 35.9-80 80-80m0-64C64.5 112 0 176.5 0 256s64.5 144 144 144 144-64.5 144-144-64.5-144-144-144z"},
  rhUiIcon: null,
};

export const GenderlessIcon = createIconBase(GenderlessIconConfig);

export default GenderlessIcon;