import { createIconBase } from '../createIcon.js';

export const RhMicronsSwapUpDownIconConfig = {
  name: 'RhMicronsSwapUpDownIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M13.939 1.646c.283-.283.66-.44 1.06-.44s.778.157 1.061.44l2.646 2.646A1 1 0 0 1 18 6h-2v12a1 1 0 1 1-2 0V6h-2a1 1 0 0 1-.707-1.707l2.647-2.646Zm-5.233 14.06A1 1 0 0 0 8 14H6V2a1 1 0 1 0-2 0v12H2a1 1 0 0 0-.707 1.707l2.647 2.647c.283.283.66.44 1.06.44s.778-.157 1.061-.44l2.646-2.647Z"},
  rhUiIcon: null,
};

export const RhMicronsSwapUpDownIcon = createIconBase(RhMicronsSwapUpDownIconConfig);

export default RhMicronsSwapUpDownIcon;