import { createIconBase } from '../createIcon.js';

export const RhStandardPowerIconConfig = {
  name: 'RhStandardPowerIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M18 20.625a.625.625 0 0 0 .625-.625V4a.625.625 0 0 0-1.25 0v16a.625.625 0 0 0 .625.625Z"},{"path":"M27.635 9.366a13.643 13.643 0 0 0-1.711-1.433.625.625 0 1 0-.724 1.015 12.46 12.46 0 1 1-14.39 0 .625.625 0 1 0-.729-1.015 13.614 13.614 0 1 0 17.554 1.433Z"}]},
  rhUiIcon: null,
};

export const RhStandardPowerIcon = createIconBase(RhStandardPowerIconConfig);

export default RhStandardPowerIcon;