import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardCeoBusinessleaderIconConfig: {
  name: 'RhStandardCeoBusinessleaderIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M31 9.38h-6.48l-.75-3.51a.62.62 0 0 0-.61-.49H12.84a.62.62 0 0 0-.61.49l-.75 3.51H5a.61.61 0 0 0-.62.62v20a.61.61 0 0 0 .62.62h26a.61.61 0 0 0 .62-.62V10a.61.61 0 0 0-.62-.62ZM13.35 6.62h9.3l.59 2.76H12.76Zm17 22.76H5.62V10.62h24.76Z"},{"path":"M28 8.62h2a.62.62 0 1 0 0-1.24h-2a.62.62 0 0 0 0 1.24Zm-22 0h2a.62.62 0 0 0 0-1.24H6a.62.62 0 1 0 0 1.24Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardCeoBusinessleaderIcon: ComponentClass<SVGIconProps>;
export default RhStandardCeoBusinessleaderIcon;