import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsSortUpLargeToSmallIconConfig: {
  name: 'RhMicronsSortUpLargeToSmallIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M18 16h-8a1 1 0 1 0 0 2h8a1 1 0 1 0 0-2Zm-8-2h5a1 1 0 1 0 0-2h-5a1 1 0 1 0 0 2Zm0-4h2a1 1 0 1 0 0-2h-2a1 1 0 1 0 0 2ZM6.06 1.646a1.5 1.5 0 0 0-2.12 0L1.292 4.293A1 1 0 0 0 2 6h2v12a1 1 0 1 0 2 0V6h2a1 1 0 0 0 .707-1.707L6.061 1.646Z"},
  rhUiIcon: null,
};
export declare const RhMicronsSortUpLargeToSmallIcon: ComponentClass<SVGIconProps>;
export default RhMicronsSortUpLargeToSmallIcon;