import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiSecurityIconConfig: {
  name: 'RhUiSecurityIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 31C8.832 31 3 25.168 3 18V4.56a1 1 0 0 1 .792-.978l12-2.56a1.01 1.01 0 0 1 .417 0l12 2.56c.461.099.792.506.792.978V18c0 7.168-5.832 13-13 13ZM5 5.369V18c0 6.065 4.935 11 11 11s11-4.935 11-11V5.369L16 3.022 5 5.369Z"},
  rhUiIcon: null,
};
export declare const RhUiSecurityIcon: ComponentClass<SVGIconProps>;
export default RhUiSecurityIcon;