import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardPlatformIconConfig: {
  name: 'RhStandardPlatformIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"m4.7 15.55 13 7.22a.6.6 0 0 0 .6 0l13-7.22a.63.63 0 0 0 0-1.1l-13-7.22a.64.64 0 0 0-.6 0l-13 7.22a.63.63 0 0 0 0 1.1ZM18 8.49 29.71 15 18 21.51 6.29 15Z"},{"path":"M30.7 20.23 18 27.29 5.3 20.23a.62.62 0 1 0-.6 1.09l13 7.23a.68.68 0 0 0 .6 0l13-7.23a.62.62 0 1 0-.6-1.09Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardPlatformIcon: ComponentClass<SVGIconProps>;
export default RhStandardPlatformIcon;