import { createIconBase } from '../createIcon.js';

export const RhUiCardPaymentIconConfig = {
  name: 'RhUiCardPaymentIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29.5 6h-27C1.673 6 1 6.673 1 7.5v17c0 .827.673 1.5 1.5 1.5h27c.827 0 1.5-.673 1.5-1.5v-17c0-.827-.673-1.5-1.5-1.5ZM29 24H3v-9h26v9Zm0-13H3V8h26v3ZM6 20a1 1 0 0 1 1-1h9a1 1 0 0 1 0 2H7a1 1 0 0 1-1-1Z"},
  rhUiIcon: null,
};

export const RhUiCardPaymentIcon = createIconBase(RhUiCardPaymentIconConfig);

export default RhUiCardPaymentIcon;