import { createIconBase } from '../createIcon.js';

export const RhUiMenuBarsIconConfig = {
  name: 'RhUiMenuBarsIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M31 16a1 1 0 0 1-1 1H2a1 1 0 1 1 0-2h28a1 1 0 0 1 1 1Zm-1 9H2a1 1 0 1 0 0 2h28a1 1 0 1 0 0-2ZM2 7h28a1 1 0 1 0 0-2H2a1 1 0 1 0 0 2Z"},
  rhUiIcon: null,
};

export const RhUiMenuBarsIcon = createIconBase(RhUiMenuBarsIconConfig);

export default RhUiMenuBarsIcon;