import { createIconBase } from '../createIcon.js';

export const RhUiFolderFillIconConfig = {
  name: 'RhUiFolderFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M31 9.5v17c0 .827-.673 1.5-1.5 1.5h-27c-.827 0-1.5-.673-1.5-1.5v-17C1 8.673 1.673 8 2.5 8h2.69l.681-3.208A1 1 0 0 1 6.85 4h9.301a1 1 0 0 1 .979.792L17.811 8h11.69c.827 0 1.5.673 1.5 1.5Z"},
  rhUiIcon: null,
};

export const RhUiFolderFillIcon = createIconBase(RhUiFolderFillIconConfig);

export default RhUiFolderFillIcon;