import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsCheckboxCompleteFillIconConfig: {
  name: 'RhMicronsCheckboxCompleteFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M17.5 1h-15C1.67 1 1 1.67 1 2.5v15c0 .83.67 1.5 1.5 1.5h15c.83 0 1.5-.67 1.5-1.5v-15c0-.83-.67-1.5-1.5-1.5Zm-1.7 6.8-5.65 5.65c-.32.32-.73.47-1.15.47s-.83-.16-1.15-.47L5.2 10.8c-.43-.45-.41-1.16.04-1.59.44-.42 1.12-.42 1.56 0L9 11.42l5.2-5.2c.45-.43 1.16-.41 1.59.04.42.44.42 1.12 0 1.56Z"},
  rhUiIcon: null,
};
export declare const RhMicronsCheckboxCompleteFillIcon: ComponentClass<SVGIconProps>;
export default RhMicronsCheckboxCompleteFillIcon;