import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardMountainsIconConfig: {
  name: 'RhStandardMountainsIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"m32.54 28.88-6-10.62a.64.64 0 0 0-1.08 0l-.81 1.44-7.46-13.2a.65.65 0 0 0-1.09 0L3.46 28.88a.62.62 0 0 0 .54.93h28a.62.62 0 0 0 .54-.93ZM16.65 8.08l2.93 5.2-1.13 1.13c-2.06-2.06-1.55-2.05-3.61 0l-1.13-1.13Zm12.64 20.48H5.07l8-14.15c2 2.07 1.55 1.95 3.58 0 2 2 1.52 2.1 3.57 0L23.93 21l-2.11 3.72a.63.63 0 0 0 1.09.62l3.09-5.5 4.93 8.72Z"},
  rhUiIcon: null,
};
export declare const RhStandardMountainsIcon: ComponentClass<SVGIconProps>;
export default RhStandardMountainsIcon;