/**
 * Minimum google.protobuf.Timestamp in milliseconds (inclusive).
 * Only enforced in ProtoJSON.
 *
 * @private
 */
export declare const timestampMsMin: number;
/**
 * Maximum google.protobuf.Timestamp in milliseconds (inclusive).
 * Only enforced in ProtoJSON.
 *
 * @private
 */
export declare const timestampMsMax: number;
/**
 * Minimum google.protobuf.Duration in seconds.
 * Only enforced in ProtoJSON.
 *
 * @private
 */
export declare const durationSecondsMin = -315576000000;
/**
 * Maximum google.protobuf.Duration in seconds.
 * Only enforced in ProtoJSON.
 *
 * @private
 */
export declare const durationSecondsMax = 315576000000;
