import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiArrowDownRightIconConfig: {
  name: 'RhUiArrowDownRightIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M28 11v15.5c0 .827-.673 1.5-1.5 1.5H11a1 1 0 1 1 0-2h13.586L4.293 5.707a.999.999 0 1 1 1.414-1.414L26 24.586V11a1 1 0 1 1 2 0Z"},
  rhUiIcon: null,
};
export declare const RhUiArrowDownRightIcon: ComponentClass<SVGIconProps>;
export default RhUiArrowDownRightIcon;