import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsCheckboxIncompleteIconConfig: {
  name: 'RhMicronsCheckboxIncompleteIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M17.5 1h-15C1.67 1 1 1.67 1 2.5v15c0 .83.67 1.5 1.5 1.5h15c.83 0 1.5-.67 1.5-1.5v-15c0-.83-.67-1.5-1.5-1.5ZM17 17H3V3h14v14Z"},
  rhUiIcon: null,
};
export declare const RhMicronsCheckboxIncompleteIcon: ComponentClass<SVGIconProps>;
export default RhMicronsCheckboxIncompleteIcon;