import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardAssignedDeskIconConfig: {
  name: 'RhStandardAssignedDeskIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M31 16.38H20.62v-.76H25a.61.61 0 0 0 .62-.62V5a.61.61 0 0 0-.62-.62H11a.61.61 0 0 0-.62.62v10a.61.61 0 0 0 .62.62h4.38v.76H5a.62.62 0 1 0 0 1.24h.38V31a.62.62 0 0 0 1.24 0V17.62h12.76V28a.61.61 0 0 0 .62.62h9.38V31a.62.62 0 0 0 1.24 0V17.62H31a.62.62 0 0 0 0-1.24Zm-11.62 0h-2.76v-.76h2.76Zm-3.38-2h-4.38V5.62h12.76v8.76H16Zm13.38 13h-8.76v-9.76h8.76Z"},{"path":"M23 22.62h4a.62.62 0 0 0 0-1.24h-4a.62.62 0 0 0 0 1.24Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardAssignedDeskIcon: ComponentClass<SVGIconProps>;
export default RhStandardAssignedDeskIcon;