import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiPlugFillIconConfig: {
  name: 'RhUiPlugFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M24 8.5V15c0 4.072-3.06 7.436-7 7.931V30a1 1 0 1 1-2 0v-7.069c-3.94-.495-7-3.859-7-7.931V8.5C8 7.673 8.673 7 9.5 7H11V2a1 1 0 1 1 2 0v5h6V2a1 1 0 1 1 2 0v5h1.5c.827 0 1.5.673 1.5 1.5Z"},
  rhUiIcon: null,
};
export declare const RhUiPlugFillIcon: ComponentClass<SVGIconProps>;
export default RhUiPlugFillIcon;