import { createIconBase } from '../createIcon.js';

export const RhUiCommentFillIconConfig = {
  name: 'RhUiCommentFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30.875 5.5v16c0 .758-.617 1.375-1.375 1.375H16.362l-6.744 6.744A.875.875 0 0 1 8.124 29v-6.125H2.5A1.377 1.377 0 0 1 1.125 21.5v-16c0-.758.617-1.375 1.375-1.375h27c.758 0 1.375.617 1.375 1.375Z"},
  rhUiIcon: null,
};

export const RhUiCommentFillIcon = createIconBase(RhUiCommentFillIconConfig);

export default RhUiCommentFillIcon;