import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiFoldersFillIconConfig: {
  name: 'RhUiFoldersFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M24.5 24h-22c-.827 0-1.5-.673-1.5-1.5v-14C1 7.673 1.673 7 2.5 7h2.69l.681-3.208A1 1 0 0 1 6.85 3H15a1 1 0 0 1 .979.792L16.66 7h7.841c.827 0 1.5.673 1.5 1.5v14c0 .827-.673 1.5-1.5 1.5ZM30 10a1 1 0 0 0-1 1v16H5a1 1 0 1 0 0 2h24.5c.827 0 1.5-.673 1.5-1.5V11a1 1 0 0 0-1-1Z"},
  rhUiIcon: null,
};
export declare const RhUiFoldersFillIcon: ComponentClass<SVGIconProps>;
export default RhUiFoldersFillIcon;