import { createIconBase } from '../createIcon.js';

export const RhUiCaretLeftFillIconConfig = {
  name: 'RhUiCaretLeftFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M22 3v26a1 1 0 0 1-1.707.707L7.647 17.061a1.501 1.501 0 0 1 0-2.121L20.293 2.293A1 1 0 0 1 22 3Z"},
  rhUiIcon: null,
};

export const RhUiCaretLeftFillIcon = createIconBase(RhUiCaretLeftFillIconConfig);

export default RhUiCaretLeftFillIcon;