import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsInformationFillIconConfig: {
  name: 'RhMicronsInformationFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M10 0C4.486 0 0 4.486 0 10s4.486 10 10 10 10-4.486 10-10S15.514 0 10 0Zm1.375 11.716V15a1.375 1.375 0 1 1-2.75 0v-3.48a1.363 1.363 0 0 1-.97-1.023 1.375 1.375 0 0 1 1.057-1.632l1-.214a1.383 1.383 0 0 1 1.47.645c.095.161.144.333.168.51.031.221.025.45.025.675v1.235Zm-1.37-5.088a1.625 1.625 0 1 1 0-3.25 1.625 1.625 0 0 1 0 3.25Z"},
  rhUiIcon: null,
};
export declare const RhMicronsInformationFillIcon: ComponentClass<SVGIconProps>;
export default RhMicronsInformationFillIcon;