import { createIconBase } from '../createIcon.js';

export const RhUiServerFillIconConfig = {
  name: 'RhUiServerFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29.5 9h-27C1.673 9 1 9.673 1 10.5v11c0 .827.673 1.5 1.5 1.5h27c.827 0 1.5-.673 1.5-1.5v-11c0-.827-.673-1.5-1.5-1.5ZM13 17.125H8a1.125 1.125 0 0 1 0-2.25h5a1.125 1.125 0 0 1 0 2.25Zm10.005.766a1.874 1.874 0 1 1-.001-3.749 1.874 1.874 0 0 1 .001 3.749Z"},
  rhUiIcon: null,
};

export const RhUiServerFillIcon = createIconBase(RhUiServerFillIconConfig);

export default RhUiServerFillIcon;