import { createIconBase } from '../createIcon.js';

export const RhStandardImportIconConfig = {
  name: 'RhStandardImportIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M31 4.375h-4a.625.625 0 1 0 0 1.25h3.375v24.75H27a.625.625 0 0 0 0 1.25h4c.345 0 .625-.28.625-.625V5A.625.625 0 0 0 31 4.375Z"},{"path":"m27.442 17.558-8-8a.625.625 0 1 0-.884.884l6.933 6.933H5a.625.625 0 0 0 0 1.25h20.49l-6.932 6.933a.626.626 0 0 0 .884.884l8-8a.626.626 0 0 0 0-.884Z"}]},
  rhUiIcon: null,
};

export const RhStandardImportIcon = createIconBase(RhStandardImportIconConfig);

export default RhStandardImportIcon;