import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiEthernetFillIconConfig: {
  name: 'RhUiEthernetFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M28.5 2h-25C2.673 2 2 2.673 2 3.5v25c0 .827.673 1.5 1.5 1.5h25c.827 0 1.5-.673 1.5-1.5v-25c0-.827-.673-1.5-1.5-1.5ZM14 5.875h4a1.125 1.125 0 0 1 0 2.25h-4a1.125 1.125 0 0 1 0-2.25ZM25 24a1 1 0 0 1-1 1h-2v-4a1 1 0 0 0-2 0v4h-3v-4a1 1 0 0 0-2 0v4h-3v-4a1 1 0 0 0-2 0v4H8a1 1 0 0 1-1-1v-9.25a1 1 0 0 1 1-1h3V12a1 1 0 0 1 1-1h8a1 1 0 0 1 1 1v1.75h3a1 1 0 0 1 1 1V24Z"},
  rhUiIcon: null,
};
export declare const RhUiEthernetFillIcon: ComponentClass<SVGIconProps>;
export default RhUiEthernetFillIcon;