import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardServerSecuredIconConfig: {
  name: 'RhStandardServerSecuredIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M27 18.62a.62.62 0 1 0-.62-.62.61.61 0 0 0 .62.62Z"},{"path":"M23 22.38H5.62v-8.76h24.76V18a.62.62 0 0 0 1.24 0v-5a.61.61 0 0 0-.62-.62H5a.61.61 0 0 0-.62.62v10a.61.61 0 0 0 .62.62h18a.62.62 0 0 0 0-1.24Z"},{"path":"M9 17.38a.62.62 0 0 0 0 1.24h6a.62.62 0 0 0 0-1.24Zm23.13 3.01-3-.64a.57.57 0 0 0-.26 0l-3 .64a.62.62 0 0 0-.49.61v3.45a3.62 3.62 0 1 0 7.24 0V21a.62.62 0 0 0-.49-.61Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardServerSecuredIcon: ComponentClass<SVGIconProps>;
export default RhStandardServerSecuredIcon;