import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiArrowUpIconConfig: {
  name: 'RhUiArrowUpIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M27.707 12.293 17.061 1.646a1.501 1.501 0 0 0-2.121 0L4.293 12.293a.999.999 0 1 0 1.414 1.414L15 4.414V30a1 1 0 0 0 2 0V4.414l9.293 9.293a.997.997 0 0 0 1.414 0 .999.999 0 0 0 0-1.414Z"},
  rhUiIcon: null,
};
export declare const RhUiArrowUpIcon: ComponentClass<SVGIconProps>;
export default RhUiArrowUpIcon;