import { createIconBase } from '../createIcon.js';

export const RhStandardHarveyBall90IconConfig = {
  name: 'RhStandardHarveyBall90Icon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M18 3.375A14.625 14.625 0 1 0 32.625 18 14.642 14.642 0 0 0 18 3.375Zm-.625 12.707-6.759-9.224a13.29 13.29 0 0 1 6.759-2.2Z"},
  rhUiIcon: null,
};

export const RhStandardHarveyBall90Icon = createIconBase(RhStandardHarveyBall90IconConfig);

export default RhStandardHarveyBall90Icon;