import { createIconBase } from '../createIcon.js';

export const RhUiCollectionFillIconConfig = {
  name: 'RhUiCollectionFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30 12.5v17c0 .827-.673 1.5-1.5 1.5h-25c-.827 0-1.5-.673-1.5-1.5v-17c0-.827.673-1.5 1.5-1.5h25c.827 0 1.5.673 1.5 1.5ZM7 3h18a1 1 0 0 0 0-2H7a1 1 0 0 0 0 2ZM5 8h22a1 1 0 0 0 0-2H5a1 1 0 0 0 0 2Z"},
  rhUiIcon: null,
};

export const RhUiCollectionFillIcon = createIconBase(RhUiCollectionFillIconConfig);

export default RhUiCollectionFillIcon;