import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiDecreasingIconConfig: {
  name: 'RhUiDecreasingIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M2 5V3a1 1 0 0 1 2 0v2a1 1 0 0 1-2 0Zm27 23H4V17a1 1 0 0 0-2 0v11.5c0 .827.673 1.5 1.5 1.5H29a1 1 0 0 0 0-2ZM8.939 17.354a1.501 1.501 0 0 0 2.121 0l5.939-5.939 11.293 11.293a.997.997 0 0 0 1.414 0 .999.999 0 0 0 0-1.414L18.06 9.648a1.501 1.501 0 0 0-2.121 0L10 15.587 3.707 9.294a.999.999 0 1 0-1.414 1.414l6.646 6.646Z"},
  rhUiIcon: null,
};
export declare const RhUiDecreasingIcon: ComponentClass<SVGIconProps>;
export default RhUiDecreasingIcon;