import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiGovernmentFillIconConfig: {
  name: 'RhUiGovernmentFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30 29a1 1 0 0 1-1 1H3a1 1 0 0 1 0-2h26a1 1 0 0 1 1 1ZM4 24a1 1 0 0 0 1 1h22a1 1 0 0 0 0-2H5a1 1 0 0 0-1 1Zm4-4v-7a1 1 0 0 0-2 0v7a1 1 0 0 0 2 0Zm6 0v-7a1 1 0 0 0-2 0v7a1 1 0 0 0 2 0Zm6 0v-7a1 1 0 0 0-2 0v7a1 1 0 0 0 2 0Zm6 0v-7a1 1 0 0 0-2 0v7a1 1 0 0 0 2 0ZM3 10h26a1 1 0 0 0 .419-1.909l-13-6a1.005 1.005 0 0 0-.838 0l-13 6.001A1 1 0 0 0 3 10.001Z"},
  rhUiIcon: null,
};
export declare const RhUiGovernmentFillIcon: ComponentClass<SVGIconProps>;
export default RhUiGovernmentFillIcon;