import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardPadlockLockedIconConfig: {
  name: 'RhStandardPadlockLockedIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M27 12.38h-3.38V10a5.62 5.62 0 0 0-11.24 0v2.38H9a.62.62 0 0 0-.62.62v18a.62.62 0 0 0 .62.62h18a.62.62 0 0 0 .62-.62V13a.62.62 0 0 0-.62-.62ZM13.62 10a4.38 4.38 0 1 1 8.76 0v2.38h-8.76Zm-4 20.38V13.62h16.76v3.76H18a.62.62 0 0 0 0 1.24h8.38v2.76H18a.62.62 0 0 0 0 1.24h8.38v2.76H18a.62.62 0 0 0 0 1.24h8.38v3.76Z"},
  rhUiIcon: null,
};
export declare const RhStandardPadlockLockedIcon: ComponentClass<SVGIconProps>;
export default RhStandardPadlockLockedIcon;