/// <reference types="react" />
export interface CompassNavContentProps extends React.HTMLProps<HTMLDivElement> {
    /** Content of the nav content wrapper. */
    children: React.ReactNode;
    /** Additional classes added to the nav content. */
    className?: string;
}
export declare const CompassNavContent: React.FunctionComponent<CompassNavContentProps>;
//# sourceMappingURL=CompassNavContent.d.ts.map