import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiMinusIconConfig: {
  name: 'RhUiMinusIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29 17H3a1 1 0 0 1 0-2h26a1 1 0 0 1 0 2Z"},
  rhUiIcon: null,
};
export declare const RhUiMinusIcon: ComponentClass<SVGIconProps>;
export default RhUiMinusIcon;