import { createIconBase } from '../createIcon.js';

export const RhUiHarveyBall25IconConfig = {
  name: 'RhUiHarveyBall25Icon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm0 28C8.832 29 3 23.168 3 16 3 9.168 8.297 3.551 15 3.038V16a1 1 0 0 0 1 1h12.962C28.45 23.703 22.832 29 16 29Z"},
  rhUiIcon: null,
};

export const RhUiHarveyBall25Icon = createIconBase(RhUiHarveyBall25IconConfig);

export default RhUiHarveyBall25Icon;