import { createIconBase } from '../createIcon.js';

export const RhMicronsCheckmarkIconConfig = {
  name: 'RhMicronsCheckmarkIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M18.71 4.27c-.4-.38-1.03-.37-1.41.02L7 14.59 2.71 10.3l-.02-.02c-.4-.38-1.03-.37-1.41.02-.38.4-.37 1.03.02 1.41l4.65 4.65a1.499 1.499 0 0 0 2.12 0L18.72 5.71l.02-.02c.38-.4.37-1.03-.02-1.41Z"},
  rhUiIcon: null,
};

export const RhMicronsCheckmarkIcon = createIconBase(RhMicronsCheckmarkIconConfig);

export default RhMicronsCheckmarkIcon;