import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardMusicNoteIconConfig: {
  name: 'RhStandardMusicNoteIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M31.61 4.94a.63.63 0 0 0-.74-.55l-19 4a.65.65 0 0 0-.49.61v15.55a4.12 4.12 0 1 0 1.24 3s0-18 0-18l17.76-3.78v15.78a4.14 4.14 0 0 0-7 2.95c.12 5.28 7.79 5.51 8.22.25.07-.17.02-19.63.01-19.81ZM8.5 30.38a2.88 2.88 0 0 1 0-5.75 2.88 2.88 0 0 1 0 5.75Zm19-3a2.88 2.88 0 0 1 0-5.75 2.88 2.88 0 0 1 0 5.75Z"},
  rhUiIcon: null,
};
export declare const RhStandardMusicNoteIcon: ComponentClass<SVGIconProps>;
export default RhStandardMusicNoteIcon;