import { createIconBase } from '../createIcon.js';

export const RhUiClipboardFillIconConfig = {
  name: 'RhUiClipboardFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M25.5 6H23v-.5c0-.827-.673-1.5-1.5-1.5h-1.626C19.429 2.276 17.861 1 16 1s-3.428 1.276-3.874 3H10.5C9.673 4 9 4.673 9 5.5V6H6.5C5.673 6 5 6.673 5 7.5v22c0 .827.673 1.5 1.5 1.5h19c.827 0 1.5-.673 1.5-1.5v-22c0-.827-.673-1.5-1.5-1.5ZM11 6h2a1 1 0 0 0 1-1c0-1.103.897-2 2-2s2 .897 2 2a1 1 0 0 0 1 1h2v2H11V6Z"},
  rhUiIcon: null,
};

export const RhUiClipboardFillIcon = createIconBase(RhUiClipboardFillIconConfig);

export default RhUiClipboardFillIcon;