import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiMinusCircleFillIconConfig: {
  name: 'RhUiMinusCircleFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm7 16.125H9a1.125 1.125 0 0 1 0-2.25h14a1.125 1.125 0 0 1 0 2.25Z"},
  rhUiIcon: null,
};
export declare const RhUiMinusCircleFillIcon: ComponentClass<SVGIconProps>;
export default RhUiMinusCircleFillIcon;