import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const MinusIconConfig: {
  name: 'MinusIcon',
  icon: {"xOffset":0,"yOffset":0,"width":448,"height":512,"svgPathData":"M416 208H32c-17.67 0-32 14.33-32 32v32c0 17.67 14.33 32 32 32h384c17.67 0 32-14.33 32-32v-32c0-17.67-14.33-32-32-32z"},
  rhUiIcon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29 17H3a1 1 0 0 1 0-2h26a1 1 0 0 1 0 2Z"},
};
export declare const MinusIcon: ComponentClass<SVGIconProps>;
export default MinusIcon;