import { createIconBase } from '../createIcon.js';

export const RhUiOpenDrawerLeftIconConfig = {
  name: 'RhUiOpenDrawerLeftIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29.5 3h-27C1.673 3 1 3.673 1 4.5v23c0 .827.673 1.5 1.5 1.5h27c.827 0 1.5-.673 1.5-1.5v-23c0-.827-.673-1.5-1.5-1.5ZM29 27H3V5h26v22ZM6 22.5v-13C6 8.673 6.673 8 7.5 8h6c.827 0 1.5.673 1.5 1.5v13c0 .827-.673 1.5-1.5 1.5h-6c-.827 0-1.5-.673-1.5-1.5Z"},
  rhUiIcon: null,
};

export const RhUiOpenDrawerLeftIcon = createIconBase(RhUiOpenDrawerLeftIconConfig);

export default RhUiOpenDrawerLeftIcon;