import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiPanelCloseIconConfig: {
  name: 'RhUiPanelCloseIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M28.5 2h-4c-.827 0-1.5.673-1.5 1.5v25c0 .827.673 1.5 1.5 1.5h4c.827 0 1.5-.673 1.5-1.5v-25c0-.827-.673-1.5-1.5-1.5ZM28 28h-3V4h3v24Zm-8-12a1 1 0 0 1-1 1H5.414l5.293 5.293a.999.999 0 1 1-1.414 1.414l-6.646-6.646a1.501 1.501 0 0 1 0-2.121l6.646-6.646a.999.999 0 1 1 1.414 1.414l-5.293 5.293H19a1 1 0 0 1 1 1Z"},
  rhUiIcon: null,
};
export declare const RhUiPanelCloseIcon: ComponentClass<SVGIconProps>;
export default RhUiPanelCloseIcon;