import { Avatar } from '@patternfly/react-core';

export const AvatarInitials: React.FunctionComponent = () => (
  <>
    <Avatar alt="non-color avatar with initial C" isBordered initials="C" />
    <Avatar color="red" alt="red avatar with initial C" initials="C" />
    <Avatar color="orangered" alt="orangered avatar with initial C" initials="C" />
    <Avatar color="orange" alt="orange avatar with initial C" initials="C" />
    <Avatar color="yellow" alt="yellow avatar with initial C" initials="C" />
    <Avatar color="green" alt="green avatar with initial C" initials="C" />
    <Avatar color="teal" alt="teal avatar with initial C" initials="C" />
    <Avatar color="blue" alt="blue avatar with initial C" initials="C" />
    <Avatar color="purple" alt="purple avatar with initial C" initials="C" />
    <Avatar color="gray" alt="gray avatar with initial C" initials="C" />
  </>
);
