/// <reference types="react" />
export interface CompassNavMainProps extends React.HTMLProps<HTMLDivElement> {
    /** Content of the nav main section (typically tabs). */
    children: React.ReactNode;
    /** Additional classes added to the nav main section. */
    className?: string;
}
export declare const CompassNavMain: React.FunctionComponent<CompassNavMainProps>;
//# sourceMappingURL=CompassNavMain.d.ts.map