import { createIconBase } from '../createIcon.js';

export const RhUiOpenDrawerRightFillIconConfig = {
  name: 'RhUiOpenDrawerRightFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M24.875 22.875h-5.75V9.125h5.75v13.75ZM1 27.5v-23C1 3.673 1.673 3 2.5 3h27c.827 0 1.5.673 1.5 1.5v23c0 .827-.673 1.5-1.5 1.5h-27c-.827 0-1.5-.673-1.5-1.5Zm15.875-4c0 .896.729 1.625 1.625 1.625h7c.896 0 1.625-.729 1.625-1.625v-15c0-.896-.729-1.625-1.625-1.625h-7c-.896 0-1.625.729-1.625 1.625v15Z"},
  rhUiIcon: null,
};

export const RhUiOpenDrawerRightFillIcon = createIconBase(RhUiOpenDrawerRightFillIconConfig);

export default RhUiOpenDrawerRightFillIcon;