import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiNotStartedFillIconConfig: {
  name: 'RhUiNotStartedFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1ZM8 17.876a1.874 1.874 0 1 1-.001-3.749A1.874 1.874 0 0 1 8 17.876Zm8 0a1.874 1.874 0 1 1-.001-3.749A1.874 1.874 0 0 1 16 17.876Zm8 0a1.874 1.874 0 1 1-.001-3.749A1.874 1.874 0 0 1 24 17.876Z"},
  rhUiIcon: null,
};
export declare const RhUiNotStartedFillIcon: ComponentClass<SVGIconProps>;
export default RhUiNotStartedFillIcon;