import { createIconBase } from '../createIcon.js';

export const RhUiApplicationsFillIconConfig = {
  name: 'RhUiApplicationsFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M25 29a1 1 0 0 1-1 1H3.5c-.827 0-1.5-.673-1.5-1.5V8a1 1 0 1 1 2 0v20h20a1 1 0 0 1 1 1Zm5-25.5v20c0 .827-.673 1.5-1.5 1.5h-20c-.827 0-1.5-.673-1.5-1.5v-20C7 2.673 7.673 2 8.5 2h20c.827 0 1.5.673 1.5 1.5ZM18.87 8a1.874 1.874 0 1 0-3.749-.001A1.874 1.874 0 0 0 18.87 8Zm7 0a1.874 1.874 0 1 0-3.749-.001A1.874 1.874 0 0 0 25.87 8Z"},
  rhUiIcon: null,
};

export const RhUiApplicationsFillIcon = createIconBase(RhUiApplicationsFillIconConfig);

export default RhUiApplicationsFillIcon;