import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardArrowDirectionalIconConfig: {
  name: 'RhStandardArrowDirectionalIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M31.58 18.24a.64.64 0 0 0-.14-.68l-9-9c-.56-.58-1.47.32-.88.88l7.93 7.94H5a.62.62 0 1 0 0 1.24h24.49l-7.93 7.94a.62.62 0 0 0 .88.88l9-9a.72.72 0 0 0 .14-.2Z"},
  rhUiIcon: null,
};
export declare const RhStandardArrowDirectionalIcon: ComponentClass<SVGIconProps>;
export default RhStandardArrowDirectionalIcon;