import { createIconBase } from '../createIcon.js';

export const RhUiMinusIconConfig = {
  name: 'RhUiMinusIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29 17H3a1 1 0 0 1 0-2h26a1 1 0 0 1 0 2Z"},
  rhUiIcon: null,
};

export const RhUiMinusIcon = createIconBase(RhUiMinusIconConfig);

export default RhUiMinusIcon;