import { createIconBase } from '../createIcon.js';

export const RhUiPlayIconConfig = {
  name: 'RhUiPlayIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"m30.447 15.105-28-14A1.001 1.001 0 0 0 1 2v28a1.003 1.003 0 0 0 1 1c.153 0 .306-.035.447-.105l28-14a1 1 0 0 0 0-1.79ZM3 28.382V3.618L27.764 16 3 28.382Z"},
  rhUiIcon: null,
};

export const RhUiPlayIcon = createIconBase(RhUiPlayIconConfig);

export default RhUiPlayIcon;