import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardDiscIconConfig: {
  name: 'RhStandardDiscIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M18 3.38A14.62 14.62 0 1 0 32.62 18 14.64 14.64 0 0 0 18 3.38Zm0 28A13.38 13.38 0 1 1 31.38 18 13.39 13.39 0 0 1 18 31.38Z"},{"path":"M18 13.38A4.62 4.62 0 1 0 22.62 18 4.62 4.62 0 0 0 18 13.38Zm0 8A3.38 3.38 0 1 1 21.38 18 3.39 3.39 0 0 1 18 21.38Zm0-14a.62.62 0 1 0 0 1.24A9.39 9.39 0 0 1 27.38 18a.62.62 0 0 0 1.24 0A10.63 10.63 0 0 0 18 7.38Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardDiscIcon: ComponentClass<SVGIconProps>;
export default RhStandardDiscIcon;