import { createIconBase } from '../createIcon.js';

export const RhUiLongArrowLeftIconConfig = {
  name: 'RhUiLongArrowLeftIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M31 16a1 1 0 0 1-1 1H4.414l4.293 4.293a.999.999 0 1 1-1.414 1.414l-5.646-5.646a1.501 1.501 0 0 1 0-2.121l5.646-5.646a.999.999 0 1 1 1.414 1.414l-4.293 4.293H30a1 1 0 0 1 1 1Z"},
  rhUiIcon: null,
};

export const RhUiLongArrowLeftIcon = createIconBase(RhUiLongArrowLeftIconConfig);

export default RhUiLongArrowLeftIcon;