import { createIconBase } from '../createIcon.js';

export const RhStandardDownloadIconConfig = {
  name: 'RhStandardDownloadIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M31 30.38H5a.62.62 0 0 0 0 1.24h26a.62.62 0 0 0 0-1.24Zm-13.44-2.94a.63.63 0 0 0 .88 0l8-8c.58-.56-.31-1.47-.88-.88l-6.94 6.93V5a.62.62 0 0 0-1.24 0v20.49l-6.94-6.93a.62.62 0 0 0-.88.88Z"},
  rhUiIcon: null,
};

export const RhStandardDownloadIcon = createIconBase(RhStandardDownloadIconConfig);

export default RhStandardDownloadIcon;