import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiSecurityFillIconConfig: {
  name: 'RhUiSecurityFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29 4.56V18c0 7.168-5.832 13-13 13S3 25.168 3 18V4.56a1 1 0 0 1 .792-.978l12-2.56a1.01 1.01 0 0 1 .417 0l12 2.56c.461.099.792.506.792.978Z"},
  rhUiIcon: null,
};
export declare const RhUiSecurityFillIcon: ComponentClass<SVGIconProps>;
export default RhUiSecurityFillIcon;