import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardMegaphoneIconConfig: {
  name: 'RhStandardMegaphoneIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M30.32 4.46a.63.63 0 0 0-.61 0l-14.87 7.92H11a5.62 5.62 0 0 0-1.24 11.1l1.63 7.65a.64.64 0 0 0 .61.49h3a.62.62 0 0 0 .62-.62v-7l14.09 7.51a.62.62 0 0 0 .91-.55V5a.63.63 0 0 0-.3-.54ZM14.38 30.38h-1.87l-1.44-6.76h3.31Zm0-8H11a4.38 4.38 0 0 1 0-8.76h3.38Zm15 7.58-13.76-7.34v-9.24L29.38 6Z"},
  rhUiIcon: null,
};
export declare const RhStandardMegaphoneIcon: ComponentClass<SVGIconProps>;
export default RhStandardMegaphoneIcon;