import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiResourcesAlmostEmptyIconConfig: {
  name: 'RhUiResourcesAlmostEmptyIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm0 28C8.832 29 3 23.168 3 16S8.832 3 16 3s13 5.832 13 13-5.832 13-13 13Zm8.796-8.25a9.992 9.992 0 0 1-10.616 5.09c-3.022-.533-5.597-2.483-7.004-5.122-.173-.325.082-.718.451-.718h16.732c.384 0 .619.412.436.75Z"},
  rhUiIcon: null,
};
export declare const RhUiResourcesAlmostEmptyIcon: ComponentClass<SVGIconProps>;
export default RhUiResourcesAlmostEmptyIcon;