import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsDoubleCaretUpIconConfig: {
  name: 'RhMicronsDoubleCaretUpIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M1.293 10.707a1 1 0 0 1 0-1.414l7.646-7.647a1.5 1.5 0 0 1 2.122 0l7.646 7.647a1 1 0 1 1-1.414 1.414L10 3.414l-7.293 7.293a1 1 0 0 1-1.414 0Zm9.768-1.06a1.5 1.5 0 0 0-2.122 0l-7.646 7.646a1 1 0 1 0 1.414 1.414L10 11.414l7.293 7.293a.997.997 0 0 0 1.414 0 1 1 0 0 0 0-1.414l-7.646-7.647Z"},
  rhUiIcon: null,
};
export declare const RhMicronsDoubleCaretUpIcon: ComponentClass<SVGIconProps>;
export default RhMicronsDoubleCaretUpIcon;