import { createIconBase } from '../createIcon.js';

export const BorderAllIconConfig = {
  name: 'BorderAllIcon',
  icon: {"xOffset":0,"yOffset":0,"width":448,"height":512,"svgPathData":"M416 32H32A32 32 0 0 0 0 64v384a32 32 0 0 0 32 32h384a32 32 0 0 0 32-32V64a32 32 0 0 0-32-32zm-32 64v128H256V96zm-192 0v128H64V96zM64 416V288h128v128zm192 0V288h128v128z"},
  rhUiIcon: null,
};

export const BorderAllIcon = createIconBase(BorderAllIconConfig);

export default BorderAllIcon;