import { createIconBase } from '../createIcon.js';

export const RhUiLongArrowRightIconConfig = {
  name: 'RhUiLongArrowRightIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"m30.354 17.061-5.646 5.646a.997.997 0 0 1-1.414 0 .999.999 0 0 1 0-1.414L27.587 17H2a1 1 0 0 1 0-2h25.586l-4.293-4.293a.999.999 0 1 1 1.414-1.414l5.646 5.646a1.501 1.501 0 0 1 0 2.121Z"},
  rhUiIcon: null,
};

export const RhUiLongArrowRightIcon = createIconBase(RhUiLongArrowRightIconConfig);

export default RhUiLongArrowRightIcon;