import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardEmailIconConfig: {
  name: 'RhStandardEmailIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M18 3.38a14.62 14.62 0 1 0 9.4 25.82.62.62 0 1 0-.8-.95 13.48 13.48 0 1 1 3.15-3.87H27A2.39 2.39 0 0 1 24.62 22V12a.62.62 0 0 0-1.24 0v2a7.12 7.12 0 1 0 0 8A3.62 3.62 0 0 0 27 25.62h3a.64.64 0 0 0 .63-.31A14.63 14.63 0 0 0 18 3.38Zm-.5 20.5A5.88 5.88 0 1 1 23.38 18a5.89 5.89 0 0 1-5.88 5.88Z"},
  rhUiIcon: null,
};
export declare const RhStandardEmailIcon: ComponentClass<SVGIconProps>;
export default RhStandardEmailIcon;