import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiArrowCircleDownFillIconConfig: {
  name: 'RhUiArrowCircleDownFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm6.796 17.795-5.646 5.646c-.317.317-.733.475-1.149.475s-.832-.158-1.149-.475l-5.646-5.646a1.127 1.127 0 0 1 0-1.591 1.127 1.127 0 0 1 1.592 0l4.079 4.079V7.999a1.125 1.125 0 0 1 2.25 0v13.284l4.079-4.079a1.127 1.127 0 0 1 1.592 0 1.127 1.127 0 0 1 0 1.591Z"},
  rhUiIcon: null,
};
export declare const RhUiArrowCircleDownFillIcon: ComponentClass<SVGIconProps>;
export default RhUiArrowCircleDownFillIcon;