import { createIconBase } from '../createIcon.js';

export const RhUiBookmarkFillIconConfig = {
  name: 'RhUiBookmarkFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29 2.5V30a.999.999 0 0 1-1.707.707L16 19.414 4.707 30.707A.999.999 0 0 1 3 30V2.5C3 1.673 3.673 1 4.5 1h23c.827 0 1.5.673 1.5 1.5Z"},
  rhUiIcon: null,
};

export const RhUiBookmarkFillIcon = createIconBase(RhUiBookmarkFillIconConfig);

export default RhUiBookmarkFillIcon;