import { createIconBase } from '../createIcon.js';

export const LongArrowAltRightIconConfig = {
  name: 'LongArrowAltRightIcon',
  icon: {"xOffset":0,"yOffset":0,"width":448,"height":512,"svgPathData":"M313.941 216H12c-6.627 0-12 5.373-12 12v56c0 6.627 5.373 12 12 12h301.941v46.059c0 21.382 25.851 32.09 40.971 16.971l86.059-86.059c9.373-9.373 9.373-24.569 0-33.941l-86.059-86.059c-15.119-15.119-40.971-4.411-40.971 16.971V216z"},
  rhUiIcon: null,
};

export const LongArrowAltRightIcon = createIconBase(LongArrowAltRightIconConfig);

export default LongArrowAltRightIcon;