import { createIconBase } from '../createIcon.js';

export const RhStandardBookmarkIconConfig = {
  name: 'RhStandardBookmarkIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M27 31.62a.62.62 0 0 1-.44-.18L18 22.88l-8.56 8.56A.62.62 0 0 1 8.38 31V5A.61.61 0 0 1 9 4.38h18a.62.62 0 0 1 .62.62v26a.64.64 0 0 1-.38.58.67.67 0 0 1-.24.04Zm-9-10.24a.62.62 0 0 1 .44.18l7.94 7.93V5.62H9.62v23.87l7.94-7.93a.62.62 0 0 1 .44-.18Z"},
  rhUiIcon: null,
};

export const RhStandardBookmarkIcon = createIconBase(RhStandardBookmarkIconConfig);

export default RhStandardBookmarkIcon;