import { createIconBase } from '../createIcon.js';

export const RhStandardContainerIconConfig = {
  name: 'RhStandardContainerIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"m30.44 10.46-12.13-7a.62.62 0 0 0-.62 0l-12.13 7a.63.63 0 0 0-.31.54v14a.63.63 0 0 0 .31.54l12.13 7a.64.64 0 0 0 .62 0l12.13-7a.63.63 0 0 0 .31-.54V11a.63.63 0 0 0-.31-.54Zm-.94 14.18L18 31.28 6.5 24.64V11.36L18 4.72l11.5 6.64Z"},
  rhUiIcon: null,
};

export const RhStandardContainerIcon = createIconBase(RhStandardContainerIconConfig);

export default RhStandardContainerIcon;