import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsSortDownSmallToLargeIconConfig: {
  name: 'RhMicronsSortDownSmallToLargeIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M18 10h-8a1 1 0 1 0 0 2h8a1 1 0 1 0 0-2Zm-8-2h5a1 1 0 1 0 0-2h-5a1 1 0 1 0 0 2Zm0-4h2a1 1 0 1 0 0-2h-2a1 1 0 1 0 0 2ZM8 14H6V2a1 1 0 1 0-2 0v12H2a.999.999 0 0 0-.707 1.707l2.646 2.647c.292.292.677.438 1.061.438s.769-.146 1.06-.438l2.647-2.647A.999.999 0 0 0 8 14Z"},
  rhUiIcon: null,
};
export declare const RhMicronsSortDownSmallToLargeIcon: ComponentClass<SVGIconProps>;
export default RhMicronsSortDownSmallToLargeIcon;