import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import styles from '@patternfly/react-styles/css/components/Compass/compass.mjs';
import { css } from '@patternfly/react-styles';
export const CompassHeader = ({ logo, nav, profile }) => (_jsxs(_Fragment, { children: [_jsx("div", { className: css(`${styles.compass}__logo`), children: logo }), _jsx("div", { className: css(styles.compassNav), children: nav }), _jsx("div", { className: css(styles.compassProfile), children: profile })] }));
CompassHeader.displayName = 'CompassHeader';
//# sourceMappingURL=CompassHeader.js.map