import { createIconBase } from '../createIcon.js';

export const RhUiCaretUpIconConfig = {
  name: 'RhUiCaretUpIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29 22a.997.997 0 0 1-.707-.293L16 9.414 3.707 21.707a.999.999 0 1 1-1.414-1.414L14.939 7.646a1.501 1.501 0 0 1 2.121 0l12.646 12.646a.999.999 0 0 1-.707 1.707Z"},
  rhUiIcon: null,
};

export const RhUiCaretUpIcon = createIconBase(RhUiCaretUpIconConfig);

export default RhUiCaretUpIcon;