import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardLaptopIconConfig: {
  name: 'RhStandardLaptopIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M18 9.62a.62.62 0 1 0-.62-.62.61.61 0 0 0 .62.62Z"},{"path":"M6 24.62h24a.61.61 0 0 0 .62-.62V9a.61.61 0 0 0-.62-.62h-9a.62.62 0 1 0 0 1.24h8.38v13.76H6.62V9.62H15a.62.62 0 0 0 0-1.24H6a.61.61 0 0 0-.62.62v15a.61.61 0 0 0 .62.62Zm26 1.76H4a.62.62 0 1 0 0 1.24h28a.62.62 0 1 0 0-1.24Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardLaptopIcon: ComponentClass<SVGIconProps>;
export default RhStandardLaptopIcon;