import { createIconBase } from '../createIcon.js';

export const RhStandardMugIconConfig = {
  name: 'RhStandardMugIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M27 30.38H4a.62.62 0 0 0 0 1.24h23a.62.62 0 0 0 0-1.24ZM25.72 8V5a.63.63 0 0 0-.63-.62H5a.62.62 0 0 0-.62.62v16A6.63 6.63 0 0 0 11 27.62h8.09A6.63 6.63 0 0 0 25.72 21c7.81-.95 7.81-12.14 0-13Zm-1.25 13a5.39 5.39 0 0 1-5.38 5.38H11A5.39 5.39 0 0 1 5.62 21V5.62h18.85Zm1.25-1.32V9.23a5.26 5.26 0 0 1 0 10.45Z"},
  rhUiIcon: null,
};

export const RhStandardMugIcon = createIconBase(RhStandardMugIconConfig);

export default RhStandardMugIcon;