import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardSecuredIconConfig: {
  name: 'RhStandardSecuredIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"m29.13 6.73-11-2.34a.57.57 0 0 0-.26 0l-11 2.34a.61.61 0 0 0-.49.61V20a11.62 11.62 0 0 0 23.24 0V7.34a.61.61 0 0 0-.49-.61ZM28.38 20a10.38 10.38 0 0 1-20.76 0V7.84L18 5.64l10.38 2.2Z"},{"path":"M14.9 17.69a.62.62 0 0 0-.88.88l2.12 2.13a.62.62 0 0 0 .44.18.66.66 0 0 0 .42-.18l4.95-5a.62.62 0 0 0-.88-.88l-4.52 4.51Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardSecuredIcon: ComponentClass<SVGIconProps>;
export default RhStandardSecuredIcon;