import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardElectricalPlugIconConfig: {
  name: 'RhStandardElectricalPlugIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M25.5 4.38a6.12 6.12 0 0 0-6.12 6.12v15a4.88 4.88 0 0 1-9.76 0v-3.94a4.61 4.61 0 0 0 4-4.56v-4a.62.62 0 0 0-.62-.62h-1.38V9a.62.62 0 0 0-1.24 0v3.38H7.62V9a.62.62 0 0 0-1.24 0v3.38H5a.62.62 0 0 0-.62.62v4a4.61 4.61 0 0 0 4 4.56v3.94a6.12 6.12 0 0 0 12.24 0v-15a4.88 4.88 0 1 1 9.76 0V27a.62.62 0 0 0 1.24 0V10.5a6.12 6.12 0 0 0-6.12-6.12ZM5.62 17v-3.38h6.76V17a3.38 3.38 0 0 1-6.76 0Z"},
  rhUiIcon: null,
};
export declare const RhStandardElectricalPlugIcon: ComponentClass<SVGIconProps>;
export default RhStandardElectricalPlugIcon;