import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardCalendarIconConfig: {
  name: 'RhStandardCalendarIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M31 4.38H5a.62.62 0 0 0-.62.62v20a.76.76 0 0 0 .18.44l6 6a.67.67 0 0 0 .44.18h20a.62.62 0 0 0 .62-.62V5a.62.62 0 0 0-.62-.62Zm-.62 1.24v3.76h-4.76V8a.62.62 0 0 0-1.24 0v1.38H11.62V8a.62.62 0 1 0-1.24 0v1.38H5.62V5.62Zm-20 23.87-3.87-3.87h3.87Zm1.24.89V25a.62.62 0 0 0-.62-.62H5.62V10.62h4.76V12a.62.62 0 0 0 1.24 0v-1.38h12.76V12a.62.62 0 1 0 1.24 0v-1.38h4.76v19.76Z"},
  rhUiIcon: null,
};
export declare const RhStandardCalendarIcon: ComponentClass<SVGIconProps>;
export default RhStandardCalendarIcon;