import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardCheckboxBlankIconConfig: {
  name: 'RhStandardCheckboxBlankIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M31 31.625H5A.625.625 0 0 1 4.375 31V5A.625.625 0 0 1 5 4.375h26a.625.625 0 0 1 .625.625v26a.625.625 0 0 1-.625.625Zm-25.375-1.25h24.75V5.625H5.625Z"},
  rhUiIcon: null,
};
export declare const RhStandardCheckboxBlankIcon: ComponentClass<SVGIconProps>;
export default RhStandardCheckboxBlankIcon;