import { createIconBase } from '../createIcon.js';

export const RhStandardHarveyBall0IconConfig = {
  name: 'RhStandardHarveyBall0Icon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M18 3.375A14.625 14.625 0 1 0 32.625 18 14.642 14.642 0 0 0 18 3.375Zm0 28A13.375 13.375 0 1 1 31.375 18 13.39 13.39 0 0 1 18 31.375Z"},
  rhUiIcon: null,
};

export const RhStandardHarveyBall0Icon = createIconBase(RhStandardHarveyBall0IconConfig);

export default RhStandardHarveyBall0Icon;