import { createIconBase } from '../createIcon.js';

export const RhUiCleanUpFillIconConfig = {
  name: 'RhUiCleanUpFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M7 16a1 1 0 0 1 1-1h7V2a1 1 0 1 1 2 0v13h7a1 1 0 1 1 0 2H8a1 1 0 0 1-1-1Zm17.979 3.793A1 1 0 0 0 24 19H8a1 1 0 0 0-.979.793l-2.12 10A1.002 1.002 0 0 0 5.88 31h3.694l1.325-6.234a1.126 1.126 0 0 1 2.202.468L11.875 31h8.25l-1.226-5.766a1.125 1.125 0 0 1 2.202-.468L22.426 31h3.694a1 1 0 0 0 .979-1.207l-2.12-10Z"},
  rhUiIcon: null,
};

export const RhUiCleanUpFillIcon = createIconBase(RhUiCleanUpFillIconConfig);

export default RhUiCleanUpFillIcon;