import { createIconBase } from '../createIcon.js';

export const RhMicronsCheckboxCompleteIconConfig = {
  name: 'RhMicronsCheckboxCompleteIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"m5.29 10.71 2.65 2.65c.29.29.68.44 1.06.44s.77-.15 1.06-.44l4.65-4.65c.4-.38.41-1.02.02-1.41a.987.987 0 0 0-1.41-.02l-.02.02-4.29 4.29L6.72 9.3a.987.987 0 0 0-1.41-.02.987.987 0 0 0-.02 1.41l.02.02ZM17.5 1h-15C1.67 1 1 1.67 1 2.5v15c0 .83.67 1.5 1.5 1.5h15c.83 0 1.5-.67 1.5-1.5v-15c0-.83-.67-1.5-1.5-1.5ZM17 17H3V3h14v14Z"},
  rhUiIcon: null,
};

export const RhMicronsCheckboxCompleteIcon = createIconBase(RhMicronsCheckboxCompleteIconConfig);

export default RhMicronsCheckboxCompleteIcon;