import { createIconBase } from '../createIcon.js';

export const OutlinedCommentAltIconConfig = {
  name: 'OutlinedCommentAltIcon',
  icon: {"xOffset":0,"yOffset":0,"width":512,"height":512,"svgPathData":"M448 0H64C28.7 0 0 28.7 0 64v288c0 35.3 28.7 64 64 64h96v84c0 7.1 5.8 12 12 12 2.4 0 4.9-.7 7.1-2.4L304 416h144c35.3 0 64-28.7 64-64V64c0-35.3-28.7-64-64-64zm16 352c0 8.8-7.2 16-16 16H288l-12.8 9.6L208 428v-60H64c-8.8 0-16-7.2-16-16V64c0-8.8 7.2-16 16-16h384c8.8 0 16 7.2 16 16v288z"},
  rhUiIcon: null,
};

export const OutlinedCommentAltIcon = createIconBase(OutlinedCommentAltIconConfig);

export default OutlinedCommentAltIcon;