import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiArrowCircleUpRightIconConfig: {
  name: 'RhUiArrowCircleUpRightIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M22 11.5V20a1 1 0 1 1-2 0v-6.586l-8.243 8.243a.997.997 0 0 1-1.414 0 .999.999 0 0 1 0-1.414L18.586 12H12a1 1 0 1 1 0-2h8.5c.827 0 1.5.673 1.5 1.5Zm9 4.5c0 8.271-6.729 15-15 15S1 24.271 1 16 7.729 1 16 1s15 6.729 15 15Zm-2 0c0-7.168-5.832-13-13-13S3 8.832 3 16s5.832 13 13 13 13-5.832 13-13Z"},
  rhUiIcon: null,
};
export declare const RhUiArrowCircleUpRightIcon: ComponentClass<SVGIconProps>;
export default RhUiArrowCircleUpRightIcon;