import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiCaretLeftIconConfig: {
  name: 'RhUiCaretLeftIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M21 30a.997.997 0 0 1-.707-.293L7.647 17.061a1.501 1.501 0 0 1 0-2.121L20.293 2.293a.999.999 0 1 1 1.414 1.414L9.414 16l12.293 12.293A.999.999 0 0 1 21 30Z"},
  rhUiIcon: null,
};
export declare const RhUiCaretLeftIcon: ComponentClass<SVGIconProps>;
export default RhUiCaretLeftIcon;