import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiArrowUpLeftIconConfig: {
  name: 'RhUiArrowUpLeftIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M27.707 26.293 7.414 6H21a1 1 0 1 0 0-2H5.5C4.673 4 4 4.673 4 5.5V21a1 1 0 1 0 2 0V7.414l20.293 20.293a.997.997 0 0 0 1.414 0 .999.999 0 0 0 0-1.414Z"},
  rhUiIcon: null,
};
export declare const RhUiArrowUpLeftIcon: ComponentClass<SVGIconProps>;
export default RhUiArrowUpLeftIcon;