import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiArrowDownLeftUpRightToCenterIconConfig: {
  name: 'RhUiArrowDownLeftUpRightToCenterIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M14 19.5V26a1 1 0 1 1-2 0v-4.586l-8.293 8.293a.997.997 0 0 1-1.414 0 .999.999 0 0 1 0-1.414L10.586 20H6a1 1 0 1 1 0-2h6.5c.827 0 1.5.673 1.5 1.5ZM29.707 2.293a.999.999 0 0 0-1.414 0L20 10.586V6a1 1 0 1 0-2 0v6.5c0 .827.673 1.5 1.5 1.5H26a1 1 0 1 0 0-2h-4.586l8.293-8.293a.999.999 0 0 0 0-1.414Z"},
  rhUiIcon: null,
};
export declare const RhUiArrowDownLeftUpRightToCenterIcon: ComponentClass<SVGIconProps>;
export default RhUiArrowDownLeftUpRightToCenterIcon;