import { createIconBase } from '../createIcon.js';

export const RhStandardFastForwardIconConfig = {
  name: 'RhStandardFastForwardIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"m31.31 17.46-13-7.35a.64.64 0 0 0-.63 0 .63.63 0 0 0-.3.54v6.28L5.31 10.11a.63.63 0 0 0-.93.54v14.7a.63.63 0 0 0 .93.54l12.07-6.82v6.28a.63.63 0 0 0 .93.54l13-7.35a.62.62 0 0 0 0-1.08ZM5.62 24.27V11.73L16.73 18Zm13 0V11.73L29.73 18Z"},
  rhUiIcon: null,
};

export const RhStandardFastForwardIcon = createIconBase(RhStandardFastForwardIconConfig);

export default RhStandardFastForwardIcon;