import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardAlertIconConfig: {
  name: 'RhStandardAlertIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M17.38 16v6a.62.62 0 0 0 1.24 0v-6a.62.62 0 0 0-1.24 0Zm1.06 8.56a.62.62 0 0 0-.88.88c.56.56 1.44-.32.88-.88Z"},{"path":"m32.54 30.08-14-24.78a.64.64 0 0 0-1.08 0l-14 24.78A.62.62 0 0 0 4 31h28a.62.62 0 0 0 .54-.92Zm-27.47-.32L18 6.88l12.93 22.88Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardAlertIcon: ComponentClass<SVGIconProps>;
export default RhStandardAlertIcon;