import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsArrowUpIconConfig: {
  name: 'RhMicronsArrowUpIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"m16.71 7.29-5.65-5.64c-.59-.58-1.53-.58-2.12 0L3.29 7.29a.987.987 0 0 0-.02 1.41c.38.4 1.02.41 1.41.02l.02-.02 4.29-4.29V18c0 .55.45 1 1 1s1-.45 1-1V4.41l4.29 4.29a.996.996 0 1 0 1.41-1.41Z"},
  rhUiIcon: null,
};
export declare const RhMicronsArrowUpIcon: ComponentClass<SVGIconProps>;
export default RhMicronsArrowUpIcon;