import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiClipTextIconConfig: {
  name: 'RhUiClipTextIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M4 3v26a1 1 0 1 1-2 0V3a1 1 0 1 1 2 0Zm25-1a1 1 0 0 0-1 1v12H9a1 1 0 1 0 0 2h19v12a1 1 0 1 0 2 0V3a1 1 0 0 0-1-1Z"},
  rhUiIcon: null,
};
export declare const RhUiClipTextIcon: ComponentClass<SVGIconProps>;
export default RhUiClipTextIcon;