import { createIconBase } from '../createIcon.js';

export const RhStandardHeartIconConfig = {
  name: 'RhStandardHeartIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M30.1 7.24A8.65 8.65 0 0 0 18 7.13c-8.44-7.56-19.82 4-12.1 12.32L17.56 31.1a.61.61 0 0 0 .88 0L30.1 19.45a8.66 8.66 0 0 0 0-12.21Zm-.89 11.32L18 29.78 6.79 18.56C0 11.17 10.57 1.19 17.53 8.45c.42.46.95.06 1.25-.32 7.14-6.67 17.1 3.28 10.43 10.43Z"},
  rhUiIcon: null,
};

export const RhStandardHeartIcon = createIconBase(RhStandardHeartIconConfig);

export default RhStandardHeartIcon;