import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardStairsIconConfig: {
  name: 'RhStandardStairsIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M29 30.38h-5.38V25a.62.62 0 0 0-.62-.62h-5.38V19a.62.62 0 0 0-.62-.62h-5.38V13a.62.62 0 0 0-.62-.62H5a.62.62 0 0 0 0 1.24h5.38V19a.62.62 0 0 0 .62.62h5.38V25a.62.62 0 0 0 .62.62h5.38V31a.62.62 0 0 0 .62.62h6a.62.62 0 0 0 0-1.24Zm2-8h-1.74L11.44 4.56a.59.59 0 0 0-.44-.18H9a.62.62 0 0 0 0 1.24h1.74l17.82 17.82a.59.59 0 0 0 .44.18h2a.62.62 0 0 0 0-1.24Z"},
  rhUiIcon: null,
};
export declare const RhStandardStairsIcon: ComponentClass<SVGIconProps>;
export default RhStandardStairsIcon;