import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardWheelchairAccessibleIconConfig: {
  name: 'RhStandardWheelchairAccessibleIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M31 28.38h-3.5l-1.89-8.52a.62.62 0 0 0-.61-.48h-8.38v-4.76H22a.62.62 0 0 0 0-1.24h-5.38v-2.82a3.62 3.62 0 1 0-1.24 0v2.82H13.5c-12.1.49-12.1 17.75 0 18.25a9.14 9.14 0 0 0 9.12-9.13.63.63 0 0 0-1.25 0 7.88 7.88 0 0 1-7.87 7.88C3.07 30 3.07 15 13.5 14.62h1.88V20a.62.62 0 0 0 .62.62h8.5l1.89 8.52a.62.62 0 0 0 .61.48h4a.62.62 0 0 0 0-1.24ZM13.62 7a2.38 2.38 0 0 1 4.75 0 2.38 2.38 0 0 1-4.75 0Z"},
  rhUiIcon: null,
};
export declare const RhStandardWheelchairAccessibleIcon: ComponentClass<SVGIconProps>;
export default RhStandardWheelchairAccessibleIcon;