import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiCommentsFillIconConfig: {
  name: 'RhUiCommentsFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"m11.465 15.25-3.7 4.395A1.002 1.002 0 0 1 6 19v-3.75H2a1 1 0 0 1-1-1V2.714a1 1 0 0 1 1-1h19a1 1 0 0 1 1 1V14.25a1 1 0 0 1-1 1h-9.535ZM30 12h-4a1 1 0 0 0-1 1v4a1 1 0 0 1-1 1H13a.996.996 0 0 0-.707.293l-2 2A.997.997 0 0 0 10 21v3.54a1 1 0 0 0 1 1h9.535l3.7 4.395A1.002 1.002 0 0 0 26 29.29v-3.75h4a1 1 0 0 0 1-1V13a1 1 0 0 0-1-1Z"},
  rhUiIcon: null,
};
export declare const RhUiCommentsFillIcon: ComponentClass<SVGIconProps>;
export default RhUiCommentsFillIcon;