import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiCaretRightFillIconConfig: {
  name: 'RhUiCaretRightFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M24.354 17.061 11.708 29.707A1 1 0 0 1 10.001 29V3a1 1 0 0 1 1.707-.707l12.646 12.646a1.501 1.501 0 0 1 0 2.121Z"},
  rhUiIcon: null,
};
export declare const RhUiCaretRightFillIcon: ComponentClass<SVGIconProps>;
export default RhUiCaretRightFillIcon;