import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsErrorIconConfig: {
  name: 'RhMicronsErrorIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M10 0C4.486 0 0 4.486 0 10s4.486 10 10 10 10-4.486 10-10S15.514 0 10 0Zm0 18c-4.411 0-8-3.589-8-8s3.589-8 8-8 8 3.589 8 8-3.589 8-8 8Zm-1.25-8V5a1.25 1.25 0 1 1 2.5 0v5a1.25 1.25 0 1 1-2.5 0Zm2.75 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0Z"},
  rhUiIcon: null,
};
export declare const RhMicronsErrorIcon: ComponentClass<SVGIconProps>;
export default RhMicronsErrorIcon;