import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiHarveyBall33IconConfig: {
  name: 'RhUiHarveyBall33Icon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M31 16c0-8.271-6.729-15-15-15S1 7.729 1 16s6.729 15 15 15a15.035 15.035 0 0 0 13.145-7.766v-.001a15.043 15.043 0 0 0 1.854-7.232ZM16 29C8.832 29 3 23.168 3 16 3 9.168 8.297 3.551 15 3.038V16a1 1 0 0 0 .518.876l11.358 6.249A13.03 13.03 0 0 1 16 29Z"},
  rhUiIcon: null,
};
export declare const RhUiHarveyBall33Icon: ComponentClass<SVGIconProps>;
export default RhUiHarveyBall33Icon;