import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const EthereumIconConfig: {
  name: 'EthereumIcon',
  icon: {"xOffset":0,"yOffset":0,"width":320,"height":512,"svgPathData":"M311.9 260.8L160 353.6 8 260.8 160 0l151.9 260.8zM160 383.4L8 290.6 160 512l152-221.4-152 92.8z"},
  rhUiIcon: null,
};
export declare const EthereumIcon: ComponentClass<SVGIconProps>;
export default EthereumIcon;