import { createIconBase } from '../createIcon.js';

export const RhUiElectricityIconConfig = {
  name: 'RhUiElectricityIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M15 31a1 1 0 0 1-1-1V19h-4a.999.999 0 0 1-.916-1.401l7-16A1 1 0 0 1 18 2v11h4a.999.999 0 0 1 .916 1.401l-7 16A.998.998 0 0 1 15 31Zm-3.471-14H14.5c.827 0 1.5.673 1.5 1.5v6.719L20.471 15H17.5c-.827 0-1.5-.673-1.5-1.5V6.781L11.529 17Z"},
  rhUiIcon: null,
};

export const RhUiElectricityIcon = createIconBase(RhUiElectricityIconConfig);

export default RhUiElectricityIcon;