import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiMergeNodesIconConfig: {
  name: 'RhUiMergeNodesIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M17 5.414V16a1 1 0 0 1-.293.707l-13 13a.997.997 0 0 1-1.414 0 1 1 0 0 1 0-1.414L15 15.586V5.414l-3.293 3.293a1 1 0 1 1-1.414-1.414l4.646-4.647a1.5 1.5 0 0 1 2.122 0l4.646 4.647a1 1 0 1 1-1.414 1.414L17 5.414Zm12.707 22.879-9-9a1 1 0 1 0-1.414 1.414l9 9a.997.997 0 0 0 1.414 0 1 1 0 0 0 0-1.414Z"},
  rhUiIcon: null,
};
export declare const RhUiMergeNodesIcon: ComponentClass<SVGIconProps>;
export default RhUiMergeNodesIcon;