import { createIconBase } from '../createIcon.js';

export const RhStandardPadlockUnlockedIconConfig = {
  name: 'RhStandardPadlockUnlockedIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M30 12.38H16.62V10a5.62 5.62 0 0 0-11.24 0v3a.62.62 0 1 0 1.24 0v-3a4.38 4.38 0 0 1 8.76 0v2.38H12a.62.62 0 0 0-.62.62v18a.62.62 0 0 0 .62.62h18a.62.62 0 0 0 .62-.62V13a.62.62 0 0 0-.62-.62Zm-17.38 18V13.62h16.76v3.76H21a.62.62 0 0 0 0 1.24h8.38v2.76H21a.62.62 0 0 0 0 1.24h8.38v2.76H21a.62.62 0 0 0 0 1.24h8.38v3.76Z"},
  rhUiIcon: null,
};

export const RhStandardPadlockUnlockedIcon = createIconBase(RhStandardPadlockUnlockedIconConfig);

export default RhStandardPadlockUnlockedIcon;