import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiDuplicateFillIconConfig: {
  name: 'RhUiDuplicateFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M19 9h-9c-.551 0-1 .449-1 1v9a1 1 0 0 1-1 1H3.5c-.827 0-1.5-.673-1.5-1.5v-15C2 2.673 2.673 2 3.5 2h15c.827 0 1.5.673 1.5 1.5V8a1 1 0 0 1-1 1Zm9.5 3h-15c-.827 0-1.5.673-1.5 1.5v15c0 .827.673 1.5 1.5 1.5h15c.827 0 1.5-.673 1.5-1.5v-15c0-.827-.673-1.5-1.5-1.5Z"},
  rhUiIcon: null,
};
export declare const RhUiDuplicateFillIcon: ComponentClass<SVGIconProps>;
export default RhUiDuplicateFillIcon;