/// <reference types="react" />
export interface CompassDockMainProps extends React.HTMLProps<HTMLDivElement> {
    /** Additional classes added to the compass dock main container. */
    className?: string;
    /** Content of the compass dock main container. */
    children?: React.ReactNode;
}
export declare const CompassDockMain: React.FunctionComponent<CompassDockMainProps>;
//# sourceMappingURL=CompassDockMain.d.ts.map