import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardContainerSecuredIconConfig: {
  name: 'RhStandardContainerSecuredIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M21.69 29.15 18 31.28 6.5 24.64V11.36L18 4.72l11.5 6.64V22a.63.63 0 0 0 1.25 0V11a.63.63 0 0 0-.31-.54l-12.13-7a.62.62 0 0 0-.62 0l-12.13 7a.63.63 0 0 0-.31.54v14a.63.63 0 0 0 .31.54l12.13 7a.64.64 0 0 0 .62 0l4-2.31a.62.62 0 0 0-.62-1.08Z"},{"path":"m31.13 25-3-.64a.57.57 0 0 0-.26 0l-3 .64a.61.61 0 0 0-.49.61v3.45a3.62 3.62 0 1 0 7.24 0v-3.42a.61.61 0 0 0-.49-.64Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardContainerSecuredIcon: ComponentClass<SVGIconProps>;
export default RhStandardContainerSecuredIcon;