import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiContainerFillIconConfig: {
  name: 'RhUiContainerFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29 9.072v13.855c0 .357-.19.688-.5.866l-12 6.929a1 1 0 0 1-1 0l-12-6.929a1 1 0 0 1-.5-.866V9.072c0-.357.19-.688.5-.866l12-6.929a1.003 1.003 0 0 1 1 0l12 6.929a1 1 0 0 1 .5.866Z"},
  rhUiIcon: null,
};
export declare const RhUiContainerFillIcon: ComponentClass<SVGIconProps>;
export default RhUiContainerFillIcon;