import { createIconBase } from '../createIcon.js';

export const RhUiColumnsFillIconConfig = {
  name: 'RhUiColumnsFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M1 8.875V4.5C1 3.673 1.673 3 2.5 3h27c.827 0 1.5.673 1.5 1.5v4.375H1Zm30 2.25V27.5c0 .827-.673 1.5-1.5 1.5h-27c-.827 0-1.5-.673-1.5-1.5V11.125h30ZM17.125 15a1.125 1.125 0 0 0-2.25 0v10a1.125 1.125 0 0 0 2.25 0V15Z"},
  rhUiIcon: null,
};

export const RhUiColumnsFillIcon = createIconBase(RhUiColumnsFillIconConfig);

export default RhUiColumnsFillIcon;