import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsSwapRightLeftIconConfig: {
  name: 'RhMicronsSwapRightLeftIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M1 5a1 1 0 0 1 1-1h12V2a1 1 0 0 1 1.707-.707l2.647 2.646c.283.284.439.66.439 1.061s-.156.777-.44 1.06l-2.646 2.647A.999.999 0 0 1 14 8V6H2a1 1 0 0 1-1-1Zm17 9H6v-2a1 1 0 0 0-1.707-.707l-2.647 2.646c-.283.284-.439.66-.439 1.061s.156.777.44 1.06l2.646 2.647A.999.999 0 0 0 6 18v-2h12a1 1 0 1 0 0-2Z"},
  rhUiIcon: null,
};
export declare const RhMicronsSwapRightLeftIcon: ComponentClass<SVGIconProps>;
export default RhMicronsSwapRightLeftIcon;