import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardPlayIconConfig: {
  name: 'RhStandardPlayIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M5.61 32.62a.55.55 0 0 1-.31-.08A.61.61 0 0 1 5 32V4a.61.61 0 0 1 .31-.54.62.62 0 0 1 .62 0l24.78 14a.63.63 0 0 1 0 1.08l-24.78 14a.58.58 0 0 1-.32.08Zm.63-27.55v25.86L29.12 18Z"},
  rhUiIcon: null,
};
export declare const RhStandardPlayIcon: ComponentClass<SVGIconProps>;
export default RhStandardPlayIcon;