@use '../sass-utilities' as *;

.#{$pf-prefix}svg {
  // Default icon size
  width: 1em;
  height: 1em;
  vertical-align: -.125em;
}

.#{$pf-prefix}svg .#{$pf-prefix}icon-rh-ui {
  display: none;
}

.#{$pf-prefix}icon-set-rh-ui {
  .#{$pf-prefix}svg .#{$pf-prefix}icon-default {
    display: none;
  }

  .#{$pf-prefix}svg .#{$pf-prefix}icon-rh-ui {
    display: revert;
  }
}

.#{$pf-prefix}icon-rh-standard {
  width: 3rem;
  height: 3rem;
  color: var(--pf-t--global--icon--color--brand--accent--default);
}
