import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiConditionNodeIconConfig: {
  name: 'RhUiConditionNodeIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16.707 15.293A1 1 0 0 1 17 16v13a1 1 0 1 1-2 0V16.414l-11-11V10a1 1 0 1 1-2 0V3.5C2 2.673 2.673 2 3.5 2H10a1 1 0 1 1 0 2H5.414l11.293 11.293ZM28.5 2H22a1 1 0 1 0 0 2h4.586l-7.293 7.293a1 1 0 1 0 1.414 1.414L28 5.414V10a1 1 0 1 0 2 0V3.5c0-.827-.673-1.5-1.5-1.5Z"},
  rhUiIcon: null,
};
export declare const RhUiConditionNodeIcon: ComponentClass<SVGIconProps>;
export default RhUiConditionNodeIcon;