import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiRestoreWindowIconConfig: {
  name: 'RhUiRestoreWindowIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M24.5 8h-22C1.673 8 1 8.673 1 9.5v18c0 .827.673 1.5 1.5 1.5h22c.827 0 1.5-.673 1.5-1.5v-18c0-.827-.673-1.5-1.5-1.5ZM24 27H3V15h21v12Zm7-22.5V24a1 1 0 1 1-2 0V5H6a1 1 0 1 1 0-2h23.5c.827 0 1.5.673 1.5 1.5Z"},
  rhUiIcon: null,
};
export declare const RhUiRestoreWindowIcon: ComponentClass<SVGIconProps>;
export default RhUiRestoreWindowIcon;