import { createIconBase } from '../createIcon.js';

export const RhUiOffIconConfig = {
  name: 'RhUiOffIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm0 28C8.832 29 3 23.168 3 16S8.832 3 16 3s13 5.832 13 13-5.832 13-13 13Zm1-19v12a1 1 0 1 1-2 0V10a1 1 0 1 1 2 0Z"},
  rhUiIcon: null,
};

export const RhUiOffIcon = createIconBase(RhUiOffIconConfig);

export default RhUiOffIcon;