import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiPlayCircleFillIconConfig: {
  name: 'RhUiPlayCircleFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1.25C7.867 1.25 1.25 7.867 1.25 16S7.867 30.75 16 30.75 30.75 24.133 30.75 16 24.133 1.25 16 1.25Zm6.882 15.197-10.659 5.329a.505.505 0 0 1-.487-.022.5.5 0 0 1-.237-.425V10.672a.5.5 0 0 1 .723-.447l10.659 5.329a.5.5 0 0 1 0 .894Z"},
  rhUiIcon: null,
};
export declare const RhUiPlayCircleFillIcon: ComponentClass<SVGIconProps>;
export default RhUiPlayCircleFillIcon;