import { createIconBase } from '../createIcon.js';

export const RhStandardHarveyBall10IconConfig = {
  name: 'RhStandardHarveyBall10Icon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M18 3.375A14.625 14.625 0 1 0 32.625 18 14.642 14.642 0 0 0 18 3.375Zm0 28a13.366 13.366 0 0 1-.625-26.718V18a.624.624 0 0 0 .432.594.613.613 0 0 0 .193.031.626.626 0 0 0 .506-.258l7.845-10.8A13.363 13.363 0 0 1 18 31.375Z"},
  rhUiIcon: null,
};

export const RhStandardHarveyBall10Icon = createIconBase(RhStandardHarveyBall10IconConfig);

export default RhStandardHarveyBall10Icon;