import { createIconBase } from '../createIcon.js';

export const RhUiArrowCircleRightFillIconConfig = {
  name: 'RhUiArrowCircleRightFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm8.442 16.149-5.646 5.646a1.122 1.122 0 0 1-1.592 0 1.127 1.127 0 0 1 0-1.591l4.08-4.08H8a1.125 1.125 0 0 1 0-2.25h13.284l-4.08-4.08a1.127 1.127 0 0 1 0-1.591 1.127 1.127 0 0 1 1.592 0l5.646 5.646a1.628 1.628 0 0 1 0 2.298Z"},
  rhUiIcon: null,
};

export const RhUiArrowCircleRightFillIcon = createIconBase(RhUiArrowCircleRightFillIconConfig);

export default RhUiArrowCircleRightFillIcon;