import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiFlagIconConfig: {
  name: 'RhUiFlagIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M27.777 1.371A.998.998 0 0 0 27 1H5.5C4.673 1 4 1.673 4 2.5V30a1 1 0 1 0 2 0V17h18a1 1 0 0 0 .978-.791l3-14a1 1 0 0 0-.2-.838ZM23.191 15H6V3h19.763l-2.571 12Z"},
  rhUiIcon: null,
};
export declare const RhUiFlagIcon: ComponentClass<SVGIconProps>;
export default RhUiFlagIcon;