import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardObjectsPhoneMobileIconConfig: {
  name: 'RhStandardObjectsPhoneMobileIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M18 8.63a.62.62 0 1 0-.62-.63.61.61 0 0 0 .62.63Z"},{"path":"M25 4.38H11a.62.62 0 0 0-.62.62v26a.62.62 0 0 0 .62.62h14a.62.62 0 0 0 .62-.62V5a.62.62 0 0 0-.62-.62Zm-.62 26H11.62V5.62h12.76Z"},{"path":"M16 28.62h4a.62.62 0 0 0 0-1.24h-4a.62.62 0 1 0 0 1.24Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardObjectsPhoneMobileIcon: ComponentClass<SVGIconProps>;
export default RhStandardObjectsPhoneMobileIcon;