import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiCaretUpFillIconConfig: {
  name: 'RhUiCaretUpFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30.027 21a1 1 0 0 1-1 1H3a1 1 0 0 1-.707-1.707L14.939 7.646a1.501 1.501 0 0 1 2.121 0l12.521 12.522a.997.997 0 0 1 .445.832Z"},
  rhUiIcon: null,
};
export declare const RhUiCaretUpFillIcon: ComponentClass<SVGIconProps>;
export default RhUiCaretUpFillIcon;