import { createIconBase } from '../createIcon.js';

export const RhUiArrowRightIconConfig = {
  name: 'RhUiArrowRightIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30.354 14.939 19.708 4.293a.999.999 0 1 0-1.414 1.414L27.587 15H2a1 1 0 0 0 0 2h25.586l-9.293 9.293a.999.999 0 1 0 1.414 1.414l10.646-10.646c.283-.283.439-.66.439-1.061s-.156-.777-.439-1.061Z"},
  rhUiIcon: null,
};

export const RhUiArrowRightIcon = createIconBase(RhUiArrowRightIconConfig);

export default RhUiArrowRightIcon;