import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardHarveyBall25IconConfig: {
  name: 'RhStandardHarveyBall25Icon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M18 3.375A14.625 14.625 0 1 0 32.625 18 14.642 14.642 0 0 0 18 3.375Zm0 28a13.366 13.366 0 0 1-.625-26.718V18a.625.625 0 0 0 .625.625h13.343A13.38 13.38 0 0 1 18 31.375Z"},
  rhUiIcon: null,
};
export declare const RhStandardHarveyBall25Icon: ComponentClass<SVGIconProps>;
export default RhStandardHarveyBall25Icon;