import { createIconBase } from '../createIcon.js';

export const RhStandardHybridCloudInfrastructureIconConfig = {
  name: 'RhStandardHybridCloudInfrastructureIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M10.5 25.62H28a.75.75 0 0 0 .26-.05 5.11 5.11 0 0 0 .36-10 9.12 9.12 0 0 0-17.28-4.07 7.12 7.12 0 1 0-.84 14.19Zm0-13a5.93 5.93 0 0 1 1.09.11.64.64 0 0 0 .69-.36 7.87 7.87 0 0 1 15.1 3.13v.5a.63.63 0 0 0 .56.66 3.87 3.87 0 0 1-.41 7.71h-17a5.88 5.88 0 0 1 0-11.76ZM31 28.38H5a.62.62 0 1 0 0 1.24h26a.62.62 0 0 0 0-1.24Z"},
  rhUiIcon: null,
};

export const RhStandardHybridCloudInfrastructureIcon = createIconBase(RhStandardHybridCloudInfrastructureIconConfig);

export default RhStandardHybridCloudInfrastructureIcon;