import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiErrorIconConfig: {
  name: 'RhUiErrorIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M14.75 16V9a1.25 1.25 0 0 1 2.5 0v7a1.25 1.25 0 0 1-2.5 0ZM31 16c0 8.271-6.729 15-15 15S1 24.271 1 16 7.729 1 16 1s15 6.729 15 15Zm-2 0c0-7.168-5.832-13-13-13S3 8.832 3 16s5.832 13 13 13 13-5.832 13-13Zm-13 4.261a1.75 1.75 0 1 0 .001 3.501A1.75 1.75 0 0 0 16 20.261Z"},
  rhUiIcon: null,
};
export declare const RhUiErrorIcon: ComponentClass<SVGIconProps>;
export default RhUiErrorIcon;