import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiDocumentFillIconConfig: {
  name: 'RhUiDocumentFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M4.275 8.875a.738.738 0 0 1 .195-.405l7-7a.738.738 0 0 1 .405-.195v7.6h-7.6ZM26.5 1.25H14.125V9.5c0 .896-.729 1.625-1.625 1.625H4.25V29.5c0 .689.561 1.25 1.25 1.25h21c.689 0 1.25-.561 1.25-1.25v-27c0-.689-.561-1.25-1.25-1.25Z"},
  rhUiIcon: null,
};
export declare const RhUiDocumentFillIcon: ComponentClass<SVGIconProps>;
export default RhUiDocumentFillIcon;