import { createIconBase } from '../createIcon.js';

export const FolderCloseIconConfig = {
  name: 'FolderCloseIcon',
  icon: {"width":1088,"height":1024,"svgPathData":"M1088,256 C1088,256 1088,192 1024,192 L502.3,192 L469.6,130.1 C469.6,130.1 439,64 373.7,64 L64,64 C0,64 0,128 0,128 L0,960 L1088,960 L1088,256 Z"},
  rhUiIcon: null,
};

export const FolderCloseIcon = createIconBase(FolderCloseIconConfig);

export default FolderCloseIcon;