import { createIconBase } from '../createIcon.js';

export const RhUiCheckCircleFillIconConfig = {
  name: 'RhUiCheckCircleFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm7.795 11.795-8.646 8.646c-.317.317-.733.475-1.149.475s-.832-.158-1.149-.475l-4.646-4.646a1.126 1.126 0 0 1 1.591-1.591l4.205 4.205 8.205-8.205a1.126 1.126 0 0 1 1.591 1.591Z"},
  rhUiIcon: null,
};

export const RhUiCheckCircleFillIcon = createIconBase(RhUiCheckCircleFillIconConfig);

export default RhUiCheckCircleFillIcon;