import { MenuToggle } from '@patternfly/react-core';

export const MenuToggleFullWidth: React.FunctionComponent = () => (
  <MenuToggle isFullWidth aria-label="Full width menu toggle">
    Full width
  </MenuToggle>
);
