
// Do not edit directly
// Generated on Tue, 23 Jun 2026 19:20:00 GMT

// Only tokens that differ from base theme (14 tokens)
@mixin pf-v6-tokens {
  --pf-t--global--border--color--brand--accent--clicked: var(--pf-t--global--dark--color--brand--accent--400);
  --pf-t--global--border--color--brand--accent--default: var(--pf-t--global--dark--color--brand--accent--400);
  --pf-t--global--border--color--brand--accent--hover: var(--pf-t--global--dark--color--brand--accent--400);
  --pf-t--global--color--brand--accent--clicked: var(--pf-t--global--dark--color--brand--accent--200);
  --pf-t--global--color--brand--accent--default: var(--pf-t--global--dark--color--brand--accent--100);
  --pf-t--global--color--brand--accent--hover: var(--pf-t--global--dark--color--brand--accent--200);
  --pf-t--global--icon--color--brand--accent--clicked: var(--pf-t--global--dark--color--brand--accent--300);
  --pf-t--global--icon--color--brand--accent--hover: var(--pf-t--global--dark--color--brand--accent--300);
  --pf-t--global--icon--color--on-brand--accent--clicked: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--on-brand--accent--default: var(--pf-t--global--icon--color--regular);
  --pf-t--global--icon--color--on-brand--accent--hover: var(--pf-t--global--icon--color--regular);
  --pf-t--global--text--color--on-brand--accent--clicked: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--on-brand--accent--default: var(--pf-t--global--text--color--regular);
  --pf-t--global--text--color--on-brand--accent--hover: var(--pf-t--global--text--color--regular);
}
