import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsArrowLeftIconConfig: {
  name: 'RhMicronsArrowLeftIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M18 9H4.41L8.7 4.71c.4-.38.41-1.02.02-1.41a.987.987 0 0 0-1.41-.02l-.02.02-5.64 5.64c-.58.59-.58 1.53 0 2.12l5.65 5.65a.996.996 0 1 0 1.41-1.41l-4.29-4.29h13.59c.55 0 1-.45 1-1s-.45-1-1-1Z"},
  rhUiIcon: null,
};
export declare const RhMicronsArrowLeftIcon: ComponentClass<SVGIconProps>;
export default RhMicronsArrowLeftIcon;