import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardUnsecuredIconConfig: {
  name: 'RhStandardUnsecuredIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M23.66 28.7a10.38 10.38 0 0 1-16-8.7v-8a.62.62 0 0 0-1.24 0v8a11.62 11.62 0 0 0 18 9.74.62.62 0 1 0-.68-1Zm6.78.86-2.91-2.91A11.53 11.53 0 0 0 29.62 20V7.34a.61.61 0 0 0-.49-.61l-11-2.34a.57.57 0 0 0-.26 0L7.48 6.6l-2-2a.62.62 0 0 0-.88.88l25 25a.63.63 0 0 0 .88 0 .61.61 0 0 0-.04-.92ZM18 5.64l10.38 2.2V20a10.32 10.32 0 0 1-1.75 5.75L8.54 7.65Z"},
  rhUiIcon: null,
};
export declare const RhStandardUnsecuredIcon: ComponentClass<SVGIconProps>;
export default RhStandardUnsecuredIcon;