import { createIconBase } from '../createIcon.js';

export const RhStandardEnvelopeIconConfig = {
  name: 'RhStandardEnvelopeIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M31.62 27V9a.59.59 0 0 0-.23-.48.52.52 0 0 0-.39-.14H5a.62.62 0 0 0-.62.62v18a.62.62 0 0 0 .62.62h26a.62.62 0 0 0 .62-.62Zm-10.06-9.44L18 21.12l-3.56-3.56-7.93-7.94h23Zm-8.44.44-7.5 7.49v-15Zm.88.88 3.56 3.56a.63.63 0 0 0 .88 0L22 18.88l7.49 7.5h-23Zm8.88-.88 7.5-7.49v15Z"},
  rhUiIcon: null,
};

export const RhStandardEnvelopeIcon = createIconBase(RhStandardEnvelopeIconConfig);

export default RhStandardEnvelopeIcon;