import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiArrowUpRightIconConfig: {
  name: 'RhUiArrowUpRightIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M26.5 4H11a1 1 0 1 0 0 2h13.586L4.293 26.293a.999.999 0 1 0 1.414 1.414L26 7.414V21a1 1 0 1 0 2 0V5.5c0-.827-.673-1.5-1.5-1.5Z"},
  rhUiIcon: null,
};
export declare const RhUiArrowUpRightIcon: ComponentClass<SVGIconProps>;
export default RhUiArrowUpRightIcon;