import { createIconBase } from '../createIcon.js';

export const RhMicronsCaretLeftIconConfig = {
  name: 'RhMicronsCaretLeftIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"m6.41 10 7.29-7.29.02-.02c.38-.4.37-1.03-.02-1.41-.4-.38-1.03-.37-1.41.02L4.64 8.95a1.49 1.49 0 0 0 0 2.12l7.65 7.65c.19.19.44.29.71.29.27 0 .52-.11.71-.29a.996.996 0 0 0 0-1.41l-7.29-7.29Z"},
  rhUiIcon: null,
};

export const RhMicronsCaretLeftIcon = createIconBase(RhMicronsCaretLeftIconConfig);

export default RhMicronsCaretLeftIcon;