import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardYesIconConfig: {
  name: 'RhStandardYesIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M18 3.38A14.64 14.64 0 0 0 3.38 18c.8 19.4 28.44 19.4 29.25 0A14.65 14.65 0 0 0 18 3.38Zm0 28A13.39 13.39 0 0 1 4.62 18C5.36.26 30.64.26 31.38 18A13.39 13.39 0 0 1 18 31.38Z"},{"path":"M23.56 13.56 16 21.12l-3.56-3.56c-.56-.58-1.46.32-.88.88l4 4a.63.63 0 0 0 .88 0l8-8c.56-.56-.31-1.44-.88-.88Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardYesIcon: ComponentClass<SVGIconProps>;
export default RhStandardYesIcon;