import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const EllipsisHIconConfig: {
  name: 'EllipsisHIcon',
  icon: {"xOffset":0,"yOffset":0,"width":512,"height":512,"svgPathData":"M328 256c0 39.8-32.2 72-72 72s-72-32.2-72-72 32.2-72 72-72 72 32.2 72 72zm104-72c-39.8 0-72 32.2-72 72s32.2 72 72 72 72-32.2 72-72-32.2-72-72-72zm-352 0c-39.8 0-72 32.2-72 72s32.2 72 72 72 72-32.2 72-72-32.2-72-72-72z"},
  rhUiIcon: null,
};
export declare const EllipsisHIcon: ComponentClass<SVGIconProps>;
export default EllipsisHIcon;