import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiHarveyBall100IconConfig: {
  name: 'RhUiHarveyBall100Icon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M31 16c0 8.271-6.729 15-15 15S1 24.271 1 16 7.729 1 16 1s15 6.729 15 15Z"},
  rhUiIcon: null,
};
export declare const RhUiHarveyBall100Icon: ComponentClass<SVGIconProps>;
export default RhUiHarveyBall100Icon;