import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardElectricalBoltIconConfig: {
  name: 'RhStandardElectricalBoltIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M24.21 15.52a.64.64 0 0 0-.53-.28h-4V5a.62.62 0 0 0-1.19-.25L11.74 20a.63.63 0 0 0 .58.88h4v10.19a.63.63 0 0 0 1.19.26l6.78-15.21a.67.67 0 0 0-.08-.6Zm-6.67 12.61v-7.92a.63.63 0 0 0-.63-.63h-3.63l5.18-11.64v7.92a.63.63 0 0 0 .63.63h3.63Z"},
  rhUiIcon: null,
};
export declare const RhStandardElectricalBoltIcon: ComponentClass<SVGIconProps>;
export default RhStandardElectricalBoltIcon;