import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardKubernetesPodIconConfig: {
  name: 'RhStandardKubernetesPodIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"m24.31 14-6-3.47a.62.62 0 0 0-.62 0l-6 3.47a.6.6 0 0 0-.31.54v6.92a.6.6 0 0 0 .31.54l6 3.47a.64.64 0 0 0 .62 0l6-3.47a.6.6 0 0 0 .31-.54v-6.92a.6.6 0 0 0-.31-.54Zm-.93 7.1L18 24.21l-5.38-3.11v-6.2L18 11.79l5.38 3.11Z"},{"path":"M18 3.38A14.62 14.62 0 1 0 32.62 18 14.64 14.64 0 0 0 18 3.38Zm0 28A13.38 13.38 0 1 1 31.38 18 13.39 13.39 0 0 1 18 31.38Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardKubernetesPodIcon: ComponentClass<SVGIconProps>;
export default RhStandardKubernetesPodIcon;