import { createIconBase } from '../createIcon.js';

export const RhStandardMouseIconConfig = {
  name: 'RhStandardMouseIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M17.94 4.4A8.58 8.58 0 0 0 9.38 13v10.06a8.57 8.57 0 0 0 17.13 0V13a8.58 8.58 0 0 0-8.57-8.6Zm7.32 18.66a7.32 7.32 0 0 1-14.64 0V13a7.32 7.32 0 0 1 14.64 0Z"},{"path":"M17.94 8.38a.62.62 0 0 0-.62.62v7.45a.63.63 0 0 0 1.25 0V9a.62.62 0 0 0-.63-.62Z"}]},
  rhUiIcon: null,
};

export const RhStandardMouseIcon = createIconBase(RhStandardMouseIconConfig);

export default RhStandardMouseIcon;