import { createIconBase } from '../createIcon.js';

export const RhStandardAppIconConfig = {
  name: 'RhStandardAppIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M25 8.37a.63.63 0 0 0-.62.63.63.63 0 0 0 1.25 0 .63.63 0 0 0-.63-.63Zm2 0a.63.63 0 0 0-.62.63.63.63 0 0 0 1.25 0 .63.63 0 0 0-.63-.63Z"},{"path":"M31 4.38H5a.61.61 0 0 0-.62.62v26a.61.61 0 0 0 .62.62h26a.61.61 0 0 0 .62-.62V5a.61.61 0 0 0-.62-.62Zm-.62 26H5.62V5.62h24.76Z"}]},
  rhUiIcon: null,
};

export const RhStandardAppIcon = createIconBase(RhStandardAppIconConfig);

export default RhStandardAppIcon;