import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiPaperClipIconConfig: {
  name: 'RhUiPaperClipIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M25 6v16.5c0 4.687-3.813 8.5-8.5 8.5S8 27.187 8 22.5V7c0-3.309 2.691-6 6-6s6 2.691 6 6v15.5c0 1.93-1.57 3.5-3.5 3.5S13 24.43 13 22.5V8a1 1 0 1 1 2 0v14.5c0 .827.673 1.5 1.5 1.5s1.5-.673 1.5-1.5V7c0-2.206-1.794-4-4-4s-4 1.794-4 4v15.5c0 3.584 2.916 6.5 6.5 6.5s6.5-2.916 6.5-6.5V6a1 1 0 1 1 2 0Z"},
  rhUiIcon: null,
};
export declare const RhUiPaperClipIcon: ComponentClass<SVGIconProps>;
export default RhUiPaperClipIcon;