import { createIconBase } from '../createIcon.js';

export const BlackTieIconConfig = {
  name: 'BlackTieIcon',
  icon: {"xOffset":0,"yOffset":0,"width":448,"height":512,"svgPathData":"M0 32v448h448V32H0zm316.5 325.2L224 445.9l-92.5-88.7 64.5-184-64.5-86.6h184.9L252 173.2l64.5 184z"},
  rhUiIcon: null,
};

export const BlackTieIcon = createIconBase(BlackTieIconConfig);

export default BlackTieIcon;