import { createIconBase } from '../createIcon.js';

export const RhStandardFolderIconConfig = {
  name: 'RhStandardFolderIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M31 9.38h-3.71l-.52-2.47a.62.62 0 0 0-.61-.49h-7.32a.62.62 0 0 0-.61.49l-.52 2.47h-9.5a.62.62 0 0 0-.62.62v15a.63.63 0 0 0 1.25 0V10.62h9.37a.61.61 0 0 0 .61-.49l.53-2.46h6.3l.53 2.46a.61.61 0 0 0 .61.49h3.59v17.76H5.62V10a.62.62 0 0 0-1.24 0v19a.62.62 0 0 0 .62.62h26a.62.62 0 0 0 .62-.62V10a.62.62 0 0 0-.62-.62Z"},
  rhUiIcon: null,
};

export const RhStandardFolderIcon = createIconBase(RhStandardFolderIconConfig);

export default RhStandardFolderIcon;