.pf-v6-screen-reader {
  position: fixed;
  inset-block-start: 0;
  inset-inline-start: 0;
  overflow: hidden;
  white-space: nowrap;
  border: 0;
  clip-path: inset(50%);
}
.pf-v6-screen-reader.pf-m-full-size {
  width: 100%;
  height: 100%;
}
.pf-v6-screen-reader.pf-m-absolute {
  position: absolute;
}

.pf-v6-m-tabular-nums {
  font-variant-numeric: tabular-nums;
}

.pf-v6-m-legacy-font {
  --pf-t--global--font--family--body: var(--pf-t--global--font--family--body--legacy);
  --pf-t--global--font--family--heading: var(--pf-t--global--font--family--heading--legacy);
  --pf-t--global--font--family--mono: var(--pf-t--global--font--family--mono--legacy);
  --pf-t--global--font--weight--body: var(--pf-t--global--font--weight--body--legacy);
  --pf-t--global--font--weight--body--bold: var(--pf-t--global--font--weight--body--bold--legacy);
  --pf-t--global--font--weight--heading: var(--pf-t--global--font--weight--heading--legacy);
  --pf-t--global--font--weight--heading--bold: var(--pf-t--global--font--weight--heading--bold--legacy);
}

.pf-v6-m-dir-rtl {
  --pf-v6-global--inverse--multiplier: -1;
  direction: rtl;
}

.pf-v6-m-dir-ltr {
  --pf-v6-global--inverse--multiplier: 1;
  direction: ltr;
}

:where(.pf-v6-m-dir-rtl, [dir=rtl]) .pf-v6-m-mirror-inline-rtl {
  scale: -1 1;
}

.pf-v6-m-no-motion {
  --pf-t--global--delay--400: 1ms !important;
  --pf-t--global--delay--300: 1ms !important;
  --pf-t--global--delay--200: 1ms !important;
  --pf-t--global--delay--100: 1ms !important;
  --pf-t--global--duration--600: 1ms !important;
  --pf-t--global--duration--500: 1ms !important;
  --pf-t--global--duration--400: 1ms !important;
  --pf-t--global--duration--300: 1ms !important;
  --pf-t--global--duration--200: 1ms !important;
  --pf-t--global--duration--100: 1ms !important;
  --pf-t--global--duration--50: 1ms !important;
  --pf-v6-global--thinking-active--Animation--Duration: 0 !important;
}

.pf-v6-m-ai-indicator {
  position: relative;
}
.pf-v6-m-ai-indicator::before {
  position: absolute;
  inset: 0;
  pointer-events: none;
  content: "";
  background: linear-gradient(to right, #f56e6e 0%, #876fd4 65%, #5e40be 100%) border-box;
  border: var(--pf-t--global--border--width--extra-strong) solid transparent;
  border-radius: inherit;
  mask: linear-gradient(#000 0 0) padding-box, linear-gradient(#000 0 0);
  mask-composite: exclude;
}

@property --pf-v6-global--thinking--BoxShadow--Spread {
  syntax: "<length>";
  initial-value: 0;
  inherits: false;
}
.pf-v6-m-thinking {
  box-shadow: 0 0 var(--pf-v6-global--thinking--BoxShadow--Spread) var(--pf-v6-global--thinking--BoxShadow--Color--End-End), 0 0 var(--pf-v6-global--thinking--BoxShadow--Spread) var(--pf-v6-global--thinking--BoxShadow--Color--Start-End), 0 0 var(--pf-v6-global--thinking--BoxShadow--Spread) var(--pf-v6-global--thinking--BoxShadow--Color--End-Start), 0 0 var(--pf-v6-global--thinking--BoxShadow--Spread) var(--pf-v6-global--thinking--BoxShadow--Color--Start-Start);
  animation: pf-v6-global-thinking var(--pf-v6-global--thinking-active--Animation--Duration) infinite ease-in-out;
}
.pf-v6-m-thinking.pf-m-inset {
  box-shadow: inset 0 0 var(--pf-v6-global--thinking--BoxShadow--Spread) var(--pf-v6-global--thinking--BoxShadow--Color--End-End), inset 0 0 var(--pf-v6-global--thinking--BoxShadow--Spread) var(--pf-v6-global--thinking--BoxShadow--Color--Start-End), inset 0 0 var(--pf-v6-global--thinking--BoxShadow--Spread) var(--pf-v6-global--thinking--BoxShadow--Color--End-Start), inset 0 0 var(--pf-v6-global--thinking--BoxShadow--Spread) var(--pf-v6-global--thinking--BoxShadow--Color--Start-Start);
}

@keyframes pf-v6-global-thinking {
  50% {
    --pf-v6-global--thinking--BoxShadow--Spread: var(--pf-v6-global--thinking-active--BoxShadow--Spread);
  }
}
:root {
  --pf-v6-global--danger-jiggle--AnimationDuration--Transform: var(--pf-t--global--motion--duration--fade--default);
  --pf-v6-global--danger-jiggle--AnimationTimingFunction--Transform: var(--pf-t--global--motion--timing-function--default);
  --pf-v6-global--thinking--BoxShadow--Spread: 0px;
  --pf-v6-global--thinking--BoxShadow--Color--Start-Start: oklch(45.9% 0.187 3.815deg);
  --pf-v6-global--thinking--BoxShadow--Color--Start-End: oklch(50% 0.134 242.749deg);
  --pf-v6-global--thinking--BoxShadow--Color--End-Start: oklch(45.9% 0.187 3.815deg);
  --pf-v6-global--thinking--BoxShadow--Color--End-End: oklch(43.2% 0.232 292.759deg);
  --pf-v6-global--thinking-active--BoxShadow--Spread: 15px;
  --pf-v6-global--thinking-active--Animation--Duration: 0;
}
@media screen and (prefers-reduced-motion: no-preference) {
  :root {
    --pf-v6-global--thinking-active--Animation--Duration: 2s;
  }
}
:root {
  container-name: pf-v6-contain-viewport pf-v6-contain-table;
  container-type: inline-size;
}

@property --pf-v6-global--danger-jiggle--TranslateX {
  syntax: "<length>";
  inherits: false;
  initial-value: 0;
}
@keyframes pf-v6-global-danger-jiggle-motion {
  33% {
    --pf-v6-global--danger-jiggle--TranslateX: -2px;
  }
  66% {
    --pf-v6-global--danger-jiggle--TranslateX: 3px;
  }
}
@keyframes pf-v6-global-fade-in {
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}
@keyframes pf-v6-global-fade-out {
  from {
    opacity: 1;
  }
  to {
    opacity: 0;
  }
}