import { Grid, GridItem } from '@patternfly/react-core';

export const GridAlternativeComponents: React.FunctionComponent = () => (
  <Grid component="ul">
    <GridItem component="li">Grid item</GridItem>
    <GridItem component="li">Grid item</GridItem>
    <GridItem component="li">Grid item</GridItem>
    <GridItem component="li">Grid item</GridItem>
    <GridItem component="li">Grid item</GridItem>
  </Grid>
);
