import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsCaretRightIconConfig: {
  name: 'RhMicronsCaretRightIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M14.35 8.94 6.71 1.29l-.02-.02c-.4-.38-1.03-.37-1.41.02-.38.4-.37 1.03.02 1.41l7.29 7.29-7.29 7.29a1.003 1.003 0 0 0 1.42 1.42l7.65-7.65c.59-.59.59-1.54 0-2.12Z"},
  rhUiIcon: null,
};
export declare const RhMicronsCaretRightIcon: ComponentClass<SVGIconProps>;
export default RhMicronsCaretRightIcon;