import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiHarveyBall90IconConfig: {
  name: 'RhUiHarveyBall90Icon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1a14.84 14.84 0 0 0-8.82 2.872l-.002.002A15.032 15.032 0 0 0 1 16c0 8.271 6.729 15 15 15s15-6.729 15-15S24.271 1 16 1Zm-1 11.924L9.188 4.929A12.831 12.831 0 0 1 15 3.037v9.887Z"},
  rhUiIcon: null,
};
export declare const RhUiHarveyBall90Icon: ComponentClass<SVGIconProps>;
export default RhUiHarveyBall90Icon;