import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardMonitorBlankIconConfig: {
  name: 'RhStandardMonitorBlankIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M31 6.38H5a.62.62 0 0 0-.62.62v17a.62.62 0 0 0 .62.62h10.38v3.76H9a.62.62 0 1 0 0 1.24h18a.62.62 0 0 0 0-1.24h-6.38v-3.76H31a.62.62 0 0 0 .62-.62V7a.62.62 0 0 0-.62-.62Zm-11.62 22h-2.76v-3.76h2.76Zm11-5H5.62V7.62h24.76Z"},
  rhUiIcon: null,
};
export declare const RhStandardMonitorBlankIcon: ComponentClass<SVGIconProps>;
export default RhStandardMonitorBlankIcon;