import { createIconBase } from '../createIcon.js';

export const RhUiEnterpriseFillIconConfig = {
  name: 'RhUiEnterpriseFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M17.125 31v-8.875h3.75V31h-3.75Zm-6 0h3.75v-8.875h-3.75V31ZM29 2.5v27c0 .827-.673 1.5-1.5 1.5h-4.375v-9.5c0-.896-.729-1.625-1.625-1.625h-11c-.896 0-1.625.729-1.625 1.625V31H4.5c-.827 0-1.5-.673-1.5-1.5v-27C3 1.673 3.673 1 4.5 1h23c.827 0 1.5.673 1.5 1.5ZM9 9H5v4h4V9Zm0-6H5v4h4V3Zm6 6h-4v4h4V9Zm0-6h-4v4h4V3Zm6 6h-4v4h4V9Zm0-6h-4v4h4V3Zm6 6h-4v4h4V9Zm0-6h-4v4h4V3Z"},
  rhUiIcon: null,
};

export const RhUiEnterpriseFillIcon = createIconBase(RhUiEnterpriseFillIconConfig);

export default RhUiEnterpriseFillIcon;