import { createIconBase } from '../createIcon.js';

export const RhUiAutoLightDarkModeIconConfig = {
  name: 'RhUiAutoLightDarkModeIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 2C8.28 2 2 8.28 2 16s6.28 14 14 14 14-6.28 14-14S23.72 2 16 2Zm0 26C9.383 28 4 22.617 4 16S9.383 4 16 4s12 5.383 12 12-5.383 12-12 12Zm9-12a9 9 0 0 1-8.738 8.996.259.259 0 0 1-.262-.257V7.26c0-.142.12-.261.262-.257A9 9 0 0 1 25 15.999Z"},
  rhUiIcon: null,
};

export const RhUiAutoLightDarkModeIcon = createIconBase(RhUiAutoLightDarkModeIconConfig);

export default RhUiAutoLightDarkModeIcon;