import { createIconBase } from '../createIcon.js';

export const RhUiArrowDownIconConfig = {
  name: 'RhUiArrowDownIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M27.707 19.707 17.061 30.353c-.292.292-.676.438-1.061.438s-.768-.146-1.061-.438L4.293 19.707a.999.999 0 1 1 1.414-1.414L15 27.586V2a1 1 0 0 1 2 0v25.586l9.293-9.293a.999.999 0 1 1 1.414 1.414Z"},
  rhUiIcon: null,
};

export const RhUiArrowDownIcon = createIconBase(RhUiArrowDownIconConfig);

export default RhUiArrowDownIcon;