import { createIconBase } from '../createIcon.js';

export const IceCreamIconConfig = {
  name: 'IceCreamIcon',
  icon: {"xOffset":0,"yOffset":0,"width":448,"height":512,"svgPathData":"M368 160h-.94a144 144 0 1 0-286.12 0H80a48 48 0 0 0 0 96h288a48 48 0 0 0 0-96zM195.38 493.69a31.52 31.52 0 0 0 57.24 0L352 288H96z"},
  rhUiIcon: null,
};

export const IceCreamIcon = createIconBase(IceCreamIconConfig);

export default IceCreamIcon;