import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardCompletedProductIconConfig: {
  name: 'RhStandardCompletedProductIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M14.9 21.69c-.56-.58-1.46.32-.88.88l2.12 2.13a.64.64 0 0 0 .89 0l4.95-5c.58-.56-.32-1.47-.88-.88l-4.52 4.51Z"},{"path":"m32.54 30.08-14-24.78a.64.64 0 0 0-1.08 0l-14 24.78A.62.62 0 0 0 4 31h28a.62.62 0 0 0 .54-.92Zm-27.47-.32L18 6.88l12.93 22.88Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardCompletedProductIcon: ComponentClass<SVGIconProps>;
export default RhStandardCompletedProductIcon;