import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardMagnifyingGlassIconConfig: {
  name: 'RhStandardMagnifyingGlassIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M14.5 4.38A10.12 10.12 0 1 0 24.62 14.5 10.13 10.13 0 0 0 14.5 4.38Zm0 19a8.88 8.88 0 1 1 8.88-8.88 8.9 8.9 0 0 1-8.88 8.88Zm16.94 7.18-6-6c-.56-.58-1.46.32-.88.88l6 6a.62.62 0 0 0 .88-.88Z"},{"path":"M14.5 7.38a7.12 7.12 0 0 0-7.12 7.12.62.62 0 1 0 1.24 0 5.89 5.89 0 0 1 5.88-5.88.62.62 0 0 0 0-1.24Zm8.5 15a.63.63 0 1 0 .62.62.62.62 0 0 0-.62-.62Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardMagnifyingGlassIcon: ComponentClass<SVGIconProps>;
export default RhStandardMagnifyingGlassIcon;