import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsCaretLeftFillIconConfig: {
  name: 'RhMicronsCaretLeftFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"M13 3v14a.998.998 0 0 1-1.76.65l-5.72-6.674a1.49 1.49 0 0 1 0-1.953l5.72-6.673A.998.998 0 0 1 13 3Z"},
  rhUiIcon: null,
};
export declare const RhMicronsCaretLeftFillIcon: ComponentClass<SVGIconProps>;
export default RhMicronsCaretLeftFillIcon;