import { createIconBase } from '../createIcon.js';

export const RhUiOffFillIconConfig = {
  name: 'RhUiOffFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm1.125 21a1.125 1.125 0 0 1-2.25 0V10a1.125 1.125 0 0 1 2.25 0v12Z"},
  rhUiIcon: null,
};

export const RhUiOffFillIcon = createIconBase(RhUiOffFillIconConfig);

export default RhUiOffFillIcon;