import { createIconBase } from '../createIcon.js';

export const RhStandardFilterIconConfig = {
  name: 'RhStandardFilterIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M20 31.62h-4A1.61 1.61 0 0 1 14.38 30v-8.74l-9.82-9.82a.6.6 0 0 1-.18-.44V5A.61.61 0 0 1 5 4.38h26a.61.61 0 0 1 .62.62v6a.6.6 0 0 1-.18.44l-9.82 9.82V30A1.61 1.61 0 0 1 20 31.62ZM5.62 10.74l9.82 9.82a.59.59 0 0 1 .18.44v9a.38.38 0 0 0 .38.38h4a.38.38 0 0 0 .38-.38v-9a.59.59 0 0 1 .18-.44l9.82-9.82V5.62H5.62Z"},
  rhUiIcon: null,
};

export const RhStandardFilterIcon = createIconBase(RhStandardFilterIconConfig);

export default RhStandardFilterIcon;