import { createIconBase } from '../createIcon.js';

export const RhUiPanelOpenFillIconConfig = {
  name: 'RhUiPanelOpenFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30 3.5v25c0 .827-.673 1.5-1.5 1.5h-4c-.827 0-1.5-.673-1.5-1.5v-25c0-.827.673-1.5 1.5-1.5h4c.827 0 1.5.673 1.5 1.5ZM12.707 8.293a.999.999 0 1 0-1.414 1.414L16.586 15H3a1 1 0 1 0 0 2h13.586l-5.293 5.293a.999.999 0 1 0 1.414 1.414l6.646-6.646a1.501 1.501 0 0 0 0-2.121l-6.646-6.646Z"},
  rhUiIcon: null,
};

export const RhUiPanelOpenFillIcon = createIconBase(RhUiPanelOpenFillIconConfig);

export default RhUiPanelOpenFillIcon;