import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiCalendarFillIconConfig: {
  name: 'RhUiCalendarFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M2.01 11.875V6.5c0-.827.673-1.5 1.5-1.5H9V3a1 1 0 1 1 2 0v2h10V3a1 1 0 1 1 2 0v2h5.5c.827 0 1.5.673 1.5 1.5v5.375H2.01Zm6.865 17.414v-6.164H2.711l6.164 6.164ZM2.01 14.125v6.75H9.5c.896 0 1.625.729 1.625 1.625V30H28.5c.827 0 1.5-.673 1.5-1.5V14.125H2.01Z"},
  rhUiIcon: null,
};
export declare const RhUiCalendarFillIcon: ComponentClass<SVGIconProps>;
export default RhUiCalendarFillIcon;