import { createIconBase } from '../createIcon.js';

export const RhUiArrowDownLeftIconConfig = {
  name: 'RhUiArrowDownLeftIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M27.707 5.707 7.414 26H21a1 1 0 1 1 0 2H5.5c-.827 0-1.5-.673-1.5-1.5V11a1 1 0 1 1 2 0v13.586L26.293 4.293a.999.999 0 1 1 1.414 1.414Z"},
  rhUiIcon: null,
};

export const RhUiArrowDownLeftIcon = createIconBase(RhUiArrowDownLeftIconConfig);

export default RhUiArrowDownLeftIcon;