import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const ItalicIconConfig: {
  name: 'ItalicIcon',
  icon: {"xOffset":0,"yOffset":0,"width":320,"height":512,"svgPathData":"M320 48v32a16 16 0 0 1-16 16h-62.76l-80 320H208a16 16 0 0 1 16 16v32a16 16 0 0 1-16 16H16a16 16 0 0 1-16-16v-32a16 16 0 0 1 16-16h62.76l80-320H112a16 16 0 0 1-16-16V48a16 16 0 0 1 16-16h192a16 16 0 0 1 16 16z"},
  rhUiIcon: null,
};
export declare const ItalicIcon: ComponentClass<SVGIconProps>;
export default ItalicIcon;