
// Do not edit directly
// Generated on Tue, 23 Jun 2026 19:20:00 GMT

// Only tokens that differ from base theme (19 tokens)
@mixin pf-v6-tokens {
  --pf-t--global--background--color--glass--primary--default: rgb(41, 41, 41, 0.5000);
  --pf-t--global--background--color--primary--clicked: rgb(56, 56, 56, 0.5000);
  --pf-t--global--background--color--primary--default: rgb(41, 41, 41, 0.5000);
  --pf-t--global--background--color--primary--hover: rgb(56, 56, 56, 0.5000);
  --pf-t--global--background--color--secondary--clicked: rgb(41, 41, 41, 0.6000);
  --pf-t--global--background--color--secondary--default: rgb(21, 21, 21, 0.6000);
  --pf-t--global--background--color--secondary--hover: rgb(41, 41, 41, 0.6000);
  --pf-t--global--background--filter--glass--blur--primary: blur(16px);
  --pf-t--global--background--color--control--default: var(--pf-t--global--dark--background--color--500);
  --pf-t--global--background--color--control--read-only: var(--pf-t--global--dark--background--color--500);
  --pf-t--global--background--color--action--plain--alt--clicked: var(--pf-t--global--background--color--action--plain--clicked);
  --pf-t--global--background--color--action--plain--alt--hover: var(--pf-t--global--background--color--action--plain--hover);
  --pf-t--global--background--color--floating--clicked: var(--pf-t--global--dark--background--color--300);
  --pf-t--global--background--color--floating--default: var(--pf-t--global--dark--background--color--200);
  --pf-t--global--background--color--floating--hover: var(--pf-t--global--dark--background--color--300);
  --pf-t--global--border--color--control--read-only: var(--pf-t--global--dark--border--color--50);
  --pf-t--global--border--color--glass--default: var(--pf-t--global--border--color--alt);
  --pf-t--global--border--color--subtle: var(--pf-t--global--dark--border--color--50);
  --pf-t--global--background--color--floating--secondary--default: var(--pf-t--global--background--color--floating--default);
}
