#ws-react-c-compass-basic [class*="pf-v6-c-compass"] {
  position: relative;
}

#ws-react-c-compass-basic [class*="pf-v6-c-compass"]::after {
  content: "";
  position: absolute;
  inset: 0;
  border: var(--pf-t--global--border--width--regular) dashed var(--pf-t--global--border--color--default);
  pointer-events: none;
}

#ws-react-c-compass-with-alternate-footer [class*="pf-v6-c-compass"] {
  position: relative;
}

#ws-react-c-compass-with-alternate-footer [class*="pf-v6-c-compass"]:not([class*="footer"])::after {
  content: "";
  position: absolute;
  inset: 0;
  border: var(--pf-t--global--border--width--regular) dashed var(--pf-t--global--border--color--default);
  pointer-events: none;
}

#ws-react-c-compass-with-docked-nav [class*="pf-v6-c-compass"] {
  position: relative;
}

#ws-react-c-compass-with-docked-nav [class*="pf-v6-c-compass"]:not([class*="footer"])::after {
  content: "";
  position: absolute;
  inset: 0;
  border: var(--pf-t--global--border--width--regular) dashed var(--pf-t--global--border--color--default);
  pointer-events: none;
}
