import { createIconBase } from '../createIcon.js';

export const RhUiAddCircleIconConfig = {
  name: 'RhUiAddCircleIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm0 28C8.832 29 3 23.168 3 16S8.832 3 16 3s13 5.832 13 13-5.832 13-13 13Zm8-13a1 1 0 0 1-1 1h-6v6a1 1 0 0 1-2 0v-6H9a1 1 0 0 1 0-2h6V9a1 1 0 0 1 2 0v6h6a1 1 0 0 1 1 1Z"},
  rhUiIcon: null,
};

export const RhUiAddCircleIcon = createIconBase(RhUiAddCircleIconConfig);

export default RhUiAddCircleIcon;