import { createIconBase } from '../createIcon.js';

export const RhUiColumnsIconConfig = {
  name: 'RhUiColumnsIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M15 24V14a1 1 0 0 1 2 0v10a1 1 0 0 1-2 0ZM31 4.5v23c0 .827-.673 1.5-1.5 1.5h-27c-.827 0-1.5-.673-1.5-1.5v-23C1 3.673 1.673 3 2.5 3h27c.827 0 1.5.673 1.5 1.5ZM29 11H3v16h26V11Z"},
  rhUiIcon: null,
};

export const RhUiColumnsIcon = createIconBase(RhUiColumnsIconConfig);

export default RhUiColumnsIcon;