import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardShieldIconConfig: {
  name: 'RhStandardShieldIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"m29.13 6.73-11-2.34a.57.57 0 0 0-.26 0l-11 2.34a.61.61 0 0 0-.49.61V20a11.62 11.62 0 0 0 23.24 0V7.34a.61.61 0 0 0-.49-.61ZM18 5.64l10.38 2.2v5.61L7.62 17.86v-10Zm0 24.74A10.4 10.4 0 0 1 7.62 20v-.86l20.76-4.41V20A10.4 10.4 0 0 1 18 30.38Z"},
  rhUiIcon: null,
};
export declare const RhStandardShieldIcon: ComponentClass<SVGIconProps>;
export default RhStandardShieldIcon;