@use '../../sass-utilities/' as *;

@mixin pf-v6-tokens {
  --pf-t--global--background--image--default: var(--pf-t--global--background--image--felt--glass--dark, url("#{$pf-v6-global--image-path}/Felt-Bkg-Generic-Dark.svg"));
}
