import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiHarveyBall66IconConfig: {
  name: 'RhUiHarveyBall66Icon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16c0 2.854.808 5.634 2.336 8.037l.004.005A14.922 14.922 0 0 0 15.999 31c8.271 0 15-6.729 15-15S24.271 1 16 1Zm-1 2.038V15.45L4.52 22.099A12.943 12.943 0 0 1 3 16C3 9.168 8.297 3.551 15 3.038Z"},
  rhUiIcon: null,
};
export declare const RhUiHarveyBall66Icon: ComponentClass<SVGIconProps>;
export default RhUiHarveyBall66Icon;