import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiElectricityFillIconConfig: {
  name: 'RhUiElectricityFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"m22.916 14.401-7 16a.998.998 0 0 1-1.121.578A1 1 0 0 1 14 30V19h-4a.999.999 0 0 1-.916-1.401l7-16A1 1 0 0 1 18 2v11h4a.999.999 0 0 1 .916 1.401Z"},
  rhUiIcon: null,
};
export declare const RhUiElectricityFillIcon: ComponentClass<SVGIconProps>;
export default RhUiElectricityFillIcon;