import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhMicronsCaretUpIconConfig: {
  name: 'RhMicronsCaretUpIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"m18.71 13.29-7.65-7.65a1.49 1.49 0 0 0-2.12 0l-7.65 7.65-.02.02c-.38.4-.37 1.03.02 1.41.4.38 1.03.37 1.41-.02l7.29-7.29 7.29 7.29c.19.19.44.29.71.29.27 0 .52-.11.71-.29a.996.996 0 0 0 0-1.41Z"},
  rhUiIcon: null,
};
export declare const RhMicronsCaretUpIcon: ComponentClass<SVGIconProps>;
export default RhMicronsCaretUpIcon;