import { createIconBase } from '../createIcon.js';

export const FlipboardIconConfig = {
  name: 'FlipboardIcon',
  icon: {"xOffset":0,"yOffset":0,"width":448,"height":512,"svgPathData":"M0 32v448h448V32H0zm358.4 179.2h-89.6v89.6h-89.6v89.6H89.6V121.6h268.8v89.6z"},
  rhUiIcon: null,
};

export const FlipboardIcon = createIconBase(FlipboardIconConfig);

export default FlipboardIcon;