import { createIconBase } from '../createIcon.js';

export const EggIconConfig = {
  name: 'EggIcon',
  icon: {"xOffset":0,"yOffset":0,"width":384,"height":512,"svgPathData":"M192 0C86 0 0 214 0 320s86 192 192 192 192-86 192-192S298 0 192 0z"},
  rhUiIcon: null,
};

export const EggIcon = createIconBase(EggIconConfig);

export default EggIcon;