import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiArrowCircleUpRightFillIconConfig: {
  name: 'RhUiArrowCircleUpRightFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm7.125 18a1.125 1.125 0 0 1-2.25 0v-6.284l-10.08 10.08c-.22.22-.507.329-.795.329s-.576-.109-.795-.329a1.127 1.127 0 0 1 0-1.592l10.079-10.079H13a1.125 1.125 0 0 1 0-2.25h8.5c.896 0 1.625.729 1.625 1.625V19Z"},
  rhUiIcon: null,
};
export declare const RhUiArrowCircleUpRightFillIcon: ComponentClass<SVGIconProps>;
export default RhUiArrowCircleUpRightFillIcon;