import { createIconBase } from '../createIcon.js';

export const RhStandardPodiumPresentationIconConfig = {
  name: 'RhStandardPodiumPresentationIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M29 31.62a.62.62 0 0 0 0-1.24h-4.38V16.62H27a.62.62 0 0 0 .62-.62v-6a.62.62 0 0 0-.62-.62h-2.38V6a.62.62 0 0 0-.62-.62h-2.5a1.63 1.63 0 0 0-1.5-1h-4a1.62 1.62 0 1 0 0 3.24h4a1.63 1.63 0 0 0 1.5-1h1.88v2.76H9a.62.62 0 0 0-.62.62v6a.62.62 0 0 0 .62.62h2.38v13.76H7a.62.62 0 1 0 0 1.24ZM20 6.38h-4a.38.38 0 1 1 0-.76h4a.38.38 0 1 1 0 .76Zm-10.38 9v-4.76h16.76v4.76Zm3 15V16.62h10.76v13.76Z"},
  rhUiIcon: null,
};

export const RhStandardPodiumPresentationIcon = createIconBase(RhStandardPodiumPresentationIconConfig);

export default RhStandardPodiumPresentationIcon;