import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const OutlinedCaretSquareDownIconConfig: {
  name: 'OutlinedCaretSquareDownIcon',
  icon: {"xOffset":0,"yOffset":0,"width":448,"height":512,"svgPathData":"M125.1 208h197.8c10.7 0 16.1 13 8.5 20.5l-98.9 98.3c-4.7 4.7-12.2 4.7-16.9 0l-98.9-98.3c-7.7-7.5-2.3-20.5 8.4-20.5zM448 80v352c0 26.5-21.5 48-48 48H48c-26.5 0-48-21.5-48-48V80c0-26.5 21.5-48 48-48h352c26.5 0 48 21.5 48 48zm-48 346V86c0-3.3-2.7-6-6-6H54c-3.3 0-6 2.7-6 6v340c0 3.3 2.7 6 6 6h340c3.3 0 6-2.7 6-6z"},
  rhUiIcon: null,
};
export declare const OutlinedCaretSquareDownIcon: ComponentClass<SVGIconProps>;
export default OutlinedCaretSquareDownIcon;