import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiCompressIconConfig: {
  name: 'RhUiCompressIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M21 9.5V3a1 1 0 1 1 2 0v6h6a1 1 0 1 1 0 2h-6.5c-.827 0-1.5-.673-1.5-1.5ZM10 2a1 1 0 0 0-1 1v6H3a1 1 0 1 0 0 2h6.5c.827 0 1.5-.673 1.5-1.5V3a1 1 0 0 0-1-1Zm-.5 19H3a1 1 0 1 0 0 2h6v6a1 1 0 1 0 2 0v-6.5c0-.827-.673-1.5-1.5-1.5ZM29 21h-6.5c-.827 0-1.5.673-1.5 1.5V29a1 1 0 1 0 2 0v-6h6a1 1 0 1 0 0-2Z"},
  rhUiIcon: null,
};
export declare const RhUiCompressIcon: ComponentClass<SVGIconProps>;
export default RhUiCompressIcon;