import { createIconBase } from '../createIcon.js';

export const RhUiMicrophoneFillIconConfig = {
  name: 'RhUiMicrophoneFillIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M9 15V8c0-3.859 3.14-7 7-7s7 3.141 7 7v7c0 3.859-3.14 7-7 7s-7-3.141-7-7Zm18 0a1 1 0 1 0-2 0c0 4.963-4.038 9-9 9s-9-4.037-9-9a1 1 0 1 0-2 0c0 5.731 4.407 10.447 10.01 10.95 0 .018-.01.032-.01.05v2.021h-4.98a1 1 0 1 0 0 2H22a1 1 0 1 0 0-2h-5V26c0-.018-.009-.033-.01-.05C22.593 25.447 27 20.731 27 15Z"},
  rhUiIcon: null,
};

export const RhUiMicrophoneFillIcon = createIconBase(RhUiMicrophoneFillIconConfig);

export default RhUiMicrophoneFillIcon;