import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardUploadIconConfig: {
  name: 'RhStandardUploadIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M31 30.38H5a.62.62 0 0 0 0 1.24h26a.62.62 0 0 0 0-1.24ZM10 13.62a.62.62 0 0 0 .44-.18l6.94-6.93V27a.62.62 0 0 0 1.24 0V6.51l6.94 6.93a.62.62 0 0 0 .88-.88l-8-8a.62.62 0 0 0-.83 0c-.06 0-8 8-8 8a.62.62 0 0 0 .39 1.06Z"},
  rhUiIcon: null,
};
export declare const RhStandardUploadIcon: ComponentClass<SVGIconProps>;
export default RhStandardUploadIcon;