import { createIconBase } from '../createIcon.js';

export const RhStandardHarveyBall50IconConfig = {
  name: 'RhStandardHarveyBall50Icon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M18 3.375A14.625 14.625 0 1 0 32.625 18 14.642 14.642 0 0 0 18 3.375ZM4.625 18a13.38 13.38 0 0 1 12.75-13.343v26.686A13.38 13.38 0 0 1 4.625 18Z"},
  rhUiIcon: null,
};

export const RhStandardHarveyBall50Icon = createIconBase(RhStandardHarveyBall50IconConfig);

export default RhStandardHarveyBall50Icon;