import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardJoystickControllerIconConfig: {
  name: 'RhStandardJoystickControllerIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M31 23.375H14.772l2.097-9.867a3.64 3.64 0 1 0-3.197-.753l-2.257 10.62H5a.625.625 0 0 0-.625.625v5a.625.625 0 0 0 .625.625h26a.625.625 0 0 0 .625-.625v-5a.625.625 0 0 0-.625-.625ZM16 7.625A2.375 2.375 0 1 1 13.625 10 2.378 2.378 0 0 1 16 7.625Zm-1.189 5.783a3.581 3.581 0 0 0 .765.174l-2.082 9.793h-.801Zm15.564 14.967H5.625v-3.75h24.75Z"},{"path":"M23 22.625h3a.625.625 0 0 0 0-1.25h-3a.625.625 0 0 0 0 1.25Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardJoystickControllerIcon: ComponentClass<SVGIconProps>;
export default RhStandardJoystickControllerIcon;