import { createIconBase } from '../createIcon.js';

export const RhUiApplicationIconConfig = {
  name: 'RhUiApplicationIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M28.5 2h-25C2.673 2 2 2.673 2 3.5v25c0 .827.673 1.5 1.5 1.5h25c.827 0 1.5-.673 1.5-1.5v-25c0-.827-.673-1.5-1.5-1.5ZM28 28H4V4h24v24ZM15.38 9.003a1.626 1.626 0 1 1 3.251.001 1.626 1.626 0 0 1-3.251-.001Zm6 .005a1.626 1.626 0 1 1 3.251.001 1.626 1.626 0 0 1-3.251-.001Z"},
  rhUiIcon: null,
};

export const RhUiApplicationIcon = createIconBase(RhUiApplicationIconConfig);

export default RhUiApplicationIcon;