import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiForwardIconConfig: {
  name: 'RhUiForwardIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29.793 11c0 .4-.156.777-.439 1.061l-7.646 7.646a.997.997 0 0 1-1.414 0 .999.999 0 0 1 0-1.414L26.587 12H13.001c-4.962 0-9 4.038-9 9v8a1 1 0 0 1-2 0v-8c0-6.065 4.935-11 11-11h13.586l-6.293-6.293a.999.999 0 1 1 1.414-1.414l7.646 7.646c.283.283.439.66.439 1.061Z"},
  rhUiIcon: null,
};
export declare const RhUiForwardIcon: ComponentClass<SVGIconProps>;
export default RhUiForwardIcon;