import { __rest } from "tslib";
import { jsx as _jsx } from "react/jsx-runtime";
import styles from '@patternfly/react-styles/css/components/Compass/compass.mjs';
import { css } from '@patternfly/react-styles';
export const CompassMessageBar = (_a) => {
    var { children, className } = _a, props = __rest(_a, ["children", "className"]);
    return (_jsx("div", Object.assign({ className: css(styles.compassMessageBar, className) }, props, { children: children })));
};
CompassMessageBar.displayName = 'CompassMessageBar';
//# sourceMappingURL=CompassMessageBar.js.map