import { createIconBase } from '../createIcon.js';

export const RhUiCommentIconConfig = {
  name: 'RhUiCommentIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M29.5 4h-27C1.673 4 1 4.673 1 5.5v16c0 .827.673 1.5 1.5 1.5H8v6a1.002 1.002 0 0 0 1.707.707L16.414 23H29.5c.827 0 1.5-.673 1.5-1.5v-16c0-.827-.673-1.5-1.5-1.5ZM29 21H16a.997.997 0 0 0-.707.293L10 26.586V22.5c0-.827-.673-1.5-1.5-1.5H3V6h26v15Z"},
  rhUiIcon: null,
};

export const RhUiCommentIcon = createIconBase(RhUiCommentIconConfig);

export default RhUiCommentIcon;