import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardViewIconConfig: {
  name: 'RhStandardViewIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M32.52 17.65c-6.74-10.18-22.3-10.18-29 0a.64.64 0 0 0 0 .7c6.74 10.18 22.3 10.18 29 0a.64.64 0 0 0 0-.7ZM18 24.78A16.31 16.31 0 0 1 4.76 18C11.05 9 25 9 31.24 18A16.31 16.31 0 0 1 18 24.78Z"},{"path":"M18 13.38c-6.11.19-6.11 9 0 9.25 6.11-.2 6.11-9.06 0-9.25Zm0 8a3.38 3.38 0 0 1 0-6.75 3.38 3.38 0 0 1 0 6.75Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardViewIcon: ComponentClass<SVGIconProps>;
export default RhStandardViewIcon;