import { createIconBase } from '../createIcon.js';

export const GripLinesIconConfig = {
  name: 'GripLinesIcon',
  icon: {"xOffset":0,"yOffset":0,"width":512,"height":512,"svgPathData":"M496 288H16c-8.8 0-16 7.2-16 16v32c0 8.8 7.2 16 16 16h480c8.8 0 16-7.2 16-16v-32c0-8.8-7.2-16-16-16zm0-128H16c-8.8 0-16 7.2-16 16v32c0 8.8 7.2 16 16 16h480c8.8 0 16-7.2 16-16v-32c0-8.8-7.2-16-16-16z"},
  rhUiIcon: null,
};

export const GripLinesIcon = createIconBase(GripLinesIconConfig);

export default GripLinesIcon;