import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiHarveyBall70IconConfig: {
  name: 'RhUiHarveyBall70Icon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16a15.002 15.002 0 0 0 .73 4.631A14.956 14.956 0 0 0 16 31.001c8.271 0 15-6.729 15-15S24.271 1 16 1Zm-1 2.038v12.235L3.36 19.048A13.05 13.05 0 0 1 3 16C3 9.168 8.297 3.551 15 3.038Z"},
  rhUiIcon: null,
};
export declare const RhUiHarveyBall70Icon: ComponentClass<SVGIconProps>;
export default RhUiHarveyBall70Icon;