import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiImportAltIconConfig: {
  name: 'RhUiImportAltIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M30 3.5v25c0 .827-.673 1.5-1.5 1.5h-25c-.827 0-1.5-.673-1.5-1.5V16a1 1 0 1 1 2 0v12h24V4H16a1 1 0 1 1 0-2h12.5c.827 0 1.5.673 1.5 1.5ZM17.586 19H9a1 1 0 1 0 0 2h10.5c.827 0 1.5-.673 1.5-1.5V9a1 1 0 1 0-2 0v8.586L4.707 3.293a.999.999 0 1 0-1.414 1.414L17.586 19Z"},
  rhUiIcon: null,
};
export declare const RhUiImportAltIcon: ComponentClass<SVGIconProps>;
export default RhUiImportAltIcon;