import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiHarveyBall80IconConfig: {
  name: 'RhUiHarveyBall80Icon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1A14.956 14.956 0 0 0 1.73 11.37l-.001.003A15.032 15.032 0 0 0 1 16.001c0 8.271 6.729 15 15 15s15-6.729 15-15S24.271 1 16 1Zm-1 2.038v11.586L3.976 11.049A12.952 12.952 0 0 1 15 3.039Z"},
  rhUiIcon: null,
};
export declare const RhUiHarveyBall80Icon: ComponentClass<SVGIconProps>;
export default RhUiHarveyBall80Icon;