import { createIconBase } from '../createIcon.js';

export const InstalodIconConfig = {
  name: 'InstalodIcon',
  icon: {"xOffset":0,"yOffset":0,"width":512,"height":512,"svgPathData":"M153.384,480H387.113L502.554,275.765,204.229,333.211ZM504.726,240.078,387.113,32H155.669L360.23,267.9ZM124.386,48.809,7.274,256,123.236,461.154,225.627,165.561Z"},
  rhUiIcon: null,
};

export const InstalodIcon = createIconBase(InstalodIconConfig);

export default InstalodIcon;