import { createIconBase } from '../createIcon.js';

export const RhStandardCheckboxCheckedIconConfig = {
  name: 'RhStandardCheckboxCheckedIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M31 4.375H5A.625.625 0 0 0 4.375 5v26a.625.625 0 0 0 .625.625h26a.625.625 0 0 0 .625-.625V5A.625.625 0 0 0 31 4.375Zm-.625 26H5.625V5.625h24.75Z"},{"path":"M14.558 23.442a.625.625 0 0 0 .884 0l10.5-10.5a.625.625 0 0 0-.884-.884L15 22.116l-3.558-3.558a.625.625 0 0 0-.884.884Z"}]},
  rhUiIcon: null,
};

export const RhStandardCheckboxCheckedIcon = createIconBase(RhStandardCheckboxCheckedIconConfig);

export default RhStandardCheckboxCheckedIcon;