import { createIconBase } from '../createIcon.js';

export const RhStandardHarveyBall33IconConfig = {
  name: 'RhStandardHarveyBall33Icon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M18 3.375A14.625 14.625 0 1 0 32.625 18 14.642 14.642 0 0 0 18 3.375Zm0 28a13.366 13.366 0 0 1-.625-26.718V18a.626.626 0 0 0 .313.542l11.557 6.672A13.366 13.366 0 0 1 18 31.375Z"},
  rhUiIcon: null,
};

export const RhStandardHarveyBall33Icon = createIconBase(RhStandardHarveyBall33IconConfig);

export default RhStandardHarveyBall33Icon;