import { createIconBase } from '../createIcon.js';

export const RhMicronsSearchIconConfig = {
  name: 'RhMicronsSearchIcon',
  icon: {"xOffset":0,"yOffset":0,"width":20,"height":20,"svgPathData":"m18.8 17.21-4.41-4.41A7.906 7.906 0 0 0 16 8c0-4.41-3.59-8-8-8S0 3.59 0 8s3.59 8 8 8c1.73 0 3.42-.57 4.8-1.61l4.41 4.41c.44.44 1.15.44 1.59 0 .44-.44.44-1.15 0-1.59ZM8 14c-3.31 0-6-2.69-6-6s2.69-6 6-6 6 2.69 6 6-2.69 6-6 6Z"},
  rhUiIcon: null,
};

export const RhMicronsSearchIcon = createIconBase(RhMicronsSearchIconConfig);

export default RhMicronsSearchIcon;