import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhUiCollectionIconConfig: {
  name: 'RhUiCollectionIcon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M28.5 11h-25c-.827 0-1.5.673-1.5 1.5v17c0 .827.673 1.5 1.5 1.5h25c.827 0 1.5-.673 1.5-1.5v-17c0-.827-.673-1.5-1.5-1.5ZM28 29H4V13h24v16ZM6 2a1 1 0 0 1 1-1h18a1 1 0 0 1 0 2H7a1 1 0 0 1-1-1ZM4 7a1 1 0 0 1 1-1h22a1 1 0 0 1 0 2H5a1 1 0 0 1-1-1Z"},
  rhUiIcon: null,
};
export declare const RhUiCollectionIcon: ComponentClass<SVGIconProps>;
export default RhUiCollectionIcon;