import { createIconBase } from '../createIcon.js';

export const RhUiHarveyBallLower50IconConfig = {
  name: 'RhUiHarveyBallLower50Icon',
  icon: {"xOffset":0,"yOffset":0,"width":32,"height":32,"svgPathData":"M16 1C7.729 1 1 7.729 1 16s6.729 15 15 15 15-6.729 15-15S24.271 1 16 1Zm0 2c6.83 0 12.435 5.299 12.949 12H3.051C3.565 8.299 9.17 3 16 3Z"},
  rhUiIcon: null,
};

export const RhUiHarveyBallLower50Icon = createIconBase(RhUiHarveyBallLower50IconConfig);

export default RhUiHarveyBallLower50Icon;