/// <reference types="react" />
export interface TabTitleTextProps extends React.HTMLProps<HTMLSpanElement> {
    /** Text to be rendered inside the tab button title. */
    children: React.ReactNode;
    /** additional classes added to the tab title text */
    className?: string;
}
export declare const TabTitleText: React.FunctionComponent<TabTitleTextProps>;
//# sourceMappingURL=TabTitleText.d.ts.map