import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardAmpIconConfig: {
  name: 'RhStandardAmpIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":[{"path":"M31 8.38h-6.48l-.75-3.51a.62.62 0 0 0-.61-.49H12.84a.62.62 0 0 0-.61.49l-.75 3.51H5a.62.62 0 0 0-.62.62v20a.62.62 0 0 0 .62.62h26a.62.62 0 0 0 .62-.62V9a.62.62 0 0 0-.62-.62ZM13.35 5.62h9.3l.59 2.76H12.76Zm17 4v4.76H5.62V9.62ZM5.62 28.38V15.62h24.76v12.76Z"},{"path":"M24 12.62h3a.62.62 0 0 0 0-1.24h-3a.62.62 0 0 0 0 1.24Z"}]},
  rhUiIcon: null,
};
export declare const RhStandardAmpIcon: ComponentClass<SVGIconProps>;
export default RhStandardAmpIcon;