import { ComponentClass } from 'react';
import { SVGIconProps } from '../createIcon.js';
export declare const RhStandardPaperClipIconConfig: {
  name: 'RhStandardPaperClipIcon',
  icon: {"xOffset":0,"yOffset":0,"width":36,"height":36,"svgClassName":"pf-v6-icon-rh-standard","svgPathData":"M23 8.38a.62.62 0 0 0-.62.62v17a4.38 4.38 0 0 1-8.76 0V8.5a2.88 2.88 0 1 1 5.76 0V24a1.38 1.38 0 0 1-2.76 0V11a.62.62 0 1 0-1.24 0v13a2.62 2.62 0 0 0 5.24 0V8.5a4.12 4.12 0 0 0-8.24 0V26a5.62 5.62 0 0 0 11.24 0V9a.62.62 0 0 0-.62-.62Z"},
  rhUiIcon: null,
};
export declare const RhStandardPaperClipIcon: ComponentClass<SVGIconProps>;
export default RhStandardPaperClipIcon;