/// <reference types="react" />
export interface MastheadBrandProps extends React.DetailedHTMLProps<React.HTMLProps<HTMLDivElement>, HTMLDivElement> {
    /** Content rendered inside of the masthead brand. */
    children?: React.ReactNode;
    /** Additional classes added to the masthead brand. */
    className?: string;
}
export declare const MastheadBrand: React.FunctionComponent<MastheadBrandProps>;
//# sourceMappingURL=MastheadBrand.d.ts.map