.ws-react-f-stack {
  min-height: 30em;
  display: flex;
  flex-direction: column;
}

.ws-react-f-stack > .pf-v6-l-stack {
  flex-grow: 1;
}

.ws-react-f-stack .pf-v6-l-stack,
.ws-react-f-stack .pf-v6-l-stack > .pf-v6-l-stack__item {
  padding: var(--pf-t--global--spacer--md);
  border: var(--pf-t--global--border--width--box--default) dashed var(--pf-t--global--border--color--default);
}